unit MSLU;
// Microsoft Layer for Unicode import units for Delphi
// By Rob Kennedy
// http://www.cs.wisc.edu/~rkennedy/
// Copyright  2005 Rob Kennedy.
// See mslu-readme.txt for details.

// Some anomolies:
// - ChangeMenuW is not documented anywhere that I can find.
// - GetMetaFileW and SetWindowsHookW are obsolete and no longer documented.
// - When common-dialog functions like ChooseColorW fail, do not call
//   CommDlgExtendedError; the return value will not be valid because this unit
//   has no way of setting the extended error information.
// - When DDE functions like DdeConnect fail, do not call DdeGetLastError; the
//   return value will not be valid because this unit has no way of setting the
//   extended error information.
// - GetOpenFileNamePreviewW and GetSaveFileNamePreviewW will return
//   Invalid_Handle_Value on error; that's the best interpretation I can make
//   from the documentation.
{$Z4}
interface

uses
  Windows, SysUtils, ShellAPI, CommDlg, MultiMon, ActiveX, OleDlg, WinSpool,
  ShlObj, MMSystem, DdeMl;

//__FreeAllLibrariesInMsluDll;

type
  TLoadUnicows = function: HModule;

  // This exception gets thrown by the GetStartupInfoW function if there is an
  // error in loading the MSLU function.
  EMSLU = class(Exception)
  strict private
    FFunctionName: string;
  public
    constructor Create(const AFunctionName: string);
    property FunctionName: string read FFunctionName;
  end;

var
  // Assign a value to this variable to control how Unicows.dll gets loaded.
  // Return a handle to the loaded module.
  // The function will only get called if _PfnLoadUnicows is assigne BEFORE any
  // Unicows-handled functions get called in this program. Calling such a function
  // forces the library to be loaded, and once it's loaded, a custom loading
  // routine is useless.
  _PfnLoadUnicows: TLoadUnicows;

// Assign values to these variables to override the MSLU versions on operating
// systems that need Unicows. Assigning these variables has no effect on Windows
// NT-based systems since those systems support Unicode natively. Assigning them
// also has no effect once the corresponding API function has been called. This
// means that the order of unit initialization in a program might be important.
// Some of the function prototypes are commented out. This is because I do not
// have declarations for many of the data types used in those functions. They
// include the security, OLE UI, NLS, and RAS functions.
{$REGION ' MSLU Overrides '}
var
  Unicows_AcquireCredentialsHandleW: TFarProc; // function(pszPrincipal, pszPackage: PSecWChar; fCredentialUse: Cardinal; pvLogonId, pAuthData: Pointer; pGetKeyFn: SEC_GET_KEY_FN; pvGetKeyArgument: Pointer; phCredential: PCredHandle; var ptsExpiry: TTimeStamp): SECURITY_STATUS; stdcall;
  Unicows_AddAtomW: function(lpString: PWideChar): ATOM; stdcall;
  Unicows_AddFontResourceW: function(FileName: PWideChar): Integer; stdcall;
  Unicows_AddJobW: function(hPrinter: THandle; Level: DWORD; pData: Pointer; cbBuf: DWORD; var pcbNeeded: DWORD): BOOL; stdcall;
  Unicows_AddMonitorW: function(pName: PWideChar; Level: DWORD; pMonitors: Pointer): BOOL; stdcall;
  Unicows_AddPortW: function(pName: PWideChar; hWnd: HWND; pMonitorName: PWideChar): BOOL; stdcall;
  Unicows_AddPrintProcessorW: function(pName, pEnvironment, pPathName, pPrintProcessorName: PWideChar): BOOL; stdcall;
  Unicows_AddPrintProvidorW: function(pName: PWideChar; level: DWORD; pProvidorInfo: Pointer): BOOL; stdcall;
  Unicows_AddPrinterDriverW: function(pName: PWideChar; Level: DWORD; pDriverInfo: Pointer): BOOL; stdcall;
  Unicows_AddPrinterW: function(pName: PWideChar; Level: DWORD; pPrinter: Pointer): THandle; stdcall;
  Unicows_AdvancedDocumentPropertiesW: function(hWnd: HWND; hPrinter: THandle; pDeviceName: PWideChar; pDevModeOutput, pDevModeInput: PDeviceModeW): Longint; stdcall;
  Unicows_AppendMenuW: function(hMenu: HMENU; uFlags, uIDNewItem: UINT; lpNewItem: PWideChar): BOOL; stdcall;
  Unicows_BeginUpdateResourceA: function(pFileName: PAnsiChar; bDeleteExistingResources: BOOL): THandle; stdcall;
  Unicows_BeginUpdateResourceW: function(pFileName: PWideChar; bDeleteExistingResources: BOOL): THandle; stdcall;
  Unicows_BroadcastSystemMessageW: function(Flags: DWORD; Recipients: PDWORD; uiMessage: UINT; wParam: WPARAM; lParam: LPARAM): Longint; stdcall;
  Unicows_BuildCommDCBAndTimeoutsW: function(lpDef: PWideChar; var lpDCB: TDCB; var lpCommTimeouts: TCommTimeouts): BOOL; stdcall;
  Unicows_BuildCommDCBW: function(lpDef: PWideChar; var lpDCB: TDCB): BOOL; stdcall;
  Unicows_CallMsgFilterW: function(var lpMsg: TMsg; nCode: Integer): BOOL; stdcall;
  Unicows_CallNamedPipeW: function(lpNamedPipeName: PWideChar; lpInBuffer: Pointer; nInBufferSize: DWORD; lpOutBuffer: Pointer; nOutBufferSize: DWORD; var lpBytesRead: DWORD; nTimeOut: DWORD): BOOL; stdcall;
  Unicows_CallWindowProcA: function(lpPrevWndFunc: TFNWndProc; hWnd: HWND; Msg: UINT; wParam: WPARAM; lParam: LPARAM): LRESULT; stdcall;
  Unicows_CallWindowProcW: function(lpPrevWndFunc: TFNWndProc; hWnd: HWND; Msg: UINT; wParam: WPARAM; lParam: LPARAM): LRESULT; stdcall;
  Unicows_ChangeDisplaySettingsExW: function(lpszDeviceName: PWideChar; var lpDevMode: TDeviceModeW; wnd: HWND; dwFlags: DWORD; lParam: Pointer): Longint; stdcall;
  Unicows_ChangeDisplaySettingsW: function(var lpDevMode: TDeviceModeW; dwFlags: DWORD): Longint; stdcall;
  Unicows_ChangeMenuW: function(hMenu: HMENU; cmd: UINT; lpszNewItem: PWideChar; cmdInsert: UINT; flags: UINT): BOOL; stdcall;
  Unicows_CharLowerBuffW: function(lpsz: PWideChar; cchLength: DWORD): DWORD; stdcall;
  Unicows_CharLowerW: function(lpsz: PWideChar): PWideChar; stdcall;
  Unicows_CharNextW: function(lpsz: PWideChar): PWideChar; stdcall;
  Unicows_CharPrevW: function(lpszStart: PWideChar; lpszCurrent: PWideChar): PWideChar; stdcall;
  Unicows_CharToOemBuffW: function(lpszSrc: PWideChar; lpszDst: PWideChar; cchDstLength: DWORD): BOOL; stdcall;
  Unicows_CharToOemW: function(lpszSrc: PWideChar; lpszDst: PWideChar): BOOL; stdcall;
  Unicows_CharUpperBuffW: function(lpsz: PWideChar; cchLength: DWORD): DWORD; stdcall;
  Unicows_CharUpperW: function(lpsz: PWideChar): PWideChar; stdcall;
  Unicows_ChooseColorW: function(var CC: TChooseColorW): Bool; stdcall;
  Unicows_ChooseFontW: function(var ChooseFont: TChooseFontW): Bool; stdcall;
  Unicows_CommConfigDialogW: function(lpszName: PWideChar; hWnd: HWND; var lpCC: TCommConfig): BOOL; stdcall;
  Unicows_CompareStringW: function(Locale: LCID; dwCmpFlags: DWORD; lpString1: PWideChar; cchCount1: Integer; lpString2: PWideChar; cchCount2: Integer): Integer; stdcall;
  Unicows_ConfigurePortW: function(pName: PWideChar; hWnd: HWND; pPortName: PWideChar): BOOL; stdcall;
  Unicows_CopyAcceleratorTableW: function(hAccelSrc: HACCEL; var lpAccelDst; cAccelEntries: Integer): Integer; stdcall;
  Unicows_CopyEnhMetaFileW: function(p1: HENHMETAFILE; p2: PWideChar): HENHMETAFILE; stdcall;
  Unicows_CopyFileExW: function(lpExistingFileName, lpNewFileName: PWideChar; lpProgressRoutine: TFNProgressRoutine; lpData: Pointer; pbCancel: PBool; dwCopyFlags: DWORD): BOOL; stdcall;
  Unicows_CopyFileW: function(lpExistingFileName, lpNewFileName: PWideChar; bFailIfExists: BOOL): BOOL; stdcall;
  Unicows_CopyMetaFileW: function(p1: HMETAFILE; p2: PWideChar): HMETAFILE; stdcall;
  Unicows_CreateAcceleratorTableW: function(var Accel; Count: Integer): HACCEL; stdcall;
  Unicows_CreateColorSpaceW: function(var ColorSpace: TLogColorSpaceW): HCOLORSPACE; stdcall;
  Unicows_CreateDCW: function(lpszDriver, lpszDevice, lpszOutput: PWideChar; lpdvmInit: PDeviceModeW): HDC; stdcall;
  Unicows_CreateDialogIndirectParamW: function(hInstance: HINST; const lpTemplate: TDlgTemplate; hWndParent: HWND; lpDialogFunc: TFNDlgProc; dwInitParam: LPARAM): HWND; stdcall;
  Unicows_CreateDialogParamW: function(hInstance: HINST; lpTemplateName: PWideChar; hWndParent: HWND; lpDialogFunc: TFNDlgProc; dwInitParam: LPARAM): HWND; stdcall;
  Unicows_CreateDirectoryExW: function(lpTemplateDirectory, lpNewDirectory: PWideChar; lpSecurityAttributes: PSecurityAttributes): BOOL; stdcall;
  Unicows_CreateDirectoryW: function(lpPathName: PWideChar; lpSecurityAttributes: PSecurityAttributes): BOOL; stdcall;
  Unicows_CreateEnhMetaFileW: function(DC: HDC; FileName: PWideChar; Rect: PRect; Desc: PWideChar): HDC; stdcall;
  Unicows_CreateEventW: function(lpEventAttributes: PSecurityAttributes; bManualReset, bInitialState: BOOL; lpName: PWideChar): THandle; stdcall;
  Unicows_CreateFileMappingW: function(hFile: THandle; lpFileMappingAttributes: PSecurityAttributes; flProtect, dwMaximumSizeHigh, dwMaximumSizeLow: DWORD; lpName: PWideChar): THandle; stdcall;
  Unicows_CreateFileW: function(lpFileName: PWideChar; dwDesiredAccess, dwShareMode: DWORD; lpSecurityAttributes: PSecurityAttributes; dwCreationDisposition, dwFlagsAndAttributes: DWORD; hTemplateFile: THandle): THandle; stdcall;
  Unicows_CreateFontIndirectW: function(const p1: TLogFontW): HFONT; stdcall;
  Unicows_CreateFontW: function(nHeight, nWidth, nEscapement, nOrientaion, fnWeight: Integer; fdwItalic, fdwUnderline, fdwStrikeOut, fdwCharSet, fdwOutputPrecision, fdwClipPrecision, fdwQuality, fdwPitchAndFamily: DWORD; lpszFace: PWideChar): HFONT; stdcall;
  Unicows_CreateICW: function(lpszDriver, lpszDevice, lpszOutput: PWideChar; lpdvmInit: PDeviceModeW): HDC; stdcall;
  Unicows_CreateMDIWindowW: function(lpClassName, lpWindowName: PWideChar; dwStyle: DWORD; X, Y, nWidth, nHeight: Integer; hWndParent: HWND; hInstance: HINST; lParam: LPARAM): HWND; stdcall;
  Unicows_CreateMailslotW: function(lpName: PWideChar; nMaxMessageSize: DWORD; lReadTimeout: DWORD; lpSecurityAttributes: PSecurityAttributes): THandle; stdcall;
  Unicows_CreateMetaFileW: function(lpszFile: PWideChar): HDC; stdcall;
  Unicows_CreateMutexW: function(lpMutexAttributes: PSecurityAttributes; bInitialOwner: BOOL; lpName: PWideChar): THandle; stdcall;
  Unicows_CreateNamedPipeW: function(lpName: PWideChar; dwOpenMode, dwPipeMode, nMaxInstances, nOutBufferSize, nInBufferSize, nDefaultTimeOut: DWORD; lpSecurityAttributes: PSecurityAttributes): THandle; stdcall;
  Unicows_CreateProcessW: function(lpApplicationName: PWideChar; lpCommandLine: PWideChar; lpProcessAttributes, lpThreadAttributes: PSecurityAttributes; bInheritHandles: BOOL; dwCreationFlags: DWORD; lpEnvironment: Pointer; lpCurrentDirectory: PWideChar; const lpStartupInfo: TStartupInfoW; var lpProcessInformation: TProcessInformation): BOOL; stdcall;
  Unicows_CreateScalableFontResourceW: function(p1: DWORD; p2, p3, p4: PWideChar): BOOL; stdcall;
  Unicows_CreateSemaphoreW: function(lpSemaphoreAttributes: PSecurityAttributes; lInitialCount, lMaximumCount: Longint; lpName: PWideChar): THandle; stdcall;
  Unicows_CreateStdAccessibleProxyW: function(hwnd: HWnd; const pszClassName: PWideChar; idObject: LongInt; const riidInterface: TGUID; out pvvObject): HResult; stdcall;
  Unicows_CreateWaitableTimerW: function(lpTimerAttributes: PSecurityAttributes; bManualReset: BOOL; lpTimerName: PWideChar): THandle; stdcall;
  Unicows_CreateWindowExW: function(dwExStyle: DWORD; lpClassName: PWideChar; lpWindowName: PWideChar; dwStyle: DWORD; X, Y, nWidth, nHeight: Integer; hWndParent: HWND; hMenu: HMENU; hInstance: HINST; lpParam: Pointer): HWND;
  Unicows_CryptAcquireContextW: TFarProc; // function(var phProv: HCRYPTPROV; pszContainer: LPCWSTR; pszProvider: LPCWSTR; dwProvType: DWORD; dwFlags: DWORD): BOOL; stdcall;
  Unicows_CryptEnumProviderTypesW: function(dwIndex: DWORD; pdwReserved: LPDWORD; dwFlags: DWORD; var pdwProvType: DWORD; pszTypeName: LPWSTR; var pcbTypeName: DWORD): BOOL; stdcall;
  Unicows_CryptEnumProvidersW: function(dwIndex: DWORD; pdwReserved: LPDWORD; dwFlags: DWORD; var pdwProvType: DWORD; pszProvName: LPWSTR; var pcbProvName: DWORD): BOOL; stdcall;
  Unicows_CryptGetDefaultProviderW: function(dwProvType: DWORD; pdwReserved: LPDWORD; dwFlags: DWORD; pszProvName: LPWSTR; var pcbProvName: DWORD): BOOL; stdcall;
  Unicows_CryptSetProviderExW: function(pszProvName: LPCWSTR; dwProvType: DWORD; pdwReserved: LPDWORD; dwFlags: DWORD): BOOL; stdcall;
  Unicows_CryptSetProviderW: function(pszProvName: LPCWSTR; dwProvType: DWORD): BOOL; stdcall;
  Unicows_CryptSignHashW: TFarProc; // function(hHash: HCRYPTHASH; dwKeySpec: DWORD; sDescription: LPCWSTR; dwFlags: DWORD; pbSignature: LPBYTE; var pdwSigLen: DWORD): BOOL; stdcall;
  Unicows_CryptVerifySignatureW: TFarProc; // function(hHash: HCRYPTHASH; pbSignature: LPBYTE; dwSigLen: DWORD; hPubKey: HCRYPTKEY; sDescription: LPCWSTR; dwFlags: DWORD): BOOL; stdcall;
  Unicows_DdeConnect: function(Inst: DWORD; Service, Topic: HSZ; CC: PConvContext): HConv; stdcall;
  Unicows_DdeConnectList: function(Inst: DWORD; Service, Topic: HSZ; ConvList: HConvList; CC: PConvContext): HConvList; stdcall;
  Unicows_DdeCreateStringHandleW: function(Inst: DWORD; psz: PWideChar; CodePage: Integer): HSZ; stdcall;
  Unicows_DdeInitializeW: function(var Inst: Longint; Callback: TFNCallback; Cmd, Res: Longint): Longint; stdcall;
  Unicows_DdeQueryConvInfo: function(Conv: HConv; Transaction: DWORD; ConvInfo: PConvInfo): UINT; stdcall;
  Unicows_DdeQueryStringW: function(Inst: DWORD; HSZ: HSZ; psz: PWideChar; Max: DWORD; CodePage: Integer): DWORD; stdcall;
  Unicows_DefDlgProcW: function(hDlg: HWND; Msg: UINT; wParam: WPARAM; lParam: LPARAM): LRESULT; stdcall;
  Unicows_DefFrameProcW: function(hWnd, hWndMDIClient: HWND; uMsg: UINT; wParam: WPARAM; lParam: LPARAM): LRESULT; stdcall;
  Unicows_DefMDIChildProcW: function(hWnd: HWND; uMsg: UINT; wParam: WPARAM; lParam: LPARAM): LRESULT; stdcall;
  Unicows_DefWindowProcW: function(hWnd: HWND; Msg: UINT; wParam: WPARAM; lParam: LPARAM): LRESULT; stdcall;
  Unicows_DeleteFileW: function(lpFileName: PWideChar): BOOL; stdcall;
  Unicows_DeleteMonitorW: function(pName, pEnvironment, pMonitorName: PWideChar): BOOL; stdcall;
  Unicows_DeletePortW: function(pName: PWideChar; hWnd: HWND; pPortName: PWideChar): BOOL; stdcall;
  Unicows_DeletePrintProcessorW: function(pName, pEnvironment, pPrintProcessorName: PWideChar): BOOL; stdcall;
  Unicows_DeletePrintProvidorW: function(pName, pEnvironment, pPrintProvidorName: PWideChar): BOOL; stdcall;
  Unicows_DeletePrinterDriverW: function(pName, pEnvironment, pDriverName: PWideChar): BOOL; stdcall;
  Unicows_DeviceCapabilitiesW: function(pDevice, pPort: PWideChar; fwCapability: Word; pOutput: PWideChar; DevMode: PDeviceModeW): Integer; stdcall;
  Unicows_DialogBoxIndirectParamW: function(hInstance: HINST; const lpDialogTemplate: TDlgTemplate; hWndParent: HWND; lpDialogFunc: TFNDlgProc; dwInitParam: LPARAM): Integer; stdcall;
  Unicows_DialogBoxParamW: function(hInstance: HINST; lpTemplateName: PWideChar; hWndParent: HWND; lpDialogFunc: TFNDlgProc; dwInitParam: LPARAM): Integer; stdcall;
  Unicows_DispatchMessageW: function(const lpMsg: TMsg): Longint; stdcall;
  Unicows_DlgDirListComboBoxW: function(hDlg: HWND; lpPathSpec: PWideChar; nIDComboBox, nIDStaticPath: Integer; uFiletype: UINT): Integer; stdcall;
  Unicows_DlgDirListW: function(hDlg: HWND; lpPathSpec: PWideChar; nIDListBox, nIDStaticPath: Integer; uFileType: UINT): Integer; stdcall;
  Unicows_DlgDirSelectComboBoxExW: function(hDlg: HWND; lpString: PWideChar; nCount, nIDComboBox: Integer): BOOL; stdcall;
  Unicows_DlgDirSelectExW: function(hDlg: HWND; lpString: PWideChar; nCount, nIDListBox: Integer): BOOL; stdcall;
  Unicows_DocumentPropertiesW: function(hWnd: HWND; hPrinter: THandle; pDeviceName: PWideChar; const pDevModeOutput: TDeviceModeW; var pDevModeInput: TDeviceModeW; fMode: DWORD): Longint; stdcall;
  Unicows_DragQueryFileW: function(Drop: HDROP; FileIndex: UINT; FileName: PWideChar; cb: UINT): UINT; stdcall;
  Unicows_DrawStateW: function(DC: HDC; Brush: HBRUSH; CBFunc: TFNDrawStateProc; lData: LPARAM; wData: WPARAM; x, y, cx, cy: Integer; Flags: UINT): BOOL; stdcall;
  Unicows_DrawTextExW: function(DC: HDC; lpchText: PWideChar; cchText: Integer; var p4: TRect; dwDTFormat: UINT; DTParams: PDrawTextParams): Integer; stdcall;
  Unicows_DrawTextW: function(hDC: HDC; lpString: PWideChar; nCount: Integer; var lpRect: TRect; uFormat: UINT): Integer; stdcall;
  Unicows_EnableWindow: function(hWnd: HWND; bEnable: BOOL): BOOL; stdcall;
  Unicows_EndUpdateResourceA: function(hUpdate: THandle; fDiscard: BOOL): BOOL; stdcall;
  Unicows_EndUpdateResourceW: function(hUpdate: THandle; fDiscard: BOOL): BOOL; stdcall;
  Unicows_EnumCalendarInfoExW: TFarProc; // function(lpCalInfoEnumProcEx: CALINFO_ENUMPROCEXW; Locale: LCID; Calendar: CALID; CalType: CALTYPE): BOOL; stdcall;
  Unicows_EnumCalendarInfoW: TFarProc; // function(lpCalInfoEnumProc: CALINFO_ENUMPROCW; Locale: LCID; Calendar: CALID; CalType: CALTYPE): BOOL; stdcall;
  Unicows_EnumClipboardFormats: function(format: UINT): UINT; stdcall;
  Unicows_EnumDateFormatsExW: TFarProc; // function(lpDateFmtEnumProcEx: DATEFMT_ENUMPROCEXW; Locale: LCID; dwFlags: DWORD): BOOL; stdcall;
  Unicows_EnumDateFormatsW: TFarProc; // function(lpDateFmtEnumProc: DATEFMT_ENUMPROCW; Locale: LCID; dwFlags: DWORD): BOOL; stdcall;
  Unicows_EnumDisplayDevicesW: function(Unused: Pointer; iDevNum: DWORD; var lpDisplayDevice: TDisplayDeviceW; dwFlags: DWORD): BOOL; stdcall;
  Unicows_EnumDisplaySettingsExW: function(lpszDeviceName: LPCWSTR; iModeNum: DWORD; var lpDevMode: DEVMODEW; dwFlags: DWORD): BOOL; stdcall;
  Unicows_EnumDisplaySettingsW: function(lpszDeviceName: PWideChar; iModeNum: DWORD; var lpDevMode: TDeviceModeW): BOOL; stdcall;
  Unicows_EnumFontFamiliesExW: function(DC: HDC; var p2: TLogFontW; p3: TFNFontEnumProcW; p4: LPARAM; p5: DWORD): BOOL; stdcall;
  Unicows_EnumFontFamiliesW: function(DC: HDC; p2: PWideChar; p3: TFNFontEnumProcW; p4: LPARAM): BOOL; stdcall;
  Unicows_EnumFontsW: function(DC: HDC; lpszFace: PWideChar; fntenmprc: TFNFontEnumProcW; lpszData: PChar): Integer; stdcall;
  Unicows_EnumICMProfilesW: function(DC: HDC; ICMProc: TFNICMEnumProc; p3: LPARAM): Integer; stdcall;
  Unicows_EnumMonitorsW: function(pName: PWideChar; Level: DWORD; pMonitors: Pointer; cbBuf: DWORD; var pcbNeeded, pcReturned: DWORD): BOOL; stdcall;
  Unicows_EnumPortsW: function(pName: PWideChar; Level: DWORD; pPorts: Pointer; cbBuf: DWORD; var pcbNeeded, pcReturned: DWORD): BOOL; stdcall;
  Unicows_EnumPrintProcessorDatatypesW: function(pName, pPrintProcessorName: PWideChar; Level: DWORD; pDatatypes: Pointer; cbBuf: DWORD; var pcbNeeded, pcReturned: DWORD): BOOL; stdcall;
  Unicows_EnumPrintProcessorsW: function(pName, pEnvironment: PWideChar; Level: DWORD; pPrintProcessorInfo: Pointer; cbBuf: DWORD; var pcbNeeded, pcReturned: DWORD): BOOL; stdcall;
  Unicows_EnumPrinterDriversW: function(pName, pEnvironment: PWideChar; Level: DWORD; pDriverInfo: Pointer; cbBuf: DWORD; var pcbNeeded, pcReturned: DWORD): BOOL; stdcall;
  Unicows_EnumPrintersW: function(Flags: DWORD; Name: PWideChar; Level: DWORD; pPrinterEnum: Pointer; cbBuf: DWORD; var pcbNeeded, pcReturned: DWORD): BOOL; stdcall;
  Unicows_EnumPropsA: function(hWnd: HWND; lpEnumFunc: TFNPropEnumProc): Integer; stdcall;
  Unicows_EnumPropsExA: function(hWnd: HWND; lpEnumFunc: TFNPropEnumProcEx; lParam: LPARAM): Integer; stdcall;
  Unicows_EnumPropsExW: function(hWnd: HWND; lpEnumFunc: TFNPropEnumProcEx; lParam: LPARAM): Integer; stdcall;
  Unicows_EnumPropsW: function(hWnd: HWND; lpEnumFunc: TFNPropEnumProc): Integer; stdcall;
  Unicows_EnumSystemCodePagesW: function(lpCodePageEnumProc: TFNCodepageEnumProc; dwFlags: DWORD): BOOL; stdcall;
  Unicows_EnumSystemLocalesW: function(lpLocaleEnumProc: TFNLocaleEnumProc; dwFlags: DWORD): BOOL; stdcall;
  Unicows_EnumTimeFormatsW: function(lpTimeFmtEnumProc: TFNTimeFmtEnumProc; Locale: LCID; dwFlags: DWORD): BOOL; stdcall;
  Unicows_EnumerateSecurityPackagesW: TFarProc; // function(var pcPackages: Cardinal; var ppPackageInfo: PSecPkgInfoW): SECURITY_STATUS; stdcall;
  Unicows_ExpandEnvironmentStringsW: function(lpSrc: PWideChar; lpDst: PWideChar; nSize: DWORD): DWORD; stdcall;
  Unicows_ExtTextOutW: function(DC: HDC; X, Y: Integer; Options: Longint; Rect: PRect; Str: PWideChar; Count: Longint; Dx: PInteger): BOOL; stdcall;
  Unicows_ExtractIconExW: function(lpszFile: PWideChar; nIconIndex: Integer; var phiconLarge, phiconSmall: HICON; nIcons: UINT): UINT; stdcall;
  Unicows_ExtractIconW: function(hInst: HINST; lpszExeFileName: PWideChar; nIconIndex: UINT): HICON; stdcall;
  Unicows_FatalAppExitW: procedure(uAction: UINT; lpMessageText: PWideChar); stdcall;
  Unicows_FillConsoleOutputCharacterW: function(hConsoleOutput: THandle; cCharacter: WideChar; nLength: DWORD; dwWriteCoord: TCoord; var lpNumberOfCharsWritten: DWORD): BOOL; stdcall;
  Unicows_FindAtomW: function(lpString: PWideChar): ATOM; stdcall;
  Unicows_FindExecutableW: function(FileName, Directory: PWideChar; lpResult: PWideChar): HINST; stdcall;
  Unicows_FindFirstChangeNotificationW: function(lpPathName: PWideChar; bWatchSubtree: BOOL; dwNotifyFilter: DWORD): THandle; stdcall;
  Unicows_FindFirstFileW: function(lpFileName: PWideChar; var lpFindFileData: TWIN32FindDataW): THandle; stdcall;
  Unicows_FindNextFileW: function(hFindFile: THandle; var lpFindFileData: TWIN32FindDataW): BOOL; stdcall;
  Unicows_FindResourceExW: function(hModule: HMODULE; lpType, lpName: PWideChar; wLanguage: Word): HRSRC; stdcall;
  Unicows_FindResourceW: function(hModule: HMODULE; lpName, lpType: PWideChar): HRSRC; stdcall;
  Unicows_FindTextW: function(var FindReplace: TFindReplaceW): HWND; stdcall;
  Unicows_FindWindowExW: function(Parent, Child: HWND; ClassName, WindowName: PWideChar): HWND; stdcall;
  Unicows_FindWindowW: function(lpClassName, lpWindowName: PWideChar): HWND; stdcall;
  Unicows_FormatMessageW: function(dwFlags: DWORD; lpSource: Pointer; dwMessageId: DWORD; dwLanguageId: DWORD; lpBuffer: PWideChar; nSize: DWORD; Arguments: Pointer): DWORD; stdcall;
  Unicows_FreeContextBuffer: TFarProc; // function(pvContextBuffer: Pointer): SECURITY_STATUS; stdcall;
  Unicows_FreeEnvironmentStringsW: function(EnvBlock: PWideChar): BOOL; stdcall;
  Unicows_GetAltTabInfoW: function(hwnd: HWND; iItem: Integer; var pati: TAltTabInfo; pszItemText: PWideChar; cchItemText: UINT): BOOL; stdcall;
  Unicows_GetAtomNameW: function(nAtom: ATOM; lpBuffer: PWideChar; nSize: Integer): UINT; stdcall;
  Unicows_GetCPInfo: function(CodePage: UINT; var lpCPInfo: TCPInfo): BOOL; stdcall;
  Unicows_GetCPInfoExW: TFarProc; // function(CodePage: UINT; dwFlags: DWORD; var lpCPInfoEx: CPINFOEXW): BOOL; stdcall;
  Unicows_GetCalendarInfoW: function(Locale: LCID; Calendar: CALID; CalType: CALTYPE; lpCalData: LPWSTR; cchData: Integer; lpValue: LPDWORD): Integer; stdcall;
  Unicows_GetCharABCWidthsFloatW: function(DC: HDC; FirstChar, LastChar: UINT; const ABCFloatSturcts): BOOL; stdcall;
  Unicows_GetCharABCWidthsW: function(DC: HDC; FirstChar, LastChar: UINT; const ABCStructs): BOOL; stdcall;
  Unicows_GetCharWidth32W: function(DC: HDC; FirstChar, LastChar: UINT; const Widths): BOOL; stdcall;
  Unicows_GetCharWidthFloatW: function(DC: HDC; FirstChar, LastChar: UINT; const Widths): BOOL; stdcall;
  Unicows_GetCharWidthW: function(DC: HDC; FirstChar, LastChar: UINT; const Widths): BOOL; stdcall;
  Unicows_GetCharacterPlacementW: function(DC: HDC; p2: PWideChar; p3, p4: BOOL; var p5: TGCPResults; p6: DWORD): DWORD; stdcall;
  Unicows_GetClassInfoExW: function(Instance: HINST; Classname: PWideChar; var WndClass: TWndClassExW): BOOL; stdcall;
  Unicows_GetClassInfoW: function(hInstance: HINST; lpClassName: PWideChar; var lpWndClass: TWndClassW): BOOL; stdcall;
  Unicows_GetClassLongW: function(hWnd: HWND; nIndex: Integer): DWORD; stdcall;
  Unicows_GetClassNameW: function(hWnd: HWND; lpClassName: PWideChar; nMaxCount: Integer): Integer; stdcall;
  Unicows_GetClipboardData: function(uFormat: UINT): THandle; stdcall;
  Unicows_GetClipboardFormatNameW: function(format: UINT; lpszFormatName: PWideChar; cchMaxCount: Integer): Integer; stdcall;
  Unicows_GetComputerNameW: function(lpBuffer: PWideChar; var nSize: DWORD): BOOL; stdcall;
  Unicows_GetConsoleTitleW: function(lpConsoleTitle: PWideChar; nSize: DWORD): DWORD; stdcall;
  Unicows_GetCurrencyFormatW: function(Locale: LCID; dwFlags: DWORD; lpValue: PWideChar; lpFormat: PCurrencyFmtW; lpCurrencyStr: PWideChar; cchCurrency: Integer): Integer; stdcall;
  Unicows_GetCurrentDirectoryW: function(nBufferLength: DWORD; lpBuffer: PWideChar): DWORD; stdcall;
  Unicows_GetCurrentHwProfileW: function(var lpHwProfileInfo: THWProfileInfoW): BOOL; stdcall;
  Unicows_GetDateFormatW: function(Locale: LCID; dwFlags: DWORD; lpDate: PSystemTime; lpFormat: PWideChar; lpDateStr: PWideChar; cchDate: Integer): Integer; stdcall;
  Unicows_GetDefaultCommConfigW: function(lpszName: PWideChar; var lpCC: TCommConfig; var lpdwSize: DWORD): BOOL; stdcall;
  Unicows_GetDiskFreeSpaceExW: function(lpDirectoryName: PWideChar; var lpFreeBytesAvailableToCaller, lpTotalNumberOfBytes; lpTotalNumberOfFreeBytes: PLargeInteger): BOOL; stdcall;
  Unicows_GetDiskFreeSpaceW: function(lpRootPathName: PWideChar; var lpSectorsPerCluster, lpBytesPerSector, lpNumberOfFreeClusters, lpTotalNumberOfClusters: DWORD): BOOL; stdcall;
  Unicows_GetDlgItemTextW: function(hDlg: HWND; nIDDlgItem: Integer; lpString: PWideChar; nMaxCount: Integer): UINT; stdcall;
  Unicows_GetDriveTypeW: function(lpRootPathName: PWideChar): UINT; stdcall;
  Unicows_GetEnhMetaFileDescriptionW: function(p1: HENHMETAFILE; p2: UINT; p3: PWideChar): UINT; stdcall;
  Unicows_GetEnhMetaFileW: function(p1: PWideChar): HENHMETAFILE; stdcall;
  Unicows_GetEnvironmentStringsW: function: PWideChar; stdcall;
  Unicows_GetEnvironmentVariableW: function(lpName: PWideChar; lpBuffer: PWideChar; nSize: DWORD): DWORD; stdcall;
  Unicows_GetFileAttributesExW: function(lpFileName: PWideChar; fInfoLevelId: TGetFileExInfoLevels; lpFileInformation: Pointer): BOOL; stdcall;
  Unicows_GetFileAttributesW: function(lpFileName: PWideChar): DWORD; stdcall;
  Unicows_GetFileTitleW: function(FileName: PWideChar; Title: PWideChar; TitleSize: Word): Smallint; stdcall;
  Unicows_GetFileVersionInfoSizeW: function(lptstrFilename: PWideChar; var lpdwHandle: DWORD): DWORD; stdcall;
  Unicows_GetFileVersionInfoW: function(lptstrFilename: PWideChar; dwHandle, dwLen: DWORD; lpData: Pointer): BOOL; stdcall;
  Unicows_GetFullPathNameW: function(lpFileName: PWideChar; nBufferLength: DWORD; lpBuffer: PWideChar; var lpFilePart: PWideChar): DWORD; stdcall;
  Unicows_GetGlyphOutlineW: function(DC: HDC; uChar, uFormat: UINT; const lpgm: TGlyphMetrics; cbBuffer: DWORD; lpvBuffer: Pointer; const lpmat2: TMat2): DWORD; stdcall;
  Unicows_GetICMProfileW: function(DC: HDC; var Size: DWORD; Name: PWideChar): BOOL; stdcall;
  Unicows_GetJobW: function(hPrinter: THandle; JobId: DWORD; Level: DWORD; pJob: Pointer; cbBuf: DWORD; pcbNeeded: PDWORD): BOOL; stdcall;
  Unicows_GetKerningPairsW: TFarProc; // function(hDc: HDC; nNumPairs: DWORD; lpkrnpair: LPKERNINGPAIR): DWORD; stdcall;
  Unicows_GetKeyNameTextW: function(lParam: Longint; lpString: PWideChar; nSize: Integer): Integer; stdcall;
  Unicows_GetKeyboardLayoutNameW: function(pwszKLID: PWideChar): BOOL; stdcall;
  Unicows_GetLocaleInfoW: function(Locale: LCID; LCType: LCTYPE; lpLCData: PWideChar; cchData: Integer): Integer; stdcall;
  Unicows_GetLogColorSpaceW: function(p1: HCOLORSPACE; var ColorSpace: TLogColorSpaceW; Size: DWORD): BOOL; stdcall;
  Unicows_GetLogicalDriveStringsW: function(nBufferLength: DWORD; lpBuffer: PAnsiChar): DWORD; stdcall;
  Unicows_GetLongPathNameW: function(lpszShortPath: LPCWSTR; lpszLongPath: LPWSTR; cchBuffer: DWORD): DWORD; stdcall;
  Unicows_GetMenuItemInfoW: function(p1: HMENU; p2: UINT; p3: BOOL; var p4: TMenuItemInfoW): BOOL; stdcall;
  Unicows_GetMenuStringW: function(hMenu: HMENU; uIDItem: UINT; lpString: PWideChar; nMaxCount: Integer; uFlag: UINT): Integer; stdcall;
  Unicows_GetMessageW: function(var lpMsg: TMsg; hWnd: HWND; wMsgFilterMin, wMsgFilterMax: UINT): BOOL; stdcall;
  Unicows_GetMetaFileW: function(p1: PWideChar): HMETAFILE; stdcall;
  Unicows_GetModuleFileNameW: function(hModule: HINST; lpFilename: PWideChar; nSize: DWORD): DWORD; stdcall;
  Unicows_GetModuleHandleW: function(lpModuleName: PWideChar): HMODULE; stdcall;
  Unicows_GetMonitorInfoW: function(hMonitor: HMONITOR; lpMonitorInfo: PMonitorInfoW): Boolean; stdcall;
  Unicows_GetNamedPipeHandleStateW: function(hNamedPipe: THandle; lpState, lpCurInstances, lpMaxCollectionCount, lpCollectDataTimeout: PDWORD; lpUserName: PWideChar; nMaxUserNameSize: DWORD): BOOL; stdcall;
  Unicows_GetNumberFormatW: function(Locale: LCID; dwFlags: DWORD; lpValue: PWideChar; lpFormat: PNumberFmtW; lpNumberStr: PWideChar; cchNumber: Integer): Integer; stdcall;
  Unicows_GetObjectW: function(p1: HGDIOBJ; p2: Integer; p3: Pointer): Integer; stdcall;
  Unicows_GetOpenFileNamePreviewW: function(var lpofn: TOpenFileNameW): Bool; stdcall;
  Unicows_GetOpenFileNameW: function(var OpenFile: TOpenFilenameW): Bool; stdcall;
  Unicows_GetOutlineTextMetricsW: function(DC: HDC; p2: UINT; OTMetricStructs: Pointer): UINT; stdcall;
  Unicows_GetPrintProcessorDirectoryW: function(pName, pEnvironment: PWideChar; Level: DWORD; pPrintProcessorInfo: Pointer; cbBuf: DWORD; var pcbNeeded: DWORD): BOOL; stdcall;
  Unicows_GetPrinterDataW: function(hPrinter: THandle; pValueName: PWideChar; pType: PDWORD; pData: Pointer; nSize: DWORD; var pcbNeeded: DWORD): DWORD; stdcall;
  Unicows_GetPrinterDriverDirectoryW: function(pName, pEnvironment: PWideChar; Level: DWORD; pDriverDirectory: Pointer; cbBuf: DWORD; var pcbNeeded: DWORD): BOOL; stdcall;
  Unicows_GetPrinterDriverW: function(hPrinter: THandle; pEnvironment: PWideChar; Level: DWORD; pDriverInfo: Pointer; cbBuf: DWORD; var pcbNeeded: DWORD): BOOL; stdcall;
  Unicows_GetPrinterW: function(hPrinter: THandle; Level: DWORD; pPrinter: Pointer; cbBuf: DWORD; pcbNeeded: PDWORD): BOOL; stdcall;
  Unicows_GetPrivateProfileIntW: function(lpAppName, lpKeyName: PWideChar; nDefault: Integer; lpFileName: PWideChar): UINT; stdcall;
  Unicows_GetPrivateProfileSectionNamesW: function(lpszReturnBuffer: PWideChar; nSize: DWORD; lpFileName: PWideChar): DWORD; stdcall;
  Unicows_GetPrivateProfileSectionW: function(lpAppName: PWideChar; lpReturnedString: PWideChar; nSize: DWORD; lpFileName: PWideChar): DWORD; stdcall;
  Unicows_GetPrivateProfileStringW: function(lpAppName, lpKeyName, lpDefault: PWideChar; lpReturnedString: PWideChar; nSize: DWORD; lpFileName: PWideChar): DWORD; stdcall;
  Unicows_GetPrivateProfileStructW: function(lpszSection, lpszKey: PWideChar; lpStruct: Pointer; uSizeStruct: UINT; szFile: PWideChar): BOOL; stdcall;
  Unicows_GetProcAddress: function(hModule: HMODULE; lpProcName: LPCSTR): FARPROC; stdcall;
  Unicows_GetProfileIntW: function(lpAppName, lpKeyName: PWideChar; nDefault: Integer): UINT; stdcall;
  Unicows_GetProfileSectionW: function(lpAppName: PWideChar; lpReturnedString: PWideChar; nSize: DWORD): DWORD; stdcall;
  Unicows_GetProfileStringW: function(lpAppName, lpKeyName, lpDefault: PWideChar; lpReturnedString: PWideChar; nSize: DWORD): DWORD; stdcall;
  Unicows_GetPropA: function(hWnd: HWND; lpString: PAnsiChar): THandle; stdcall;
  Unicows_GetPropW: function(hWnd: HWND; lpString: PWideChar): THandle; stdcall;
  Unicows_GetRoleTextW: function(dwRole: DWord; lpszRole: PWideChar; cchRoleMax: UInt): UInt; stdcall;
  Unicows_GetSaveFileNamePreviewW: function(var lpofn: TOpenFileNameW): Bool; stdcall;
  Unicows_GetSaveFileNameW: function(var OpenFile: TOpenFilenameW): Bool; stdcall;
  Unicows_GetShortPathNameW: function(lpszLongPath: PWideChar; lpszShortPath: PWideChar; cchBuffer: DWORD): DWORD; stdcall;
  Unicows_GetStartupInfoW: procedure(var lpStartupInfo: TStartupInfo); stdcall;
  Unicows_GetStateTextW: function(dwStateBit: DWord; lpszStateBit: PWideChar; cchStateBitMax: UInt): UInt; stdcall;
  Unicows_GetStringTypeExW: function(Locale: LCID; dwInfoType: DWORD; lpSrcStr: PWideChar; cchSrc: Integer; var lpCharType): BOOL; stdcall;
  Unicows_GetStringTypeW: function(dwInfoType: DWORD; const lpSrcStr: WCHAR; cchSrc: BOOL; var lpCharType: Word): BOOL;
  Unicows_GetSystemDirectoryW: function(lpBuffer: PWideChar; uSize: UINT): UINT; stdcall;
  Unicows_GetSystemWindowsDirectoryW: function(lpBuffer: LPWSTR; uSize: UINT): UINT; stdcall;
  Unicows_GetTabbedTextExtentW: function(hDC: HDC; lpString: PWideChar; nCount, nTabPositions: Integer; var lpnTabStopPositions): DWORD; stdcall;
  Unicows_GetTempFileNameW: function(lpPathName, lpPrefixString: PWideChar; uUnique: UINT; lpTempFileName: PWideChar): UINT; stdcall;
  Unicows_GetTempPathW: function(nBufferLength: DWORD; lpBuffer: PWideChar): DWORD; stdcall;
  Unicows_GetTextExtentExPointW: function(DC: HDC; p2: PWideChar; p3, p4: Integer; p5, p6: PInteger; var p7: TSize): BOOL; stdcall;
  Unicows_GetTextExtentPoint32W: function(DC: HDC; Str: PWideChar; Count: Integer; var Size: TSize): BOOL; stdcall;
  Unicows_GetTextExtentPointW: function(DC: HDC; Str: PWideChar; Count: Integer; var Size: TSize): BOOL; stdcall;
  Unicows_GetTextFaceW: function(DC: HDC; Count: Integer; Buffer: PWideChar): Integer; stdcall;
  Unicows_GetTextMetricsW: function(DC: HDC; var TM: TTextMetricW): BOOL; stdcall;
  Unicows_GetTimeFormatW: function(Locale: LCID; dwFlags: DWORD; lpTime: PSystemTime; lpFormat: PWideChar; lpTimeStr: PWideChar; cchTime: Integer): Integer; stdcall;
  Unicows_GetUserNameW: function(lpBuffer: PWideChar; var nSize: DWORD): BOOL; stdcall;
  Unicows_GetVersionExW: function(var lpVersionInformation: TOSVersionInfo): BOOL; stdcall;
  Unicows_GetVolumeInformationW: function(lpRootPathName: PWideChar; lpVolumeNameBuffer: PWideChar; nVolumeNameSize: DWORD; lpVolumeSerialNumber: PDWORD; var lpMaximumComponentLength, lpFileSystemFlags: DWORD; lpFileSystemNameBuffer: PWideChar; nFileSystemNameSize: DWORD): BOOL; stdcall;
  Unicows_GetWindowLongA: function(hWnd: HWND; nIndex: Integer): Longint; stdcall;
  Unicows_GetWindowLongW: function(hWnd: HWND; nIndex: Integer): Longint; stdcall;
  Unicows_GetWindowModuleFileNameW: function(hwnd: HWND; pszFileName: PWideChar; cchFileNameMax: UINT): UINT; stdcall;
  Unicows_GetWindowTextLengthW: function(hWnd: HWND): Integer; stdcall;
  Unicows_GetWindowTextW: function(hWnd: HWND; lpString: PWideChar; nMaxCount: Integer): Integer; stdcall;
  Unicows_GetWindowsDirectoryW: function(lpBuffer: PWideChar; uSize: UINT): UINT; stdcall;
  Unicows_GlobalAddAtomW: function(lpString: PWideChar): ATOM; stdcall;
  Unicows_GlobalFindAtomW: function(lpString: PWideChar): ATOM; stdcall;
  Unicows_GlobalGetAtomNameW: function(nAtom: ATOM; lpBuffer: PWideChar; nSize: Integer): UINT; stdcall;
  Unicows_GrayStringW: function(hDC: HDC; hBrush: HBRUSH; lpOutputFunc: TFNGrayStringProc; lpData: LPARAM; nCount, X, Y, nWidth, nHeight: Integer): BOOL; stdcall;
  Unicows_InitSecurityInterfaceW: TFarProc; // function: PSecurityFunctionTableW; stdcall;
  Unicows_InitializeSecurityContextW: TFarProc; // function(phCredential: PCredHandle; phContext: PCtxtHandle; pszTargetName: PSecWChar; fContextReq, Reserved1, TargetDataRep: Cardinal; pInput: PSecBufferDesc; Reserved2: Cardinal; phNewContext: PCtxtHandle; pOutput: PSecBufferDesc; var pfContextAttr: Cardinal; ptsExpiry: PTimeStamp): SECURITY_STATUS; stdcall;
  Unicows_InsertMenuItemW: function(p1: HMENU; p2: UINT; p3: BOOL; const p4: TMenuItemInfoW): BOOL; stdcall;
  Unicows_InsertMenuW: function(hMenu: HMENU; uPosition, uFlags, uIDNewItem: UINT; lpNewItem: PWideChar): BOOL; stdcall;
  Unicows_IsBadStringPtrW: function(lpsz: PWideChar; ucchMax: UINT): BOOL; stdcall;
  Unicows_IsCharAlphaNumericW: function(ch: WideChar): BOOL; stdcall;
  Unicows_IsCharAlphaW: function(ch: WideChar): BOOL; stdcall;
  Unicows_IsCharLowerW: function(ch: WideChar): BOOL; stdcall;
  Unicows_IsCharUpperW: function(ch: WideChar): BOOL; stdcall;
  Unicows_IsClipboardFormatAvailable: function(format: UINT): BOOL; stdcall;
  Unicows_IsDestinationReachableW: TFarProc; // function(lpszDestination: LPCWSTR; lpQOCInfo: LPQOCINFO): BOOL; stdcall;
  Unicows_IsDialogMessageW: function(hDlg: HWND; var lpMsg: TMsg): BOOL; stdcall;
  Unicows_IsTextUnicode: function(lpBuffer: Pointer; cb: Integer; lpi: PINT): BOOL; stdcall;
  Unicows_IsValidCodePage: function(CodePage: UINT): BOOL; stdcall;
  Unicows_IsWindowUnicode: function(hWnd: HWND): BOOL; stdcall;
  Unicows_LCMapStringW: function(Locale: LCID; dwMapFlags: DWORD; lpSrcStr: PWideChar; cchSrc: Integer; lpDestStr: PWideChar; cchDest: Integer): Integer; stdcall;
  Unicows_LoadAcceleratorsW: function(hInstance: HINST; lpTableName: PWideChar): HACCEL; stdcall;
  Unicows_LoadBitmapW: function(hInstance: HINST; lpBitmapName: PWideChar): HBITMAP; stdcall;
  Unicows_LoadCursorFromFileW: function(lpFileName: PWideChar): HCURSOR; stdcall;
  Unicows_LoadCursorW: function(hInstance: HINST; lpCursorName: PWideChar): HCURSOR; stdcall;
  Unicows_LoadIconW: function(hInstance: HINST; lpIconName: PWideChar): HICON; stdcall;
  Unicows_LoadImageW: function(hInst: HINST; ImageName: PWideChar; ImageType: UINT; X, Y: Integer; Flags: UINT): THandle; stdcall;
  Unicows_LoadKeyboardLayoutW: function(pwszKLID: PWideChar; Flags: UINT): HKL; stdcall;
  Unicows_LoadLibraryExW: function(lpLibFileName: PWideChar; hFile: THandle; dwFlags: DWORD): HMODULE; stdcall;
  Unicows_LoadLibraryW: function(lpLibFileName: PWideChar): HMODULE; stdcall;
  Unicows_LoadMenuIndirectW: function(lpMenuTemplate: Pointer): HMENU; stdcall;
  Unicows_LoadMenuW: function(hInstance: HINST; lpMenuName: PWideChar): HMENU; stdcall;
  Unicows_LoadStringW: function(hInstance: HINST; uID: UINT; lpBuffer: PWideChar; nBufferMax: Integer): Integer; stdcall;
  Unicows_MCIWndCreateW: function(hwndParent: HWnd; hInstance: HInst; dwStyle: DWord; szFile: PWideChar): HWnd; stdcall;
  Unicows_MapVirtualKeyExW: function(uCode, uMapType: UINT; dwhkl: HKL): UINT; stdcall;
  Unicows_MapVirtualKeyW: function(uCode, uMapType: UINT): UINT; stdcall;
  Unicows_MessageBoxExW: function(hWnd: HWND; lpText, lpCaption: PWideChar; uType: UINT; wLanguageId: Word): Integer; stdcall;
  Unicows_MessageBoxIndirectW: function(const MsgBoxParams: TMsgBoxParamsW): BOOL; stdcall;
  Unicows_MessageBoxW: function(hWnd: HWND; lpText, lpCaption: PWideChar; uType: UINT): Integer; stdcall;
  Unicows_ModifyMenuW: function(hMnu: HMENU; uPosition, uFlags, uIDNewItem: UINT; lpNewItem: PWideChar): BOOL; stdcall;
  Unicows_MoveFileW: function(lpExistingFileName, lpNewFileName: PWideChar): BOOL; stdcall;
  Unicows_MultiByteToWideChar: function(CodePage: UINT; dwFlags: DWORD; const lpMultiByteStr: LPCSTR; cchMultiByte: Integer; lpWideCharStr: LPWSTR; cchWideChar: Integer): Integer; stdcall;
  Unicows_MultinetGetConnectionPerformanceW: function(lpNetResource: PNetResourceW; lpNetConnectInfoStruc: PNetConnectInfoStruct): DWORD; stdcall;
  Unicows_OemToCharBuffW: function(lpszSrc: PWideChar; lpszDst: PWideChar; cchDstLength: DWORD): BOOL; stdcall;
  Unicows_OemToCharW: function(lpszSrc: PWideChar; lpszDst: PWideChar): BOOL; stdcall;
  Unicows_OleUIAddVerbMenuW: function(const lpOleObj: IOleObject; const lpszShortType: PWideChar; hMenu: HMenu; uPos, uIDVerbMin, uIDVerbMax: UInt; bAddConvert: Bool; idConvert: UInt; out lphMenu: HMenu): Bool; stdcall;
  Unicows_OleUIBusyW: TFarProc; // function(var Info: TOleUIBusyW): Integer; stdcall;
  Unicows_OleUIChangeIconW: TFarProc; // function(var Info: TOleUIChangeIconW): Integer; stdcall;
  Unicows_OleUIChangeSourceW: TFarProc; // function(var lpCS: TOleUIChangeSourceW): UInt; stdcall;
  Unicows_OleUIConvertW: TFarProc; // function(var Info: TOleUIConvertW): Integer; stdcall;
  Unicows_OleUIEditLinksW: TFarProc; // function(var Info: TOleUIEditLinksW): Integer; stdcall;
  Unicows_OleUIInsertObjectW: TFarProc; // function(var Info: TOleUIInsertObjectW): Integer; stdcall;
  Unicows_OleUIObjectPropertiesW: TFarProc; // function(var Info: TOleUIObjectPropsW): Integer; stdcall;
  Unicows_OleUIPasteSpecialW: TFarProc; // function(var Info: TOleUIPasteSpecialW): Integer; stdcall;
  Unicows_OleUIPromptUserW: function(nTemplate: Integer; hwndParent: HWnd): Integer; stdcall;
  Unicows_OleUIUpdateLinksW: function(const lpOleUILinkCntr: IOleUILinkContainer; hwndParent: HWnd; lpszTitle: PWideChar; cLinks: Integer): Bool; stdcall;
  Unicows_OpenEventW: function(dwDesiredAccess: DWORD; bInheritHandle: BOOL; lpName: PWideChar): THandle; stdcall;
  Unicows_OpenFileMappingW: function(dwDesiredAccess: DWORD; bInheritHandle: BOOL; lpName: PWideChar): THandle; stdcall;
  Unicows_OpenMutexW: function(dwDesiredAccess: DWORD; bInheritHandle: BOOL; lpName: PWideChar): THandle; stdcall;
  Unicows_OpenPrinterW: function(pPrinterName: PWideChar; var phPrinter: THandle; pDefault: PPrinterDefaultsW): BOOL; stdcall;
  Unicows_OpenSemaphoreW: function(dwDesiredAccess: DWORD; bInheritHandle: BOOL; lpName: PWideChar): THandle; stdcall;
  Unicows_OpenWaitableTimerW: function(dwDesiredAccess: DWORD; bInheritHandle: BOOL; lpTimerName: PWideChar): THandle; stdcall;
  Unicows_OutputDebugStringW: procedure(lpOutputString: PWideChar); stdcall;
  Unicows_PageSetupDlgW: function(var PgSetupDialog: TPageSetupDlgW): BOOL; stdcall;
  Unicows_PeekConsoleInputW: function(hConsoleInput: THandle; var lpBuffer: TInputRecord; nLength: DWORD; var lpNumberOfEventsRead: DWORD): BOOL; stdcall;
  Unicows_PeekMessageW: function(var lpMsg: TMsg; hWnd: HWND; wMsgFilterMin, wMsgFilterMax, wRemoveMsg: UINT): BOOL; stdcall;
  Unicows_PlaySoundW: function(pszSound: PWideChar; hmod: HMODULE; fdwSound: DWORD): BOOL; stdcall;
  Unicows_PolyTextOutW: function(DC: HDC; const PolyTextArray; Strings: Integer): BOOL; stdcall;
  Unicows_PostMessageW: function(hWnd: HWND; Msg: UINT; wParam: WPARAM; lParam: LPARAM): BOOL; stdcall;
  Unicows_PostThreadMessageW: function(idThread: DWORD; Msg: UINT; wParam: WPARAM; lParam: LPARAM): BOOL; stdcall;
  Unicows_PrintDlgW: function(var PrintDlg: TPrintDlgW): Bool; stdcall;
  Unicows_QueryContextAttributesW: TFarProc; // function(phContext: PCtxtHandle; ulAttribute: Cardinal; pBuffer: Pointer): SECURITY_STATUS; stdcall;
  Unicows_QueryCredentialsAttributesW: TFarProc; // function(phCredential: PCredHandle; ulAttribute: Cardinal; pBuffer: Pointer): SECURITY_STATUS; stdcall;
  Unicows_QueryDosDeviceW: function(lpDeviceName: PWideChar; lpTargetPath: PWideChar; ucchMax: DWORD): DWORD; stdcall;
  Unicows_QuerySecurityPackageInfoW: TFarProc; // function(pszPackageName: PSecWChar; var ppPackageInfo: PSecPkgInfoW): SECURITY_STATUS; stdcall;
  Unicows_RasConnectionNotificationW: TFarProc; // function(hRasConn: HRasConn; hEvent: THandle; dwFlags: DWord): DWord; stdcall;
  Unicows_RasCreatePhonebookEntryW: function(hwnd: HWnd; const lpszPhonebook: PWideChar): DWord; stdcall;
  Unicows_RasDeleteEntryW: function(const lpszPhonebook, lpszEntry: PWideChar): DWord; stdcall;
  Unicows_RasDeleteSubEntryW: function(const lpszPhonebook, lpszEntry: PWideChar; dwSubEntryId: DWord): DWord; stdcall;
  Unicows_RasDialW: TFarProc; // function(lpRasDialExtensions: PRasDialExtensions; const lpszPhonebook: PWideChar; lpRasDialParams: PRasDialParams; dwNotifierType: DWord; lpvNotifier: Pointer; out lphRasConn: HRasConn): DWord; stdcall;
  Unicows_RasEditPhonebookEntryW: function(hwnd: HWnd; const lpszPhonebook, lpszEntry: PWideChar): DWord; stdcall;
  Unicows_RasEnumConnectionsW: TFarProc; // function(lpRasConn: PRasConnW; lpcb, lpcConnections: PDWord): DWord; stdcall;
  Unicows_RasEnumDevicesW: TFarProc; // function(lpRasDevInfo: PRasDevInfoW; lpcb, lpcDevices: PDWord): DWord; stdcall;
  Unicows_RasEnumEntriesW: TFarProc; // function(const reserved, lpszPhonebook: PWideChar; lpRasEntryName: PRasEntryNameW; lpcb, lpcEntries: PDWord): DWord; stdcall;
  Unicows_RasGetConnectStatusW: TFarProc; // function(hRasConn: HRasConn; lpRasConnStatus: PRasConnStatusW): DWord; stdcall;
  Unicows_RasGetEntryDialParamsW: TFarProc; // function(const lpszPhonebook: PWideChar; lpRasDialParams: PRasDialParamsW; out lpfPassword: Bool): DWord; stdcall;
  Unicows_RasGetEntryPropertiesW: TFarProc; // function(const lpszPhonebook, lpszEntry: PWideChar; lpRasEntry: PRasEntryW; lpdwEntryInfoSize: PDWord; lpbDeviceInfo: PByte; lpdwDeviceInfoSize: PDWord): DWord; stdcall;
  Unicows_RasGetErrorStringW: function(uErrorValue: UInt; lpszErrorString: PWideChar; cBufSize: DWord): DWord; stdcall;
  Unicows_RasGetProjectionInfoW: TFarProc; // function(hRasConn: HRasConn; RasProjection: TRasProjection; lpProjection: Pointer; lpcb: PDWord): DWord; stdcall;
  Unicows_RasHangUpW: TFarProc; // function(hRasConn: HRasConn): DWord; stdcall;
  Unicows_RasRenameEntryW: function(const lpszPhonebook, lpszOldEntry, lpszNewEntry: PWideChar): DWord; stdcall;
  Unicows_RasSetEntryDialParamsW: TFarProc; // function(const lpszPhonebook: PWideChar; lpRasDialParams: PRasDialParamsW; fRemovePassword: Bool): DWord; stdcall;
  Unicows_RasSetEntryPropertiesW: TFarProc; // function(const lpszPhonebook, lpszEntry: PWideChar; lpRasEntry: PRasEntryW; dwEntryInfoSize: DWord; lpbDeviceInfo: PByte; dwDeviceInfoSize: DWord): DWord; stdcall;
  Unicows_RasSetSubEntryPropertiesW: TFarProc; // function(const lpszPhonebook, lpszEntry: PWideChar; dwSubEntry: DWord; lpRasSubEntry: PRasSubEntryW; dwcbRasSubEntry: DWord; lpbDeviceConfig: PByte; dwcbDeviceConfig: DWord): DWord; stdcall;
  Unicows_RasValidateEntryNameW: function(const lpszPhonebook, lpszEntry: PWideChar): DWord; stdcall;
  Unicows_ReadConsoleInputW: function(hConsoleInput: THandle; var lpBuffer: TInputRecord; nLength: DWORD; var lpNumberOfEventsRead: DWORD): BOOL; stdcall;
  Unicows_ReadConsoleOutputCharacterW: function(hConsoleOutput: THandle; lpCharacter: PWideChar; nLength: DWORD; dwReadCoord: TCoord; var lpNumberOfCharsRead: DWORD): BOOL; stdcall;
  Unicows_ReadConsoleOutputW: function(hConsoleOutput: THandle; lpBuffer: Pointer; dwBufferSize, dwBufferCoord: TCoord; var lpReadRegion: TSmallRect): BOOL; stdcall;
  Unicows_ReadConsoleW: function(hConsoleInput: THandle; lpBuffer: Pointer; nNumberOfCharsToRead: DWORD; var lpNumberOfCharsRead: DWORD; lpReserved: Pointer): BOOL; stdcall;
  Unicows_RegConnectRegistryW: function(lpMachineName: PWideChar; hKey: HKEY; var phkResult: HKEY): Longint; stdcall;
  Unicows_RegCreateKeyExW: function(hKey: HKEY; lpSubKey: PWideChar; Reserved: DWORD; lpClass: PWideChar; dwOptions: DWORD; samDesired: REGSAM; lpSecurityAttributes: PSecurityAttributes; var phkResult: HKEY; lpdwDisposition: PDWORD): Longint; stdcall;
  Unicows_RegCreateKeyW: function(hKey: HKEY; lpSubKey: PWideChar; var phkResult: HKEY): Longint; stdcall;
  Unicows_RegDeleteKeyW: function(hKey: HKEY; lpSubKey: PWideChar): Longint; stdcall;
  Unicows_RegDeleteValueW: function(hKey: HKEY; lpValueName: PWideChar): Longint; stdcall;
  Unicows_RegEnumKeyExW: function(hKey: HKEY; dwIndex: DWORD; lpName: PWideChar; var lpcbName: DWORD; lpReserved: Pointer; lpClass: PWideChar; lpcbClass: PDWORD; lpftLastWriteTime: PFileTime): Longint; stdcall;
  Unicows_RegEnumKeyW: function(hKey: HKEY; dwIndex: DWORD; lpName: PWideChar; cbName: DWORD): Longint; stdcall;
  Unicows_RegEnumValueW: function(hKey: HKEY; dwIndex: DWORD; lpValueName: PWideChar; var lpcbValueName: DWORD; lpReserved: Pointer; lpType: PDWORD; lpData: PByte; lpcbData: PDWORD): Longint; stdcall;
  Unicows_RegLoadKeyW: function(hKey: HKEY; lpSubKey, lpFile: PWideChar): Longint; stdcall;
  Unicows_RegOpenKeyExW: function(hKey: HKEY; lpSubKey: PWideChar; ulOptions: DWORD; samDesired: REGSAM; var phkResult: HKEY): Longint; stdcall;
  Unicows_RegOpenKeyW: function(hKey: HKEY; lpSubKey: PWideChar; var phkResult: HKEY): Longint; stdcall;
  Unicows_RegQueryInfoKeyW: function(hKey: HKEY; lpClass: PWideChar; lpcbClass: PDWORD; lpReserved: Pointer; lpcSubKeys, lpcbMaxSubKeyLen, lpcbMaxClassLen, lpcValues, lpcbMaxValueNameLen, lpcbMaxValueLen, lpcbSecurityDescriptor: PDWORD; lpftLastWriteTime: PFileTime): Longint; stdcall;
  Unicows_RegQueryMultipleValuesW: function(hKey: HKEY; var ValList; NumVals: DWORD; lpValueBuf: PWideChar; var ldwTotsize: DWORD): Longint; stdcall;
  Unicows_RegQueryValueExW: function(hKey: HKEY; lpValueName: PWideChar; lpReserved: Pointer; lpType: PDWORD; lpData: PByte; lpcbData: PDWORD): Longint; stdcall;
  Unicows_RegQueryValueW: function(hKey: HKEY; lpSubKey: PWideChar; lpValue: PWideChar; var lpcbValue: Longint): Longint; stdcall;
  Unicows_RegReplaceKeyW: function(hKey: HKEY; lpSubKey: PWideChar; lpNewFile: PWideChar; lpOldFile: PWideChar): Longint; stdcall;
  Unicows_RegSaveKeyW: function(hKey: HKEY; lpFile: PWideChar; lpSecurityAttributes: PSecurityAttributes): Longint; stdcall;
  Unicows_RegSetValueExW: function(hKey: HKEY; lpValueName: PWideChar; Reserved: DWORD; dwType: DWORD; lpData: Pointer; cbData: DWORD): Longint; stdcall;
  Unicows_RegSetValueW: function(hKey: HKEY; lpSubKey: PWideChar; dwType: DWORD; lpData: PWideChar; cbData: DWORD): Longint; stdcall;
  Unicows_RegUnLoadKeyW: function(hKey: HKEY; lpSubKey: PWideChar): Longint; stdcall;
  Unicows_RegisterClassExW: function(const WndClass: TWndClassExW): ATOM; stdcall;
  Unicows_RegisterClassW: function(const lpWndClass: TWndClassW): ATOM; stdcall;
  Unicows_RegisterClipboardFormatW: function(lpszFormat: PWideChar): UINT; stdcall;
  Unicows_RegisterDeviceNotificationW: function(hRecipient: THandle; NotificationFilter: Pointer; Flags: DWORD): HDEVNOTIFY; stdcall;
  Unicows_RegisterWindowMessageW: function(lpString: PWideChar): UINT; stdcall;
  Unicows_RemoveDirectoryW: function(lpPathName: PWideChar): BOOL; stdcall;
  Unicows_RemoveFontResourceW: function(FileName: PWideChar): BOOL; stdcall;
  Unicows_RemovePropA: function(hWnd: HWND; lpString: PAnsiChar): THandle; stdcall;
  Unicows_RemovePropW: function(hWnd: HWND; lpString: PWideChar): THandle; stdcall;
  Unicows_ReplaceTextW: function(var FindReplace: TFindReplaceW): HWND; stdcall;
  Unicows_ResetDCW: function(DC: HDC; const InitData: TDeviceModeW): HDC; stdcall;
  Unicows_ResetPrinterW: function(hPrinter: THandle; pDefault: PPrinterDefaultsW): BOOL; stdcall;
  Unicows_SHBrowseForFolderW: function(var lpbi: TBrowseInfoW): PItemIDList; stdcall;
  Unicows_SHChangeNotify: procedure(wEventId: Longint; uFlags: UINT; dwItem1, dwItem2: Pointer); stdcall;
  Unicows_SHFileOperationW: function(const lpFileOp: TSHFileOpStructW): Integer; stdcall;
  Unicows_SHGetFileInfoW: function(pszPath: PAnsiChar; dwFileAttributes: DWORD; var psfi: TSHFileInfoW; cbFileInfo, uFlags: UINT): DWORD; stdcall;
  Unicows_SHGetNewLinkInfoW: function(const pszLinkTo, pszDir: PWideChar; pszName: PWideChar; out pfMustCopy: Bool; uFlags: UInt): Bool; stdcall;
  Unicows_SHGetPathFromIDListW: function(pidl: PItemIDList; pszPath: PWideChar): BOOL; stdcall;
  Unicows_ScrollConsoleScreenBufferW: function(hConsoleOutput: THandle; const lpScrollRectangle: TSmallRect; lpClipRectangle: PSmallRect; dwDestinationOrigin: TCoord; var lpFill: TCharInfo): BOOL; stdcall;
  Unicows_SearchPathW: function(lpPath, lpFileName, lpExtension: PWideChar; nBufferLength: DWORD; lpBuffer: PWideChar; var lpFilePart: PWideChar): DWORD; stdcall;
  Unicows_SendDlgItemMessageW: function(hDlg: HWND; nIDDlgItem: Integer; Msg: UINT; wParam: WPARAM; lParam: LPARAM): Longint; stdcall;
  Unicows_SendMessageCallbackW: function(hWnd: HWND; Msg: UINT; wParam: WPARAM; lParam: LPARAM; lpResultCallBack: TFNSendAsyncProc; dwData: DWORD): BOOL; stdcall;
  Unicows_SendMessageTimeoutW: function(hWnd: HWND; Msg: UINT; wParam: WPARAM; lParam: LPARAM; fuFlags, uTimeout: UINT; var lpdwResult: DWORD): LRESULT; stdcall;
  Unicows_SendMessageW: function(hWnd: HWND; Msg: UINT; wParam: WPARAM; lParam: LPARAM): LRESULT; stdcall;
  Unicows_SendNotifyMessageW: function(hWnd: HWND; Msg: UINT; wParam: WPARAM; lParam: LPARAM): BOOL; stdcall;
  Unicows_SetCalendarInfoW: function(Locale: LCID; Calendar: CALID; CalType: CALTYPE; lpCalData: LPCWSTR): BOOL; stdcall;
  Unicows_SetClassLongW: function(hWnd: HWND; nIndex: Integer; dwNewLong: Longint): DWORD; stdcall;
  Unicows_SetComputerNameW: function(lpComputerName: PWideChar): BOOL; stdcall;
  Unicows_SetConsoleTitleW: function(lpConsoleTitle: PWideChar): BOOL; stdcall;
  Unicows_SetCurrentDirectoryW: function(lpPathName: PWideChar): BOOL; stdcall;
  Unicows_SetDefaultCommConfigW: function(lpszName: PWideChar; lpCC: PCommConfig; dwSize: DWORD): BOOL; stdcall;
  Unicows_SetDlgItemTextW: function(hDlg: HWND; nIDDlgItem: Integer; lpString: PWideChar): BOOL; stdcall;
  Unicows_SetEnvironmentVariableW: function(lpName, lpValue: PWideChar): BOOL; stdcall;
  Unicows_SetFileAttributesW: function(lpFileName: PWideChar; dwFileAttributes: DWORD): BOOL; stdcall;
  Unicows_SetICMProfileW: function(DC: HDC; Name: PWideChar): BOOL; stdcall;
  Unicows_SetJobW: function(hPrinter: THandle; JobId: DWORD; Level: DWORD; pJob: Pointer; Command: DWORD): BOOL; stdcall;
  Unicows_SetLocaleInfoW: function(Locale: LCID; LCType: LCTYPE; lpLCData: PWideChar): BOOL; stdcall;
  Unicows_SetMenuItemInfoW: function(p1: HMENU; p2: UINT; p3: BOOL; const p4: TMenuItemInfoW): BOOL; stdcall;
  Unicows_SetPrinterDataW: function(hPrinter: THandle; pValueName: PWideChar; dwType: DWORD; pData: Pointer; cbData: DWORD): DWORD; stdcall;
  Unicows_SetPrinterW: function(hPrinter: THandle; Level: DWORD; pPrinter: Pointer; Command: DWORD): BOOL; stdcall;
  Unicows_SetPropA: function(hWnd: HWND; lpString: PAnsiChar; hData: THandle): BOOL; stdcall;
  Unicows_SetPropW: function(hWnd: HWND; lpString: PWideChar; hData: THandle): BOOL; stdcall;
  Unicows_SetVolumeLabelW: function(lpRootPathName: PWideChar; lpVolumeName: PAnsiChar): BOOL; stdcall;
  Unicows_SetWindowLongA: function(hWnd: HWND; nIndex: Integer; dwNewLong: Longint): Longint; stdcall;
  Unicows_SetWindowLongW: function(hWnd: HWND; nIndex: Integer; dwNewLong: Longint): Longint; stdcall;
  Unicows_SetWindowTextW: function(hWnd: HWND; lpString: PWideChar): BOOL; stdcall;
  Unicows_SetWindowsHookExW: function(idHook: Integer; lpfn: TFNHookProc; hmod: HINST; dwThreadId: DWORD): HHOOK; stdcall;
  Unicows_SetWindowsHookW: function(nFilterType: Integer; pfnFilterProc: TFNHookProc): HHOOK; stdcall;
  Unicows_ShellAboutW: function(Wnd: HWND; szApp, szOtherStuff: PWideChar; Icon: HICON): Integer; stdcall;
  Unicows_ShellExecuteExW: function(lpExecInfo: PShellExecuteInfoW):BOOL; stdcall;
  Unicows_ShellExecuteW: function(hWnd: HWND; Operation, FileName, Parameters, Directory: PWideChar; ShowCmd: Integer): HINST; stdcall;
  Unicows_Shell_NotifyIconW: function(dwMessage: DWORD; lpData: PNotifyIconDataW): BOOL; stdcall;
  Unicows_StartDocPrinterW: function(hPrinter: THandle; Level: DWORD; pDocInfo: Pointer): DWORD; stdcall;
  Unicows_StartDocW: function(DC: HDC; const p2: TDocInfoW): Integer; stdcall;
  Unicows_SystemParametersInfoW: function(uiAction, uiParam: UINT; pvParam: Pointer; fWinIni: UINT): BOOL; stdcall;
  Unicows_TabbedTextOutW: function(hDC: HDC; X, Y: Integer; lpString: PWideChar; nCount, nTabPositions: Integer; var lpnTabStopPositions; nTabOrigin: Integer): Longint; stdcall;
  Unicows_TextOutW: function(DC: HDC; X, Y: Integer; Str: PWideChar; Count: Integer): BOOL; stdcall;
  Unicows_TranslateAcceleratorW: function(hWnd: HWND; hAccTable: HACCEL; var lpMsg: TMsg): Integer; stdcall;
  Unicows_UnregisterClassW: function(lpClassName: PWideChar; hInstance: HINST): BOOL; stdcall;
  Unicows_UpdateICMRegKeyW: function(p1: DWORD; p2, p3: PWideChar; p4: UINT): BOOL; stdcall;
  Unicows_UpdateResourceA: function(hUpdate: THandle; lpType, lpName: PAnsiChar; wLanguage: Word; lpData: Pointer; cbData: DWORD): BOOL; stdcall;
  Unicows_UpdateResourceW: function(hUpdate: THandle; lpType, lpName: PWideChar; wLanguage: Word; lpData: Pointer; cbData: DWORD): BOOL; stdcall;
  Unicows_VerFindFileW: function(uFlags: DWORD; szFileName, szWinDir, szAppDir, szCurDir: PWideChar; var lpuCurDirLen: UINT; szDestDir: PWideChar; var lpuDestDirLen: UINT): DWORD; stdcall;
  Unicows_VerInstallFileW: function(uFlags: DWORD; szSrcFileName, szDestFileName, szSrcDir, szDestDir, szCurDir, szTmpFile: PWideChar; var lpuTmpFileLen: UINT): DWORD; stdcall;
  Unicows_VerLanguageNameW: function(wLang: DWORD; szLang: PWideChar; nSize: DWORD): DWORD; stdcall;
  Unicows_VerQueryValueW: function(pBlock: Pointer; lpSubBlock: PWideChar; var lplpBuffer: Pointer; var puLen: UINT): BOOL; stdcall;
  Unicows_VkKeyScanExW: function(ch: WideChar; dwhkl: HKL): SHORT; stdcall;
  Unicows_VkKeyScanW: function(ch: WideChar): SHORT; stdcall;
  Unicows_WNetAddConnection2W: function(var lpNetResource: TNetResourceW; lpPassword, lpUserName: PWideChar; dwFlags: DWORD): DWORD; stdcall;
  Unicows_WNetAddConnection3W: function(hwndOwner: HWND; var lpNetResource: TNetResourceW; lpPassword, lpUserName: PWideChar; dwFlags: DWORD): DWORD; stdcall;
  Unicows_WNetAddConnectionW: function(lpRemoteName, lpPassword, lpLocalName: PWideChar): DWORD; stdcall;
  Unicows_WNetCancelConnection2W: function(lpName: PWideChar; dwFlags: DWORD; fForce: BOOL): DWORD; stdcall;
  Unicows_WNetCancelConnectionW: function(lpName: PWideChar; fForce: BOOL): DWORD; stdcall;
  Unicows_WNetConnectionDialog1W: function(var lpConnDlgStruct: TConnectDlgStruct): DWORD; stdcall;
  Unicows_WNetDisconnectDialog1W: function(var lpConnDlgStruct: TDiscDlgStructW): DWORD; stdcall;
  Unicows_WNetEnumResourceW: function(hEnum: THandle; var lpcCount: DWORD; lpBuffer: Pointer; var lpBufferSize: DWORD): DWORD; stdcall;
  Unicows_WNetGetConnectionW: function(lpLocalName: PWideChar; lpRemoteName: PWideChar; var lpnLength: DWORD): DWORD; stdcall;
  Unicows_WNetGetLastErrorW: function(var lpError: DWORD; lpErrorBuf: PWideChar; nErrorBufSize: DWORD; lpNameBuf: PWideChar; nNameBufSize: DWORD): DWORD; stdcall;
  Unicows_WNetGetNetworkInformationW: function(lpProvider: PWideChar; var lpNetInfoStruct: TNetInfoStruct): DWORD; stdcall;
  Unicows_WNetGetProviderNameW: function(dwNetType: DWORD; lpProviderName: PWideChar; var lpBufferSize: DWORD): DWORD; stdcall;
  Unicows_WNetGetResourceInformationW: function(const lpNetResource: NETRESOURCEW; lpBuffer: Pointer; var lpcbBuffer: DWORD; var lplpSystem: LPWSTR): DWORD; stdcall;
  Unicows_WNetGetResourceParentW: function(lpNetResource: PNetResourceW; lpBuffer: Pointer; var cbBuffer: DWORD): DWORD; stdcall;
  Unicows_WNetGetUniversalNameW: function(lpLocalPath: PWideChar; dwInfoLevel: DWORD; lpBuffer: Pointer; var lpBufferSize: DWORD): DWORD; stdcall;
  Unicows_WNetGetUserW: function(lpName: PWideChar; lpUserName: PWideChar; var lpnLength: DWORD): DWORD; stdcall;
  Unicows_WNetOpenEnumW: function(dwScope, dwType, dwUsage: DWORD; lpNetResource: PNetResourceW; var lphEnum: THandle): DWORD; stdcall;
  Unicows_WNetUseConnectionW: function(hwndOwner: HWND; var lpNetResource: TNetResourceW; lpUserID: PWideChar; lpPassword: PWideChar; dwFlags: DWORD; lpAccessName: PWideChar; var lpBufferSize: DWORD; var lpResult: DWORD): DWORD; stdcall;
  Unicows_WaitNamedPipeW: function(lpNamedPipeName: PWideChar; nTimeOut: DWORD): BOOL; stdcall;
  Unicows_WideCharToMultiByte: function(CodePage: UINT; dwFlags: DWORD; lpWideCharStr: LPWSTR; cchWideChar: Integer; lpMultiByteStr: LPSTR; cchMultiByte: Integer; lpDefaultChar: LPCSTR; lpUsedDefaultChar: PBOOL): Integer; stdcall;
  Unicows_WinHelpW: function(hWndMain: HWND; lpszHelp: PWideChar; uCommand: UINT; dwData: DWORD): BOOL; stdcall;
  Unicows_WriteConsoleInputW: function(hConsoleInput: THandle; const lpBuffer: TInputRecord; nLength: DWORD; var lpNumberOfEventsWritten: DWORD): BOOL; stdcall;
  Unicows_WriteConsoleOutputCharacterW: function(hConsoleOutput: THandle;lpCharacter: PWideChar; nLength: DWORD; dwWriteCoord: TCoord; var lpNumberOfCharsWritten: DWORD): BOOL; stdcall;
  Unicows_WriteConsoleOutputW: function(hConsoleOutput: THandle; lpBuffer: Pointer; dwBufferSize, dwBufferCoord: TCoord; var lpWriteRegion: TSmallRect): BOOL; stdcall;
  Unicows_WriteConsoleW: function(hConsoleOutput: THandle; const lpBuffer: Pointer; nNumberOfCharsToWrite: DWORD; var lpNumberOfCharsWritten: DWORD; lpReserved: Pointer): BOOL; stdcall;
  Unicows_WritePrivateProfileSectionW: function(lpAppName, lpString, lpFileName: PWideChar): BOOL; stdcall;
  Unicows_WritePrivateProfileStringW: function(lpAppName, lpKeyName, lpString, lpFileName: PWideChar): BOOL; stdcall;
  Unicows_WritePrivateProfileStructW: function(lpszSection, lpszKey: PWideChar; lpStruct: Pointer; uSizeStruct: UINT; szFile: PWideChar): BOOL; stdcall;
  Unicows_WriteProfileSectionW: function(lpAppName, lpString: PWideChar): BOOL; stdcall;
  Unicows_WriteProfileStringW: function(lpAppName, lpKeyName, lpString: PWideChar): BOOL; stdcall;
  Unicows_auxGetDevCapsW: function(uDeviceID: UINT; lpCaps: PAuxCapsW; uSize: UINT): MMRESULT; stdcall;
  Unicows_capCreateCaptureWindowW: function(const lpszWindowName: PWideChar; dwStyle: DWord; x, y, nWidth, nHeight: Integer; hWnd: HWnd; nID: Integer): HWnd; stdcall;
  Unicows_capGetDriverDescriptionW: function(wDriverIndex: Word; lpszName: PWideChar; cbName: Integer; lpszVer: PWideChar; cbVer: Integer): Bool; stdcall;
  Unicows_joyGetDevCapsW: function(uJoyID: UINT; lpCaps: PJoyCapsW; uSize: UINT): MMRESULT; stdcall;
  Unicows_lstrcatW: function(lpString1, lpString2: PWideChar): PWideChar; stdcall;
  Unicows_lstrcmpW: function(lpString1, lpString2: PWideChar): Integer; stdcall;
  Unicows_lstrcmpiW: function(lpString1, lpString2: PWideChar): Integer; stdcall;
  Unicows_lstrcpyW: function(lpString1, lpString2: PWideChar): PWideChar; stdcall;
  Unicows_lstrcpynW: function(lpString1, lpString2: PWideChar; iMaxLength: Integer): PWideChar; stdcall;
  Unicows_lstrlenW: function(lpString: PWideChar): Integer; stdcall;
  Unicows_mciGetDeviceIDW: function(pszDevice: PWideChar): MCIDEVICEID; stdcall;
  Unicows_mciGetErrorStringW: function(mcierr: MCIERROR; pszText: PWideChar; uLength: UINT): BOOL; stdcall;
  Unicows_mciSendCommandW: function(mciId: MCIDEVICEID; uMessage: UINT; dwParam1, dwParam2: DWORD): MCIERROR; stdcall;
  Unicows_mciSendStringW: function(lpstrCommand, lpstrReturnString: PWideChar; uReturnLength: UINT; hWndCallback: HWND): MCIERROR; stdcall;
  Unicows_midiInGetDevCapsW: function(DeviceID: UINT; lpCaps: PMidiInCapsW; uSize: UINT): MMRESULT; stdcall;
  Unicows_midiInGetErrorTextW: function(mmrError: MMRESULT; pszText: PWideChar; uSize: UINT): MMRESULT; stdcall;
  Unicows_midiOutGetDevCapsW: function(uDeviceID: UINT; lpCaps: PMidiOutCapsW; uSize: UINT): MMRESULT; stdcall;
  Unicows_midiOutGetErrorTextW: function(mmrError: MMRESULT; pszText: PWideChar; uSize: UINT): MMRESULT; stdcall;
  Unicows_mixerGetControlDetailsW: function(hmxobj: HMIXEROBJ; pmxcd: PMixerControlDetails; fdwDetails: DWORD): MMRESULT; stdcall;
  Unicows_mixerGetDevCapsW: function(uMxId: UINT; pmxcaps: PMixerCapsW; cbmxcaps: UINT): MMRESULT; stdcall;
  Unicows_mixerGetLineControlsW: function(hmxobj: HMIXEROBJ; pmxlc: PMixerLineControlsW; fdwControls: DWORD): MMRESULT; stdcall;
  Unicows_mixerGetLineInfoW: function(hmxobj: HMIXEROBJ; pmxl: PMixerLineW; fdwInfo: DWORD): MMRESULT; stdcall;
  Unicows_mmioInstallIOProcW: function(fccIOProc: FOURCC; pIOProc: TFNMMIOProc; dwFlags: DWORD): TFNMMIOProc; stdcall;
  Unicows_mmioOpenW: function(szFileName: PChar; lpmmioinfo: PMMIOInfo; dwOpenFlags: DWORD): HMMIO; stdcall;
  Unicows_mmioRenameW: function(szFileName, szNewFileName: PWideChar; lpmmioinfo: PMMIOInfo; dwRenameFlags: DWORD): MMRESULT; stdcall;
  Unicows_mmioStringToFOURCCW: function(sz: PWideChar; uFlags: UINT): FOURCC; stdcall;
  Unicows_sndPlaySoundW: function(lpszSoundName: PWideChar; uFlags: UINT): BOOL; stdcall;
  Unicows_waveInGetDevCapsW: function(hwo: HWAVEOUT; lpCaps: PWaveInCapsW; uSize: UINT): MMRESULT; stdcall;
  Unicows_waveInGetErrorTextW: function(mmrError: MMRESULT; lpText: PWideChar; uSize: UINT): MMRESULT; stdcall;
  Unicows_waveOutGetDevCapsW: function(uDeviceID: UINT; lpCaps: PWaveOutCapsW; uSize: UINT): MMRESULT; stdcall;
  Unicows_waveOutGetErrorTextW: function(mmrError: MMRESULT; lpText: PWideChar; uSize: UINT): MMRESULT; stdcall;
  Unicows_wsprintfW: TFarProc; // function(Output: PWideChar; Format: PWideChar): Integer; cdecl; varargs;
  Unicows_wvsprintfW: function(Output: PWideChar; Format: PWideChar; arglist: va_list): Integer; stdcall;
{$ENDREGION}

const
  unicows = 'unicows.dll';

implementation

uses
  JclPeImage;

type
  PFarProc = ^TFarProc;

  // This type is an enumeration of all MSLU-supported functions. This unit uses
  // the type to index into the MSLUData array below. GetProcAddress appears at
  // the end, instead of in its alphabetical spot, because the API-hooking code
  // calls GetProcAddress, and we don't want to hook the API too early. If we
  // do, then LoadUnicows winds up getting called within this unit's
  // initialization, and so there would be no time to provide a replacement
  // DLL-loading function in _PfnLoadUnicows. (Once Unicows.dll is loaded, any
  // value in that variable is ignored.)
  {$REGION 'TMSLUFunction'}
  TMSLUFunction = (
    fnAcquireCredentialsHandleW,
    fnAddAtomW,
    fnAddFontResourceW,
    fnAddJobW,
    fnAddMonitorW,
    fnAddPortW,
    fnAddPrintProcessorW,
    fnAddPrintProvidorW,
    fnAddPrinterDriverW,
    fnAddPrinterW,
    fnAdvancedDocumentPropertiesW,
    fnAppendMenuW,
    fnBeginUpdateResourceA,
    fnBeginUpdateResourceW,
    fnBroadcastSystemMessageW,
    fnBuildCommDCBAndTimeoutsW,
    fnBuildCommDCBW,
    fnCallMsgFilterW,
    fnCallNamedPipeW,
    fnCallWindowProcA,
    fnCallWindowProcW,
    fnChangeDisplaySettingsExW,
    fnChangeDisplaySettingsW,
    fnChangeMenuW,
    fnCharLowerBuffW,
    fnCharLowerW,
    fnCharNextW,
    fnCharPrevW,
    fnCharToOemBuffW,
    fnCharToOemW,
    fnCharUpperBuffW,
    fnCharUpperW,
    fnChooseColorW,
    fnChooseFontW,
    fnCommConfigDialogW,
    fnCompareStringW,
    fnConfigurePortW,
    fnCopyAcceleratorTableW,
    fnCopyEnhMetaFileW,
    fnCopyFileExW,
    fnCopyFileW,
    fnCopyMetaFileW,
    fnCreateAcceleratorTableW,
    fnCreateColorSpaceW,
    fnCreateDCW,
    fnCreateDialogIndirectParamW,
    fnCreateDialogParamW,
    fnCreateDirectoryExW,
    fnCreateDirectoryW,
    fnCreateEnhMetaFileW,
    fnCreateEventW,
    fnCreateFileMappingW,
    fnCreateFileW,
    fnCreateFontIndirectW,
    fnCreateFontW,
    fnCreateICW,
    fnCreateMDIWindowW,
    fnCreateMailslotW,
    fnCreateMetaFileW,
    fnCreateMutexW,
    fnCreateNamedPipeW,
    fnCreateProcessW,
    fnCreateScalableFontResourceW,
    fnCreateSemaphoreW,
    fnCreateStdAccessibleProxyW,
    fnCreateWaitableTimerW,
    fnCreateWindowExW,
    fnCryptAcquireContextW,
    fnCryptEnumProviderTypesW,
    fnCryptEnumProvidersW,
    fnCryptGetDefaultProviderW,
    fnCryptSetProviderExW,
    fnCryptSetProviderW,
    fnCryptSignHashW,
    fnCryptVerifySignatureW,
    fnDdeConnect,
    fnDdeConnectList,
    fnDdeCreateStringHandleW,
    fnDdeInitializeW,
    fnDdeQueryConvInfo,
    fnDdeQueryStringW,
    fnDefDlgProcW,
    fnDefFrameProcW,
    fnDefMDIChildProcW,
    fnDefWindowProcW,
    fnDeleteFileW,
    fnDeleteMonitorW,
    fnDeletePortW,
    fnDeletePrintProcessorW,
    fnDeletePrintProvidorW,
    fnDeletePrinterDriverW,
    fnDeviceCapabilitiesW,
    fnDialogBoxIndirectParamW,
    fnDialogBoxParamW,
    fnDispatchMessageW,
    fnDlgDirListComboBoxW,
    fnDlgDirListW,
    fnDlgDirSelectComboBoxExW,
    fnDlgDirSelectExW,
    fnDocumentPropertiesW,
    fnDragQueryFileW,
    fnDrawStateW,
    fnDrawTextExW,
    fnDrawTextW,
    fnEnableWindow,
    fnEndUpdateResourceA,
    fnEndUpdateResourceW,
    fnEnumCalendarInfoExW,
    fnEnumCalendarInfoW,
    fnEnumClipboardFormats,
    fnEnumDateFormatsExW,
    fnEnumDateFormatsW,
    fnEnumDisplayDevicesW,
    fnEnumDisplaySettingsExW,
    fnEnumDisplaySettingsW,
    fnEnumFontFamiliesExW,
    fnEnumFontFamiliesW,
    fnEnumFontsW,
    fnEnumICMProfilesW,
    fnEnumMonitorsW,
    fnEnumPortsW,
    fnEnumPrintProcessorDatatypesW,
    fnEnumPrintProcessorsW,
    fnEnumPrinterDriversW,
    fnEnumPrintersW,
    fnEnumPropsA,
    fnEnumPropsExA,
    fnEnumPropsExW,
    fnEnumPropsW,
    fnEnumSystemCodePagesW,
    fnEnumSystemLocalesW,
    fnEnumTimeFormatsW,
    fnEnumerateSecurityPackagesW,
    fnExpandEnvironmentStringsW,
    fnExtTextOutW,
    fnExtractIconExW,
    fnExtractIconW,
    fnFatalAppExitW,
    fnFillConsoleOutputCharacterW,
    fnFindAtomW,
    fnFindExecutableW,
    fnFindFirstChangeNotificationW,
    fnFindFirstFileW,
    fnFindNextFileW,
    fnFindResourceExW,
    fnFindResourceW,
    fnFindTextW,
    fnFindWindowExW,
    fnFindWindowW,
    fnFormatMessageW,
    fnFreeContextBuffer,
    fnFreeEnvironmentStringsW,
    fnGetAltTabInfoW,
    fnGetAtomNameW,
    fnGetCPInfo,
    fnGetCPInfoExW,
    fnGetCalendarInfoW,
    fnGetCharABCWidthsFloatW,
    fnGetCharABCWidthsW,
    fnGetCharWidth32W,
    fnGetCharWidthFloatW,
    fnGetCharWidthW,
    fnGetCharacterPlacementW,
    fnGetClassInfoExW,
    fnGetClassInfoW,
    fnGetClassLongW,
    fnGetClassNameW,
    fnGetClipboardData,
    fnGetClipboardFormatNameW,
    fnGetComputerNameW,
    fnGetConsoleTitleW,
    fnGetCurrencyFormatW,
    fnGetCurrentDirectoryW,
    fnGetCurrentHwProfileW,
    fnGetDateFormatW,
    fnGetDefaultCommConfigW,
    fnGetDiskFreeSpaceExW,
    fnGetDiskFreeSpaceW,
    fnGetDlgItemTextW,
    fnGetDriveTypeW,
    fnGetEnhMetaFileDescriptionW,
    fnGetEnhMetaFileW,
    fnGetEnvironmentStringsW,
    fnGetEnvironmentVariableW,
    fnGetFileAttributesExW,
    fnGetFileAttributesW,
    fnGetFileTitleW,
    fnGetFileVersionInfoSizeW,
    fnGetFileVersionInfoW,
    fnGetFullPathNameW,
    fnGetGlyphOutlineW,
    fnGetICMProfileW,
    fnGetJobW,
    fnGetKerningPairsW,
    fnGetKeyNameTextW,
    fnGetKeyboardLayoutNameW,
    fnGetLocaleInfoW,
    fnGetLogColorSpaceW,
    fnGetLogicalDriveStringsW,
    fnGetLongPathNameW,
    fnGetMenuItemInfoW,
    fnGetMenuStringW,
    fnGetMessageW,
    fnGetMetaFileW,
    fnGetModuleFileNameW,
    fnGetModuleHandleW,
    fnGetMonitorInfoW,
    fnGetNamedPipeHandleStateW,
    fnGetNumberFormatW,
    fnGetObjectW,
    fnGetOpenFileNamePreviewW,
    fnGetOpenFileNameW,
    fnGetOutlineTextMetricsW,
    fnGetPrintProcessorDirectoryW,
    fnGetPrinterDataW,
    fnGetPrinterDriverDirectoryW,
    fnGetPrinterDriverW,
    fnGetPrinterW,
    fnGetPrivateProfileIntW,
    fnGetPrivateProfileSectionNamesW,
    fnGetPrivateProfileSectionW,
    fnGetPrivateProfileStringW,
    fnGetPrivateProfileStructW,
    fnGetProfileIntW,
    fnGetProfileSectionW,
    fnGetProfileStringW,
    fnGetPropA,
    fnGetPropW,
    fnGetRoleTextW,
    fnGetSaveFileNamePreviewW,
    fnGetSaveFileNameW,
    fnGetShortPathNameW,
    fnGetStartupInfoW,
    fnGetStateTextW,
    fnGetStringTypeExW,
    fnGetStringTypeW,
    fnGetSystemDirectoryW,
    fnGetSystemWindowsDirectoryW,
    fnGetTabbedTextExtentW,
    fnGetTempFileNameW,
    fnGetTempPathW,
    fnGetTextExtentExPointW,
    fnGetTextExtentPoint32W,
    fnGetTextExtentPointW,
    fnGetTextFaceW,
    fnGetTextMetricsW,
    fnGetTimeFormatW,
    fnGetUserNameW,
    fnGetVersionExW,
    fnGetVolumeInformationW,
    fnGetWindowLongA,
    fnGetWindowLongW,
    fnGetWindowModuleFileNameW,
    fnGetWindowTextLengthW,
    fnGetWindowTextW,
    fnGetWindowsDirectoryW,
    fnGlobalAddAtomW,
    fnGlobalFindAtomW,
    fnGlobalGetAtomNameW,
    fnGrayStringW,
    fnInitSecurityInterfaceW,
    fnInitializeSecurityContextW,
    fnInsertMenuItemW,
    fnInsertMenuW,
    fnIsBadStringPtrW,
    fnIsCharAlphaNumericW,
    fnIsCharAlphaW,
    fnIsCharLowerW,
    fnIsCharUpperW,
    fnIsClipboardFormatAvailable,
    fnIsDestinationReachableW,
    fnIsDialogMessageW,
    fnIsTextUnicode,
    fnIsValidCodePage,
    fnIsWindowUnicode,
    fnLCMapStringW,
    fnLoadAcceleratorsW,
    fnLoadBitmapW,
    fnLoadCursorFromFileW,
    fnLoadCursorW,
    fnLoadIconW,
    fnLoadImageW,
    fnLoadKeyboardLayoutW,
    fnLoadLibraryExW,
    fnLoadLibraryW,
    fnLoadMenuIndirectW,
    fnLoadMenuW,
    fnLoadStringW,
    fnMCIWndCreateW,
    fnMapVirtualKeyExW,
    fnMapVirtualKeyW,
    fnMessageBoxExW,
    fnMessageBoxIndirectW,
    fnMessageBoxW,
    fnModifyMenuW,
    fnMoveFileW,
    fnMultiByteToWideChar,
    fnMultinetGetConnectionPerformanceW,
    fnOemToCharBuffW,
    fnOemToCharW,
    fnOleUIAddVerbMenuW,
    fnOleUIBusyW,
    fnOleUIChangeIconW,
    fnOleUIChangeSourceW,
    fnOleUIConvertW,
    fnOleUIEditLinksW,
    fnOleUIInsertObjectW,
    fnOleUIObjectPropertiesW,
    fnOleUIPasteSpecialW,
    fnOleUIPromptUserW,
    fnOleUIUpdateLinksW,
    fnOpenEventW,
    fnOpenFileMappingW,
    fnOpenMutexW,
    fnOpenPrinterW,
    fnOpenSemaphoreW,
    fnOpenWaitableTimerW,
    fnOutputDebugStringW,
    fnPageSetupDlgW,
    fnPeekConsoleInputW,
    fnPeekMessageW,
    fnPlaySoundW,
    fnPolyTextOutW,
    fnPostMessageW,
    fnPostThreadMessageW,
    fnPrintDlgW,
    fnQueryContextAttributesW,
    fnQueryCredentialsAttributesW,
    fnQueryDosDeviceW,
    fnQuerySecurityPackageInfoW,
    fnRasConnectionNotificationW,
    fnRasCreatePhonebookEntryW,
    fnRasDeleteEntryW,
    fnRasDeleteSubEntryW,
    fnRasDialW,
    fnRasEditPhonebookEntryW,
    fnRasEnumConnectionsW,
    fnRasEnumDevicesW,
    fnRasEnumEntriesW,
    fnRasGetConnectStatusW,
    fnRasGetEntryDialParamsW,
    fnRasGetEntryPropertiesW,
    fnRasGetErrorStringW,
    fnRasGetProjectionInfoW,
    fnRasHangUpW,
    fnRasRenameEntryW,
    fnRasSetEntryDialParamsW,
    fnRasSetEntryPropertiesW,
    fnRasSetSubEntryPropertiesW,
    fnRasValidateEntryNameW,
    fnReadConsoleInputW,
    fnReadConsoleOutputCharacterW,
    fnReadConsoleOutputW,
    fnReadConsoleW,
    fnRegConnectRegistryW,
    fnRegCreateKeyExW,
    fnRegCreateKeyW,
    fnRegDeleteKeyW,
    fnRegDeleteValueW,
    fnRegEnumKeyExW,
    fnRegEnumKeyW,
    fnRegEnumValueW,
    fnRegLoadKeyW,
    fnRegOpenKeyExW,
    fnRegOpenKeyW,
    fnRegQueryInfoKeyW,
    fnRegQueryMultipleValuesW,
    fnRegQueryValueExW,
    fnRegQueryValueW,
    fnRegReplaceKeyW,
    fnRegSaveKeyW,
    fnRegSetValueExW,
    fnRegSetValueW,
    fnRegUnLoadKeyW,
    fnRegisterClassExW,
    fnRegisterClassW,
    fnRegisterClipboardFormatW,
    fnRegisterDeviceNotificationW,
    fnRegisterWindowMessageW,
    fnRemoveDirectoryW,
    fnRemoveFontResourceW,
    fnRemovePropA,
    fnRemovePropW,
    fnReplaceTextW,
    fnResetDCW,
    fnResetPrinterW,
    fnSHBrowseForFolderW,
    fnSHChangeNotify,
    fnSHFileOperationW,
    fnSHGetFileInfoW,
    fnSHGetNewLinkInfoW,
    fnSHGetPathFromIDListW,
    fnScrollConsoleScreenBufferW,
    fnSearchPathW,
    fnSendDlgItemMessageW,
    fnSendMessageCallbackW,
    fnSendMessageTimeoutW,
    fnSendMessageW,
    fnSendNotifyMessageW,
    fnSetCalendarInfoW,
    fnSetClassLongW,
    fnSetComputerNameW,
    fnSetConsoleTitleW,
    fnSetCurrentDirectoryW,
    fnSetDefaultCommConfigW,
    fnSetDlgItemTextW,
    fnSetEnvironmentVariableW,
    fnSetFileAttributesW,
    fnSetICMProfileW,
    fnSetJobW,
    fnSetLocaleInfoW,
    fnSetMenuItemInfoW,
    fnSetPrinterDataW,
    fnSetPrinterW,
    fnSetPropA,
    fnSetPropW,
    fnSetVolumeLabelW,
    fnSetWindowLongA,
    fnSetWindowLongW,
    fnSetWindowTextW,
    fnSetWindowsHookExW,
    fnSetWindowsHookW,
    fnShellAboutW,
    fnShellExecuteExW,
    fnShellExecuteW,
    fnShell_NotifyIconW,
    fnStartDocPrinterW,
    fnStartDocW,
    fnSystemParametersInfoW,
    fnTabbedTextOutW,
    fnTextOutW,
    fnTranslateAcceleratorW,
    fnUnregisterClassW,
    fnUpdateICMRegKeyW,
    fnUpdateResourceA,
    fnUpdateResourceW,
    fnVerFindFileW,
    fnVerInstallFileW,
    fnVerLanguageNameW,
    fnVerQueryValueW,
    fnVkKeyScanExW,
    fnVkKeyScanW,
    fnWNetAddConnection2W,
    fnWNetAddConnection3W,
    fnWNetAddConnectionW,
    fnWNetCancelConnection2W,
    fnWNetCancelConnectionW,
    fnWNetConnectionDialog1W,
    fnWNetDisconnectDialog1W,
    fnWNetEnumResourceW,
    fnWNetGetConnectionW,
    fnWNetGetLastErrorW,
    fnWNetGetNetworkInformationW,
    fnWNetGetProviderNameW,
    fnWNetGetResourceInformationW,
    fnWNetGetResourceParentW,
    fnWNetGetUniversalNameW,
    fnWNetGetUserW,
    fnWNetOpenEnumW,
    fnWNetUseConnectionW,
    fnWaitNamedPipeW,
    fnWideCharToMultiByte,
    fnWinHelpW,
    fnWriteConsoleInputW,
    fnWriteConsoleOutputCharacterW,
    fnWriteConsoleOutputW,
    fnWriteConsoleW,
    fnWritePrivateProfileSectionW,
    fnWritePrivateProfileStringW,
    fnWritePrivateProfileStructW,
    fnWriteProfileSectionW,
    fnWriteProfileStringW,
    fnauxGetDevCapsW,
    fncapCreateCaptureWindowW,
    fncapGetDriverDescriptionW,
    fnjoyGetDevCapsW,
    fnlstrcatW,
    fnlstrcmpW,
    fnlstrcmpiW,
    fnlstrcpyW,
    fnlstrcpynW,
    fnlstrlenW,
    fnmciGetDeviceIDW,
    fnmciGetErrorStringW,
    fnmciSendCommandW,
    fnmciSendStringW,
    fnmidiInGetDevCapsW,
    fnmidiInGetErrorTextW,
    fnmidiOutGetDevCapsW,
    fnmidiOutGetErrorTextW,
    fnmixerGetControlDetailsW,
    fnmixerGetDevCapsW,
    fnmixerGetLineControlsW,
    fnmixerGetLineInfoW,
    fnmmioInstallIOProcW,
    fnmmioOpenW,
    fnmmioRenameW,
    fnmmioStringToFOURCCW,
    fnsndPlaySoundW,
    fnwaveInGetDevCapsW,
    fnwaveInGetErrorTextW,
    fnwaveOutGetDevCapsW,
    fnwaveOutGetErrorTextW,
    fnwsprintfW,
    fnwvsprintfW,
    fnGetProcAddress
  );

  {$ENDREGION}

  TModuleID = (
    mKernel32, mSecur32, mGDI32, mWinSpool, mUser32, mComDlg32, mOleAcc,
    mAdvAPI32, mShell32, mVersion, mVFW32, mSensAPI, mMPR, mOleDlg, mWinMM,
    mRasAPI32
  );

  TErrorProc = procedure(const DataIndex: TMSLUFunction);

  PMSLUProcInfo = ^TMSLUProcInfo;
  TMSLUProcInfo = record
    Name: AnsiString; // name of the function in Unicows.dll
    Module: TModuleID; // real module that implements the function natively
    Override: PFarProc; // Unicows_X variable above that points to an overriding function, if any
    Thunk: TProcedure; // procedure that gets called to resolve the hooked API import
    ErrorHandler: TErrorProc; // procedure that returns an error code when MSLU function isn't available
    // These last three tell ErrorHandler what and how to return
    ParamBytes: Cardinal; // number of bytes to pop off the stack; must be a multiple of 4
    ErrorReturn: Cardinal; // value for function to return
    LastError: DWord; // value GetLastError should return
  end;

  TMSLUProcInfoArray = array[TMSLUFunction] of TMSLUProcInfo;

procedure ResolveThunk(const DataIndex: TMSLUFunction; var ThunkVar: TFarProc); forward;

// This is the generic error handler. There are four function-specific error
// handlers, the _GodotFailX functions, for what the generic handler can't do.
procedure ThunkError(const DataIndex: TMSLUFunction); forward;
procedure _GodotFailGetPrivateProfileIntW(const DataIndex: TMSLUFunction); forward;
procedure _GodotFailGetProfileIntW(const DataIndex: TMSLUFunction); forward;
procedure _GodotFailGetStartupInfoW(const DataIndex: TMSLUFunction); forward;
procedure _GodotFailmmioOpenW(const DataIndex: TMSLUFunction); forward;

// These pointers determine where control goes when the corresponding API
// function gets called. Initially, they all point to ResolveThunk. That
// function will re-assign the pointer to refer to the override function above,
// to the API function in Unicows.dll, or to an error stub. The next time the
// function is called in the program, the ResolveThunk procedure gets skipped.
{$REGION 'Thunk pointers'}
var
  _AcquireCredentialsHandleW_Thunk: Pointer = @ResolveThunk;
  _AddAtomW_Thunk: Pointer = @ResolveThunk;
  _AddFontResourceW_Thunk: Pointer = @ResolveThunk;
  _AddJobW_Thunk: Pointer = @ResolveThunk;
  _AddMonitorW_Thunk: Pointer = @ResolveThunk;
  _AddPortW_Thunk: Pointer = @ResolveThunk;
  _AddPrintProcessorW_Thunk: Pointer = @ResolveThunk;
  _AddPrintProvidorW_Thunk: Pointer = @ResolveThunk;
  _AddPrinterDriverW_Thunk: Pointer = @ResolveThunk;
  _AddPrinterW_Thunk: Pointer = @ResolveThunk;
  _AdvancedDocumentPropertiesW_Thunk: Pointer = @ResolveThunk;
  _AppendMenuW_Thunk: Pointer = @ResolveThunk;
  _BeginUpdateResourceA_Thunk: Pointer = @ResolveThunk;
  _BeginUpdateResourceW_Thunk: Pointer = @ResolveThunk;
  _BroadcastSystemMessageW_Thunk: Pointer = @ResolveThunk;
  _BuildCommDCBAndTimeoutsW_Thunk: Pointer = @ResolveThunk;
  _BuildCommDCBW_Thunk: Pointer = @ResolveThunk;
  _CallMsgFilterW_Thunk: Pointer = @ResolveThunk;
  _CallNamedPipeW_Thunk: Pointer = @ResolveThunk;
  _CallWindowProcA_Thunk: Pointer = @ResolveThunk;
  _CallWindowProcW_Thunk: Pointer = @ResolveThunk;
  _ChangeDisplaySettingsExW_Thunk: Pointer = @ResolveThunk;
  _ChangeDisplaySettingsW_Thunk: Pointer = @ResolveThunk;
  _ChangeMenuW_Thunk: Pointer = @ResolveThunk;
  _CharLowerBuffW_Thunk: Pointer = @ResolveThunk;
  _CharLowerW_Thunk: Pointer = @ResolveThunk;
  _CharNextW_Thunk: Pointer = @ResolveThunk;
  _CharPrevW_Thunk: Pointer = @ResolveThunk;
  _CharToOemBuffW_Thunk: Pointer = @ResolveThunk;
  _CharToOemW_Thunk: Pointer = @ResolveThunk;
  _CharUpperBuffW_Thunk: Pointer = @ResolveThunk;
  _CharUpperW_Thunk: Pointer = @ResolveThunk;
  _ChooseColorW_Thunk: Pointer = @ResolveThunk;
  _ChooseFontW_Thunk: Pointer = @ResolveThunk;
  _CommConfigDialogW_Thunk: Pointer = @ResolveThunk;
  _CompareStringW_Thunk: Pointer = @ResolveThunk;
  _ConfigurePortW_Thunk: Pointer = @ResolveThunk;
  _CopyAcceleratorTableW_Thunk: Pointer = @ResolveThunk;
  _CopyEnhMetaFileW_Thunk: Pointer = @ResolveThunk;
  _CopyFileExW_Thunk: Pointer = @ResolveThunk;
  _CopyFileW_Thunk: Pointer = @ResolveThunk;
  _CopyMetaFileW_Thunk: Pointer = @ResolveThunk;
  _CreateAcceleratorTableW_Thunk: Pointer = @ResolveThunk;
  _CreateColorSpaceW_Thunk: Pointer = @ResolveThunk;
  _CreateDCW_Thunk: Pointer = @ResolveThunk;
  _CreateDialogIndirectParamW_Thunk: Pointer = @ResolveThunk;
  _CreateDialogParamW_Thunk: Pointer = @ResolveThunk;
  _CreateDirectoryExW_Thunk: Pointer = @ResolveThunk;
  _CreateDirectoryW_Thunk: Pointer = @ResolveThunk;
  _CreateEnhMetaFileW_Thunk: Pointer = @ResolveThunk;
  _CreateEventW_Thunk: Pointer = @ResolveThunk;
  _CreateFileMappingW_Thunk: Pointer = @ResolveThunk;
  _CreateFileW_Thunk: Pointer = @ResolveThunk;
  _CreateFontIndirectW_Thunk: Pointer = @ResolveThunk;
  _CreateFontW_Thunk: Pointer = @ResolveThunk;
  _CreateICW_Thunk: Pointer = @ResolveThunk;
  _CreateMDIWindowW_Thunk: Pointer = @ResolveThunk;
  _CreateMailslotW_Thunk: Pointer = @ResolveThunk;
  _CreateMetaFileW_Thunk: Pointer = @ResolveThunk;
  _CreateMutexW_Thunk: Pointer = @ResolveThunk;
  _CreateNamedPipeW_Thunk: Pointer = @ResolveThunk;
  _CreateProcessW_Thunk: Pointer = @ResolveThunk;
  _CreateScalableFontResourceW_Thunk: Pointer = @ResolveThunk;
  _CreateSemaphoreW_Thunk: Pointer = @ResolveThunk;
  _CreateStdAccessibleProxyW_Thunk: Pointer = @ResolveThunk;
  _CreateWaitableTimerW_Thunk: Pointer = @ResolveThunk;
  _CreateWindowExW_Thunk: Pointer = @ResolveThunk;
  _CryptAcquireContextW_Thunk: Pointer = @ResolveThunk;
  _CryptEnumProviderTypesW_Thunk: Pointer = @ResolveThunk;
  _CryptEnumProvidersW_Thunk: Pointer = @ResolveThunk;
  _CryptGetDefaultProviderW_Thunk: Pointer = @ResolveThunk;
  _CryptSetProviderExW_Thunk: Pointer = @ResolveThunk;
  _CryptSetProviderW_Thunk: Pointer = @ResolveThunk;
  _CryptSignHashW_Thunk: Pointer = @ResolveThunk;
  _CryptVerifySignatureW_Thunk: Pointer = @ResolveThunk;
  _DdeConnect_Thunk: Pointer = @ResolveThunk;
  _DdeConnectList_Thunk: Pointer = @ResolveThunk;
  _DdeCreateStringHandleW_Thunk: Pointer = @ResolveThunk;
  _DdeInitializeW_Thunk: Pointer = @ResolveThunk;
  _DdeQueryConvInfo_Thunk: Pointer = @ResolveThunk;
  _DdeQueryStringW_Thunk: Pointer = @ResolveThunk;
  _DefDlgProcW_Thunk: Pointer = @ResolveThunk;
  _DefFrameProcW_Thunk: Pointer = @ResolveThunk;
  _DefMDIChildProcW_Thunk: Pointer = @ResolveThunk;
  _DefWindowProcW_Thunk: Pointer = @ResolveThunk;
  _DeleteFileW_Thunk: Pointer = @ResolveThunk;
  _DeleteMonitorW_Thunk: Pointer = @ResolveThunk;
  _DeletePortW_Thunk: Pointer = @ResolveThunk;
  _DeletePrintProcessorW_Thunk: Pointer = @ResolveThunk;
  _DeletePrintProvidorW_Thunk: Pointer = @ResolveThunk;
  _DeletePrinterDriverW_Thunk: Pointer = @ResolveThunk;
  _DeviceCapabilitiesW_Thunk: Pointer = @ResolveThunk;
  _DialogBoxIndirectParamW_Thunk: Pointer = @ResolveThunk;
  _DialogBoxParamW_Thunk: Pointer = @ResolveThunk;
  _DispatchMessageW_Thunk: Pointer = @ResolveThunk;
  _DlgDirListComboBoxW_Thunk: Pointer = @ResolveThunk;
  _DlgDirListW_Thunk: Pointer = @ResolveThunk;
  _DlgDirSelectComboBoxExW_Thunk: Pointer = @ResolveThunk;
  _DlgDirSelectExW_Thunk: Pointer = @ResolveThunk;
  _DocumentPropertiesW_Thunk: Pointer = @ResolveThunk;
  _DragQueryFileW_Thunk: Pointer = @ResolveThunk;
  _DrawStateW_Thunk: Pointer = @ResolveThunk;
  _DrawTextExW_Thunk: Pointer = @ResolveThunk;
  _DrawTextW_Thunk: Pointer = @ResolveThunk;
  _EnableWindow_Thunk: Pointer = @ResolveThunk;
  _EndUpdateResourceA_Thunk: Pointer = @ResolveThunk;
  _EndUpdateResourceW_Thunk: Pointer = @ResolveThunk;
  _EnumCalendarInfoExW_Thunk: Pointer = @ResolveThunk;
  _EnumCalendarInfoW_Thunk: Pointer = @ResolveThunk;
  _EnumClipboardFormats_Thunk: Pointer = @ResolveThunk;
  _EnumDateFormatsExW_Thunk: Pointer = @ResolveThunk;
  _EnumDateFormatsW_Thunk: Pointer = @ResolveThunk;
  _EnumDisplayDevicesW_Thunk: Pointer = @ResolveThunk;
  _EnumDisplaySettingsExW_Thunk: Pointer = @ResolveThunk;
  _EnumDisplaySettingsW_Thunk: Pointer = @ResolveThunk;
  _EnumFontFamiliesExW_Thunk: Pointer = @ResolveThunk;
  _EnumFontFamiliesW_Thunk: Pointer = @ResolveThunk;
  _EnumFontsW_Thunk: Pointer = @ResolveThunk;
  _EnumICMProfilesW_Thunk: Pointer = @ResolveThunk;
  _EnumMonitorsW_Thunk: Pointer = @ResolveThunk;
  _EnumPortsW_Thunk: Pointer = @ResolveThunk;
  _EnumPrintProcessorDatatypesW_Thunk: Pointer = @ResolveThunk;
  _EnumPrintProcessorsW_Thunk: Pointer = @ResolveThunk;
  _EnumPrinterDriversW_Thunk: Pointer = @ResolveThunk;
  _EnumPrintersW_Thunk: Pointer = @ResolveThunk;
  _EnumPropsA_Thunk: Pointer = @ResolveThunk;
  _EnumPropsExA_Thunk: Pointer = @ResolveThunk;
  _EnumPropsExW_Thunk: Pointer = @ResolveThunk;
  _EnumPropsW_Thunk: Pointer = @ResolveThunk;
  _EnumSystemCodePagesW_Thunk: Pointer = @ResolveThunk;
  _EnumSystemLocalesW_Thunk: Pointer = @ResolveThunk;
  _EnumTimeFormatsW_Thunk: Pointer = @ResolveThunk;
  _EnumerateSecurityPackagesW_Thunk: Pointer = @ResolveThunk;
  _ExpandEnvironmentStringsW_Thunk: Pointer = @ResolveThunk;
  _ExtTextOutW_Thunk: Pointer = @ResolveThunk;
  _ExtractIconExW_Thunk: Pointer = @ResolveThunk;
  _ExtractIconW_Thunk: Pointer = @ResolveThunk;
  _FatalAppExitW_Thunk: Pointer = @ResolveThunk;
  _FillConsoleOutputCharacterW_Thunk: Pointer = @ResolveThunk;
  _FindAtomW_Thunk: Pointer = @ResolveThunk;
  _FindExecutableW_Thunk: Pointer = @ResolveThunk;
  _FindFirstChangeNotificationW_Thunk: Pointer = @ResolveThunk;
  _FindFirstFileW_Thunk: Pointer = @ResolveThunk;
  _FindNextFileW_Thunk: Pointer = @ResolveThunk;
  _FindResourceExW_Thunk: Pointer = @ResolveThunk;
  _FindResourceW_Thunk: Pointer = @ResolveThunk;
  _FindTextW_Thunk: Pointer = @ResolveThunk;
  _FindWindowExW_Thunk: Pointer = @ResolveThunk;
  _FindWindowW_Thunk: Pointer = @ResolveThunk;
  _FormatMessageW_Thunk: Pointer = @ResolveThunk;
  _FreeContextBuffer_Thunk: Pointer = @ResolveThunk;
  _FreeEnvironmentStringsW_Thunk: Pointer = @ResolveThunk;
  _GetAltTabInfoW_Thunk: Pointer = @ResolveThunk;
  _GetAtomNameW_Thunk: Pointer = @ResolveThunk;
  _GetCPInfo_Thunk: Pointer = @ResolveThunk;
  _GetCPInfoExW_Thunk: Pointer = @ResolveThunk;
  _GetCalendarInfoW_Thunk: Pointer = @ResolveThunk;
  _GetCharABCWidthsFloatW_Thunk: Pointer = @ResolveThunk;
  _GetCharABCWidthsW_Thunk: Pointer = @ResolveThunk;
  _GetCharWidth32W_Thunk: Pointer = @ResolveThunk;
  _GetCharWidthFloatW_Thunk: Pointer = @ResolveThunk;
  _GetCharWidthW_Thunk: Pointer = @ResolveThunk;
  _GetCharacterPlacementW_Thunk: Pointer = @ResolveThunk;
  _GetClassInfoExW_Thunk: Pointer = @ResolveThunk;
  _GetClassInfoW_Thunk: Pointer = @ResolveThunk;
  _GetClassLongW_Thunk: Pointer = @ResolveThunk;
  _GetClassNameW_Thunk: Pointer = @ResolveThunk;
  _GetClipboardData_Thunk: Pointer = @ResolveThunk;
  _GetClipboardFormatNameW_Thunk: Pointer = @ResolveThunk;
  _GetComputerNameW_Thunk: Pointer = @ResolveThunk;
  _GetConsoleTitleW_Thunk: Pointer = @ResolveThunk;
  _GetCurrencyFormatW_Thunk: Pointer = @ResolveThunk;
  _GetCurrentDirectoryW_Thunk: Pointer = @ResolveThunk;
  _GetCurrentHwProfileW_Thunk: Pointer = @ResolveThunk;
  _GetDateFormatW_Thunk: Pointer = @ResolveThunk;
  _GetDefaultCommConfigW_Thunk: Pointer = @ResolveThunk;
  _GetDiskFreeSpaceExW_Thunk: Pointer = @ResolveThunk;
  _GetDiskFreeSpaceW_Thunk: Pointer = @ResolveThunk;
  _GetDlgItemTextW_Thunk: Pointer = @ResolveThunk;
  _GetDriveTypeW_Thunk: Pointer = @ResolveThunk;
  _GetEnhMetaFileDescriptionW_Thunk: Pointer = @ResolveThunk;
  _GetEnhMetaFileW_Thunk: Pointer = @ResolveThunk;
  _GetEnvironmentStringsW_Thunk: Pointer = @ResolveThunk;
  _GetEnvironmentVariableW_Thunk: Pointer = @ResolveThunk;
  _GetFileAttributesExW_Thunk: Pointer = @ResolveThunk;
  _GetFileAttributesW_Thunk: Pointer = @ResolveThunk;
  _GetFileTitleW_Thunk: Pointer = @ResolveThunk;
  _GetFileVersionInfoSizeW_Thunk: Pointer = @ResolveThunk;
  _GetFileVersionInfoW_Thunk: Pointer = @ResolveThunk;
  _GetFullPathNameW_Thunk: Pointer = @ResolveThunk;
  _GetGlyphOutlineW_Thunk: Pointer = @ResolveThunk;
  _GetICMProfileW_Thunk: Pointer = @ResolveThunk;
  _GetJobW_Thunk: Pointer = @ResolveThunk;
  _GetKerningPairsW_Thunk: Pointer = @ResolveThunk;
  _GetKeyNameTextW_Thunk: Pointer = @ResolveThunk;
  _GetKeyboardLayoutNameW_Thunk: Pointer = @ResolveThunk;
  _GetLocaleInfoW_Thunk: Pointer = @ResolveThunk;
  _GetLogColorSpaceW_Thunk: Pointer = @ResolveThunk;
  _GetLogicalDriveStringsW_Thunk: Pointer = @ResolveThunk;
  _GetLongPathNameW_Thunk: Pointer = @ResolveThunk;
  _GetMenuItemInfoW_Thunk: Pointer = @ResolveThunk;
  _GetMenuStringW_Thunk: Pointer = @ResolveThunk;
  _GetMessageW_Thunk: Pointer = @ResolveThunk;
  _GetMetaFileW_Thunk: Pointer = @ResolveThunk;
  _GetModuleFileNameW_Thunk: Pointer = @ResolveThunk;
  _GetModuleHandleW_Thunk: Pointer = @ResolveThunk;
  _GetMonitorInfoW_Thunk: Pointer = @ResolveThunk;
  _GetNamedPipeHandleStateW_Thunk: Pointer = @ResolveThunk;
  _GetNumberFormatW_Thunk: Pointer = @ResolveThunk;
  _GetObjectW_Thunk: Pointer = @ResolveThunk;
  _GetOpenFileNamePreviewW_Thunk: Pointer = @ResolveThunk;
  _GetOpenFileNameW_Thunk: Pointer = @ResolveThunk;
  _GetOutlineTextMetricsW_Thunk: Pointer = @ResolveThunk;
  _GetPrintProcessorDirectoryW_Thunk: Pointer = @ResolveThunk;
  _GetPrinterDataW_Thunk: Pointer = @ResolveThunk;
  _GetPrinterDriverDirectoryW_Thunk: Pointer = @ResolveThunk;
  _GetPrinterDriverW_Thunk: Pointer = @ResolveThunk;
  _GetPrinterW_Thunk: Pointer = @ResolveThunk;
  _GetPrivateProfileIntW_Thunk: Pointer = @ResolveThunk;
  _GetPrivateProfileSectionNamesW_Thunk: Pointer = @ResolveThunk;
  _GetPrivateProfileSectionW_Thunk: Pointer = @ResolveThunk;
  _GetPrivateProfileStringW_Thunk: Pointer = @ResolveThunk;
  _GetPrivateProfileStructW_Thunk: Pointer = @ResolveThunk;
  _GetProcAddress_Thunk: Pointer = @ResolveThunk;
  _GetProfileIntW_Thunk: Pointer = @ResolveThunk;
  _GetProfileSectionW_Thunk: Pointer = @ResolveThunk;
  _GetProfileStringW_Thunk: Pointer = @ResolveThunk;
  _GetPropA_Thunk: Pointer = @ResolveThunk;
  _GetPropW_Thunk: Pointer = @ResolveThunk;
  _GetRoleTextW_Thunk: Pointer = @ResolveThunk;
  _GetSaveFileNamePreviewW_Thunk: Pointer = @ResolveThunk;
  _GetSaveFileNameW_Thunk: Pointer = @ResolveThunk;
  _GetShortPathNameW_Thunk: Pointer = @ResolveThunk;
  _GetStartupInfoW_Thunk: Pointer = @ResolveThunk;
  _GetStateTextW_Thunk: Pointer = @ResolveThunk;
  _GetStringTypeExW_Thunk: Pointer = @ResolveThunk;
  _GetStringTypeW_Thunk: Pointer = @ResolveThunk;
  _GetSystemDirectoryW_Thunk: Pointer = @ResolveThunk;
  _GetSystemWindowsDirectoryW_Thunk: Pointer = @ResolveThunk;
  _GetTabbedTextExtentW_Thunk: Pointer = @ResolveThunk;
  _GetTempFileNameW_Thunk: Pointer = @ResolveThunk;
  _GetTempPathW_Thunk: Pointer = @ResolveThunk;
  _GetTextExtentExPointW_Thunk: Pointer = @ResolveThunk;
  _GetTextExtentPoint32W_Thunk: Pointer = @ResolveThunk;
  _GetTextExtentPointW_Thunk: Pointer = @ResolveThunk;
  _GetTextFaceW_Thunk: Pointer = @ResolveThunk;
  _GetTextMetricsW_Thunk: Pointer = @ResolveThunk;
  _GetTimeFormatW_Thunk: Pointer = @ResolveThunk;
  _GetUserNameW_Thunk: Pointer = @ResolveThunk;
  _GetVersionExW_Thunk: Pointer = @ResolveThunk;
  _GetVolumeInformationW_Thunk: Pointer = @ResolveThunk;
  _GetWindowLongA_Thunk: Pointer = @ResolveThunk;
  _GetWindowLongW_Thunk: Pointer = @ResolveThunk;
  _GetWindowModuleFileNameW_Thunk: Pointer = @ResolveThunk;
  _GetWindowTextLengthW_Thunk: Pointer = @ResolveThunk;
  _GetWindowTextW_Thunk: Pointer = @ResolveThunk;
  _GetWindowsDirectoryW_Thunk: Pointer = @ResolveThunk;
  _GlobalAddAtomW_Thunk: Pointer = @ResolveThunk;
  _GlobalFindAtomW_Thunk: Pointer = @ResolveThunk;
  _GlobalGetAtomNameW_Thunk: Pointer = @ResolveThunk;
  _GrayStringW_Thunk: Pointer = @ResolveThunk;
  _InitSecurityInterfaceW_Thunk: Pointer = @ResolveThunk;
  _InitializeSecurityContextW_Thunk: Pointer = @ResolveThunk;
  _InsertMenuItemW_Thunk: Pointer = @ResolveThunk;
  _InsertMenuW_Thunk: Pointer = @ResolveThunk;
  _IsBadStringPtrW_Thunk: Pointer = @ResolveThunk;
  _IsCharAlphaNumericW_Thunk: Pointer = @ResolveThunk;
  _IsCharAlphaW_Thunk: Pointer = @ResolveThunk;
  _IsCharLowerW_Thunk: Pointer = @ResolveThunk;
  _IsCharUpperW_Thunk: Pointer = @ResolveThunk;
  _IsClipboardFormatAvailable_Thunk: Pointer = @ResolveThunk;
  _IsDestinationReachableW_Thunk: Pointer = @ResolveThunk;
  _IsDialogMessageW_Thunk: Pointer = @ResolveThunk;
  _IsTextUnicode_Thunk: Pointer = @ResolveThunk;
  _IsValidCodePage_Thunk: Pointer = @ResolveThunk;
  _IsWindowUnicode_Thunk: Pointer = @ResolveThunk;
  _LCMapStringW_Thunk: Pointer = @ResolveThunk;
  _LoadAcceleratorsW_Thunk: Pointer = @ResolveThunk;
  _LoadBitmapW_Thunk: Pointer = @ResolveThunk;
  _LoadCursorFromFileW_Thunk: Pointer = @ResolveThunk;
  _LoadCursorW_Thunk: Pointer = @ResolveThunk;
  _LoadIconW_Thunk: Pointer = @ResolveThunk;
  _LoadImageW_Thunk: Pointer = @ResolveThunk;
  _LoadKeyboardLayoutW_Thunk: Pointer = @ResolveThunk;
  _LoadLibraryExW_Thunk: Pointer = @ResolveThunk;
  _LoadLibraryW_Thunk: Pointer = @ResolveThunk;
  _LoadMenuIndirectW_Thunk: Pointer = @ResolveThunk;
  _LoadMenuW_Thunk: Pointer = @ResolveThunk;
  _LoadStringW_Thunk: Pointer = @ResolveThunk;
  _MCIWndCreateW_Thunk: Pointer = @ResolveThunk;
  _MapVirtualKeyExW_Thunk: Pointer = @ResolveThunk;
  _MapVirtualKeyW_Thunk: Pointer = @ResolveThunk;
  _MessageBoxExW_Thunk: Pointer = @ResolveThunk;
  _MessageBoxIndirectW_Thunk: Pointer = @ResolveThunk;
  _MessageBoxW_Thunk: Pointer = @ResolveThunk;
  _ModifyMenuW_Thunk: Pointer = @ResolveThunk;
  _MoveFileW_Thunk: Pointer = @ResolveThunk;
  _MultiByteToWideChar_Thunk: Pointer = @ResolveThunk;
  _MultinetGetConnectionPerformanceW_Thunk: Pointer = @ResolveThunk;
  _OemToCharBuffW_Thunk: Pointer = @ResolveThunk;
  _OemToCharW_Thunk: Pointer = @ResolveThunk;
  _OleUIAddVerbMenuW_Thunk: Pointer = @ResolveThunk;
  _OleUIBusyW_Thunk: Pointer = @ResolveThunk;
  _OleUIChangeIconW_Thunk: Pointer = @ResolveThunk;
  _OleUIChangeSourceW_Thunk: Pointer = @ResolveThunk;
  _OleUIConvertW_Thunk: Pointer = @ResolveThunk;
  _OleUIEditLinksW_Thunk: Pointer = @ResolveThunk;
  _OleUIInsertObjectW_Thunk: Pointer = @ResolveThunk;
  _OleUIObjectPropertiesW_Thunk: Pointer = @ResolveThunk;
  _OleUIPasteSpecialW_Thunk: Pointer = @ResolveThunk;
  _OleUIPromptUserW_Thunk: Pointer = @ResolveThunk;
  _OleUIUpdateLinksW_Thunk: Pointer = @ResolveThunk;
  _OpenEventW_Thunk: Pointer = @ResolveThunk;
  _OpenFileMappingW_Thunk: Pointer = @ResolveThunk;
  _OpenMutexW_Thunk: Pointer = @ResolveThunk;
  _OpenPrinterW_Thunk: Pointer = @ResolveThunk;
  _OpenSemaphoreW_Thunk: Pointer = @ResolveThunk;
  _OpenWaitableTimerW_Thunk: Pointer = @ResolveThunk;
  _OutputDebugStringW_Thunk: Pointer = @ResolveThunk;
  _PageSetupDlgW_Thunk: Pointer = @ResolveThunk;
  _PeekConsoleInputW_Thunk: Pointer = @ResolveThunk;
  _PeekMessageW_Thunk: Pointer = @ResolveThunk;
  _PlaySoundW_Thunk: Pointer = @ResolveThunk;
  _PolyTextOutW_Thunk: Pointer = @ResolveThunk;
  _PostMessageW_Thunk: Pointer = @ResolveThunk;
  _PostThreadMessageW_Thunk: Pointer = @ResolveThunk;
  _PrintDlgW_Thunk: Pointer = @ResolveThunk;
  _QueryContextAttributesW_Thunk: Pointer = @ResolveThunk;
  _QueryCredentialsAttributesW_Thunk: Pointer = @ResolveThunk;
  _QueryDosDeviceW_Thunk: Pointer = @ResolveThunk;
  _QuerySecurityPackageInfoW_Thunk: Pointer = @ResolveThunk;
  _RasConnectionNotificationW_Thunk: Pointer = @ResolveThunk;
  _RasCreatePhonebookEntryW_Thunk: Pointer = @ResolveThunk;
  _RasDeleteEntryW_Thunk: Pointer = @ResolveThunk;
  _RasDeleteSubEntryW_Thunk: Pointer = @ResolveThunk;
  _RasDialW_Thunk: Pointer = @ResolveThunk;
  _RasEditPhonebookEntryW_Thunk: Pointer = @ResolveThunk;
  _RasEnumConnectionsW_Thunk: Pointer = @ResolveThunk;
  _RasEnumDevicesW_Thunk: Pointer = @ResolveThunk;
  _RasEnumEntriesW_Thunk: Pointer = @ResolveThunk;
  _RasGetConnectStatusW_Thunk: Pointer = @ResolveThunk;
  _RasGetEntryDialParamsW_Thunk: Pointer = @ResolveThunk;
  _RasGetEntryPropertiesW_Thunk: Pointer = @ResolveThunk;
  _RasGetErrorStringW_Thunk: Pointer = @ResolveThunk;
  _RasGetProjectionInfoW_Thunk: Pointer = @ResolveThunk;
  _RasHangUpW_Thunk: Pointer = @ResolveThunk;
  _RasRenameEntryW_Thunk: Pointer = @ResolveThunk;
  _RasSetEntryDialParamsW_Thunk: Pointer = @ResolveThunk;
  _RasSetEntryPropertiesW_Thunk: Pointer = @ResolveThunk;
  _RasSetSubEntryPropertiesW_Thunk: Pointer = @ResolveThunk;
  _RasValidateEntryNameW_Thunk: Pointer = @ResolveThunk;
  _ReadConsoleInputW_Thunk: Pointer = @ResolveThunk;
  _ReadConsoleOutputCharacterW_Thunk: Pointer = @ResolveThunk;
  _ReadConsoleOutputW_Thunk: Pointer = @ResolveThunk;
  _ReadConsoleW_Thunk: Pointer = @ResolveThunk;
  _RegConnectRegistryW_Thunk: Pointer = @ResolveThunk;
  _RegCreateKeyExW_Thunk: Pointer = @ResolveThunk;
  _RegCreateKeyW_Thunk: Pointer = @ResolveThunk;
  _RegDeleteKeyW_Thunk: Pointer = @ResolveThunk;
  _RegDeleteValueW_Thunk: Pointer = @ResolveThunk;
  _RegEnumKeyExW_Thunk: Pointer = @ResolveThunk;
  _RegEnumKeyW_Thunk: Pointer = @ResolveThunk;
  _RegEnumValueW_Thunk: Pointer = @ResolveThunk;
  _RegLoadKeyW_Thunk: Pointer = @ResolveThunk;
  _RegOpenKeyExW_Thunk: Pointer = @ResolveThunk;
  _RegOpenKeyW_Thunk: Pointer = @ResolveThunk;
  _RegQueryInfoKeyW_Thunk: Pointer = @ResolveThunk;
  _RegQueryMultipleValuesW_Thunk: Pointer = @ResolveThunk;
  _RegQueryValueExW_Thunk: Pointer = @ResolveThunk;
  _RegQueryValueW_Thunk: Pointer = @ResolveThunk;
  _RegReplaceKeyW_Thunk: Pointer = @ResolveThunk;
  _RegSaveKeyW_Thunk: Pointer = @ResolveThunk;
  _RegSetValueExW_Thunk: Pointer = @ResolveThunk;
  _RegSetValueW_Thunk: Pointer = @ResolveThunk;
  _RegUnLoadKeyW_Thunk: Pointer = @ResolveThunk;
  _RegisterClassExW_Thunk: Pointer = @ResolveThunk;
  _RegisterClassW_Thunk: Pointer = @ResolveThunk;
  _RegisterClipboardFormatW_Thunk: Pointer = @ResolveThunk;
  _RegisterDeviceNotificationW_Thunk: Pointer = @ResolveThunk;
  _RegisterWindowMessageW_Thunk: Pointer = @ResolveThunk;
  _RemoveDirectoryW_Thunk: Pointer = @ResolveThunk;
  _RemoveFontResourceW_Thunk: Pointer = @ResolveThunk;
  _RemovePropA_Thunk: Pointer = @ResolveThunk;
  _RemovePropW_Thunk: Pointer = @ResolveThunk;
  _ReplaceTextW_Thunk: Pointer = @ResolveThunk;
  _ResetDCW_Thunk: Pointer = @ResolveThunk;
  _ResetPrinterW_Thunk: Pointer = @ResolveThunk;
  _SHBrowseForFolderW_Thunk: Pointer = @ResolveThunk;
  _SHChangeNotify_Thunk: Pointer = @ResolveThunk;
  _SHFileOperationW_Thunk: Pointer = @ResolveThunk;
  _SHGetFileInfoW_Thunk: Pointer = @ResolveThunk;
  _SHGetNewLinkInfoW_Thunk: Pointer = @ResolveThunk;
  _SHGetPathFromIDListW_Thunk: Pointer = @ResolveThunk;
  _ScrollConsoleScreenBufferW_Thunk: Pointer = @ResolveThunk;
  _SearchPathW_Thunk: Pointer = @ResolveThunk;
  _SendDlgItemMessageW_Thunk: Pointer = @ResolveThunk;
  _SendMessageCallbackW_Thunk: Pointer = @ResolveThunk;
  _SendMessageTimeoutW_Thunk: Pointer = @ResolveThunk;
  _SendMessageW_Thunk: Pointer = @ResolveThunk;
  _SendNotifyMessageW_Thunk: Pointer = @ResolveThunk;
  _SetCalendarInfoW_Thunk: Pointer = @ResolveThunk;
  _SetClassLongW_Thunk: Pointer = @ResolveThunk;
  _SetComputerNameW_Thunk: Pointer = @ResolveThunk;
  _SetConsoleTitleW_Thunk: Pointer = @ResolveThunk;
  _SetCurrentDirectoryW_Thunk: Pointer = @ResolveThunk;
  _SetDefaultCommConfigW_Thunk: Pointer = @ResolveThunk;
  _SetDlgItemTextW_Thunk: Pointer = @ResolveThunk;
  _SetEnvironmentVariableW_Thunk: Pointer = @ResolveThunk;
  _SetFileAttributesW_Thunk: Pointer = @ResolveThunk;
  _SetICMProfileW_Thunk: Pointer = @ResolveThunk;
  _SetJobW_Thunk: Pointer = @ResolveThunk;
  _SetLocaleInfoW_Thunk: Pointer = @ResolveThunk;
  _SetMenuItemInfoW_Thunk: Pointer = @ResolveThunk;
  _SetPrinterDataW_Thunk: Pointer = @ResolveThunk;
  _SetPrinterW_Thunk: Pointer = @ResolveThunk;
  _SetPropA_Thunk: Pointer = @ResolveThunk;
  _SetPropW_Thunk: Pointer = @ResolveThunk;
  _SetVolumeLabelW_Thunk: Pointer = @ResolveThunk;
  _SetWindowLongA_Thunk: Pointer = @ResolveThunk;
  _SetWindowLongW_Thunk: Pointer = @ResolveThunk;
  _SetWindowTextW_Thunk: Pointer = @ResolveThunk;
  _SetWindowsHookExW_Thunk: Pointer = @ResolveThunk;
  _SetWindowsHookW_Thunk: Pointer = @ResolveThunk;
  _ShellAboutW_Thunk: Pointer = @ResolveThunk;
  _ShellExecuteExW_Thunk: Pointer = @ResolveThunk;
  _ShellExecuteW_Thunk: Pointer = @ResolveThunk;
  _Shell_NotifyIconW_Thunk: Pointer = @ResolveThunk;
  _StartDocPrinterW_Thunk: Pointer = @ResolveThunk;
  _StartDocW_Thunk: Pointer = @ResolveThunk;
  _SystemParametersInfoW_Thunk: Pointer = @ResolveThunk;
  _TabbedTextOutW_Thunk: Pointer = @ResolveThunk;
  _TextOutW_Thunk: Pointer = @ResolveThunk;
  _TranslateAcceleratorW_Thunk: Pointer = @ResolveThunk;
  _UnregisterClassW_Thunk: Pointer = @ResolveThunk;
  _UpdateICMRegKeyW_Thunk: Pointer = @ResolveThunk;
  _UpdateResourceA_Thunk: Pointer = @ResolveThunk;
  _UpdateResourceW_Thunk: Pointer = @ResolveThunk;
  _VerFindFileW_Thunk: Pointer = @ResolveThunk;
  _VerInstallFileW_Thunk: Pointer = @ResolveThunk;
  _VerLanguageNameW_Thunk: Pointer = @ResolveThunk;
  _VerQueryValueW_Thunk: Pointer = @ResolveThunk;
  _VkKeyScanExW_Thunk: Pointer = @ResolveThunk;
  _VkKeyScanW_Thunk: Pointer = @ResolveThunk;
  _WNetAddConnection2W_Thunk: Pointer = @ResolveThunk;
  _WNetAddConnection3W_Thunk: Pointer = @ResolveThunk;
  _WNetAddConnectionW_Thunk: Pointer = @ResolveThunk;
  _WNetCancelConnection2W_Thunk: Pointer = @ResolveThunk;
  _WNetCancelConnectionW_Thunk: Pointer = @ResolveThunk;
  _WNetConnectionDialog1W_Thunk: Pointer = @ResolveThunk;
  _WNetDisconnectDialog1W_Thunk: Pointer = @ResolveThunk;
  _WNetEnumResourceW_Thunk: Pointer = @ResolveThunk;
  _WNetGetConnectionW_Thunk: Pointer = @ResolveThunk;
  _WNetGetLastErrorW_Thunk: Pointer = @ResolveThunk;
  _WNetGetNetworkInformationW_Thunk: Pointer = @ResolveThunk;
  _WNetGetProviderNameW_Thunk: Pointer = @ResolveThunk;
  _WNetGetResourceInformationW_Thunk: Pointer = @ResolveThunk;
  _WNetGetResourceParentW_Thunk: Pointer = @ResolveThunk;
  _WNetGetUniversalNameW_Thunk: Pointer = @ResolveThunk;
  _WNetGetUserW_Thunk: Pointer = @ResolveThunk;
  _WNetOpenEnumW_Thunk: Pointer = @ResolveThunk;
  _WNetUseConnectionW_Thunk: Pointer = @ResolveThunk;
  _WaitNamedPipeW_Thunk: Pointer = @ResolveThunk;
  _WideCharToMultiByte_Thunk: Pointer = @ResolveThunk;
  _WinHelpW_Thunk: Pointer = @ResolveThunk;
  _WriteConsoleInputW_Thunk: Pointer = @ResolveThunk;
  _WriteConsoleOutputCharacterW_Thunk: Pointer = @ResolveThunk;
  _WriteConsoleOutputW_Thunk: Pointer = @ResolveThunk;
  _WriteConsoleW_Thunk: Pointer = @ResolveThunk;
  _WritePrivateProfileSectionW_Thunk: Pointer = @ResolveThunk;
  _WritePrivateProfileStringW_Thunk: Pointer = @ResolveThunk;
  _WritePrivateProfileStructW_Thunk: Pointer = @ResolveThunk;
  _WriteProfileSectionW_Thunk: Pointer = @ResolveThunk;
  _WriteProfileStringW_Thunk: Pointer = @ResolveThunk;
  _auxGetDevCapsW_Thunk: Pointer = @ResolveThunk;
  _capCreateCaptureWindowW_Thunk: Pointer = @ResolveThunk;
  _capGetDriverDescriptionW_Thunk: Pointer = @ResolveThunk;
  _joyGetDevCapsW_Thunk: Pointer = @ResolveThunk;
  _lstrcatW_Thunk: Pointer = @ResolveThunk;
  _lstrcmpW_Thunk: Pointer = @ResolveThunk;
  _lstrcmpiW_Thunk: Pointer = @ResolveThunk;
  _lstrcpyW_Thunk: Pointer = @ResolveThunk;
  _lstrcpynW_Thunk: Pointer = @ResolveThunk;
  _lstrlenW_Thunk: Pointer = @ResolveThunk;
  _mciGetDeviceIDW_Thunk: Pointer = @ResolveThunk;
  _mciGetErrorStringW_Thunk: Pointer = @ResolveThunk;
  _mciSendCommandW_Thunk: Pointer = @ResolveThunk;
  _mciSendStringW_Thunk: Pointer = @ResolveThunk;
  _midiInGetDevCapsW_Thunk: Pointer = @ResolveThunk;
  _midiInGetErrorTextW_Thunk: Pointer = @ResolveThunk;
  _midiOutGetDevCapsW_Thunk: Pointer = @ResolveThunk;
  _midiOutGetErrorTextW_Thunk: Pointer = @ResolveThunk;
  _mixerGetControlDetailsW_Thunk: Pointer = @ResolveThunk;
  _mixerGetDevCapsW_Thunk: Pointer = @ResolveThunk;
  _mixerGetLineControlsW_Thunk: Pointer = @ResolveThunk;
  _mixerGetLineInfoW_Thunk: Pointer = @ResolveThunk;
  _mmioInstallIOProcW_Thunk: Pointer = @ResolveThunk;
  _mmioOpenW_Thunk: Pointer = @ResolveThunk;
  _mmioRenameW_Thunk: Pointer = @ResolveThunk;
  _mmioStringToFOURCCW_Thunk: Pointer = @ResolveThunk;
  _sndPlaySoundW_Thunk: Pointer = @ResolveThunk;
  _waveInGetDevCapsW_Thunk: Pointer = @ResolveThunk;
  _waveInGetErrorTextW_Thunk: Pointer = @ResolveThunk;
  _waveOutGetDevCapsW_Thunk: Pointer = @ResolveThunk;
  _waveOutGetErrorTextW_Thunk: Pointer = @ResolveThunk;
  _wsprintfW_Thunk: Pointer = @ResolveThunk;
  _wvsprintfW_Thunk: Pointer = @ResolveThunk;
{$ENDREGION}

// These thunk functions get inserted into the module's import table by the
// PatchImports procedure during unit initialization. When code in the program
// calls any API function, these thunks get called instead. The thunks then call
// ResolveThunk to redirect control to the correct function, which will be
// either the real API function or an override function. Override a function by
// setting the corresponding Unicows_X function pointer, declared in this unit's
// interface section. These thunks do not get inserted into the import table in
// Windows NT, so the API functions cannot be overridden in that case since
// these thunks never get called.
{$REGION ' Thunk implementations '}
procedure AcquireCredentialsHandleW_Thunk;
asm
  mov eax, fnAcquireCredentialsHandleW
  lea edx, _AcquireCredentialsHandleW_Thunk
  jmp _AcquireCredentialsHandleW_Thunk
end;

procedure AddAtomW_Thunk;
asm
  mov eax, fnAddAtomW
  lea edx, _AddAtomW_Thunk
  jmp _AddAtomW_Thunk
end;

procedure AddFontResourceW_Thunk;
asm
  mov eax, fnAddFontResourceW
  lea edx, _AddFontResourceW_Thunk
  jmp _AddFontResourceW_Thunk
end;

procedure AddJobW_Thunk;
asm
  mov eax, fnAddJobW
  lea edx, _AddJobW_Thunk
  jmp _AddJobW_Thunk
end;

procedure AddMonitorW_Thunk;
asm
  mov eax, fnAddMonitorW
  lea edx, _AddMonitorW_Thunk
  jmp _AddMonitorW_Thunk
end;

procedure AddPortW_Thunk;
asm
  mov eax, fnAddPortW
  lea edx, _AddPortW_Thunk
  jmp _AddPortW_Thunk
end;

procedure AddPrintProcessorW_Thunk;
asm
  mov eax, fnAddPrintProcessorW
  lea edx, _AddPrintProcessorW_Thunk
  jmp _AddPrintProcessorW_Thunk
end;

procedure AddPrintProvidorW_Thunk;
asm
  mov eax, fnAddPrintProvidorW
  lea edx, _AddPrintProvidorW_Thunk
  jmp _AddPrintProvidorW_Thunk
end;

procedure AddPrinterDriverW_Thunk;
asm
  mov eax, fnAddPrinterDriverW
  lea edx, _AddPrinterDriverW_Thunk
  jmp _AddPrinterDriverW_Thunk
end;

procedure AddPrinterW_Thunk;
asm
  mov eax, fnAddPrinterW
  lea edx, _AddPrinterW_Thunk
  jmp _AddPrinterW_Thunk
end;

procedure AdvancedDocumentPropertiesW_Thunk;
asm
  mov eax, fnAdvancedDocumentPropertiesW
  lea edx, _AdvancedDocumentPropertiesW_Thunk
  jmp _AdvancedDocumentPropertiesW_Thunk
end;

procedure AppendMenuW_Thunk;
asm
  mov eax, fnAppendMenuW
  lea edx, _AppendMenuW_Thunk
  jmp _AppendMenuW_Thunk
end;

procedure BeginUpdateResourceA_Thunk;
asm
  mov eax, fnBeginUpdateResourceA
  lea edx, _BeginUpdateResourceA_Thunk
  jmp _BeginUpdateResourceA_Thunk
end;

procedure BeginUpdateResourceW_Thunk;
asm
  mov eax, fnBeginUpdateResourceW
  lea edx, _BeginUpdateResourceW_Thunk
  jmp _BeginUpdateResourceW_Thunk
end;

procedure BroadcastSystemMessageW_Thunk;
asm
  mov eax, fnBroadcastSystemMessageW
  lea edx, _BroadcastSystemMessageW_Thunk
  jmp _BroadcastSystemMessageW_Thunk
end;

procedure BuildCommDCBAndTimeoutsW_Thunk;
asm
  mov eax, fnBuildCommDCBAndTimeoutsW
  lea edx, _BuildCommDCBAndTimeoutsW_Thunk
  jmp _BuildCommDCBAndTimeoutsW_Thunk
end;

procedure BuildCommDCBW_Thunk;
asm
  mov eax, fnBuildCommDCBW
  lea edx, _BuildCommDCBW_Thunk
  jmp _BuildCommDCBW_Thunk
end;

procedure CallMsgFilterW_Thunk;
asm
  mov eax, fnCallMsgFilterW
  lea edx, _CallMsgFilterW_Thunk
  jmp _CallMsgFilterW_Thunk
end;

procedure CallNamedPipeW_Thunk;
asm
  mov eax, fnCallNamedPipeW
  lea edx, _CallNamedPipeW_Thunk
  jmp _CallNamedPipeW_Thunk
end;

procedure CallWindowProcA_Thunk;
asm
  mov eax, fnCallWindowProcA
  lea edx, _CallWindowProcA_Thunk
  jmp _CallWindowProcA_Thunk
end;

procedure CallWindowProcW_Thunk;
asm
  mov eax, fnCallWindowProcW
  lea edx, _CallWindowProcW_Thunk
  jmp _CallWindowProcW_Thunk
end;

procedure ChangeDisplaySettingsExW_Thunk;
asm
  mov eax, fnChangeDisplaySettingsExW
  lea edx, _ChangeDisplaySettingsExW_Thunk
  jmp _ChangeDisplaySettingsExW_Thunk
end;

procedure ChangeDisplaySettingsW_Thunk;
asm
  mov eax, fnChangeDisplaySettingsW
  lea edx, _ChangeDisplaySettingsW_Thunk
  jmp _ChangeDisplaySettingsW_Thunk
end;

procedure ChangeMenuW_Thunk;
asm
  mov eax, fnChangeMenuW
  lea edx, _ChangeMenuW_Thunk
  jmp _ChangeMenuW_Thunk
end;

procedure CharLowerBuffW_Thunk;
asm
  mov eax, fnCharLowerBuffW
  lea edx, _CharLowerBuffW_Thunk
  jmp _CharLowerBuffW_Thunk
end;

procedure CharLowerW_Thunk;
asm
  mov eax, fnCharLowerW
  lea edx, _CharLowerW_Thunk
  jmp _CharLowerW_Thunk
end;

procedure CharNextW_Thunk;
asm
  mov eax, fnCharNextW
  lea edx, _CharNextW_Thunk
  jmp _CharNextW_Thunk
end;

procedure CharPrevW_Thunk;
asm
  mov eax, fnCharPrevW
  lea edx, _CharPrevW_Thunk
  jmp _CharPrevW_Thunk
end;

procedure CharToOemBuffW_Thunk;
asm
  mov eax, fnCharToOemBuffW
  lea edx, _CharToOemBuffW_Thunk
  jmp _CharToOemBuffW_Thunk
end;

procedure CharToOemW_Thunk;
asm
  mov eax, fnCharToOemW
  lea edx, _CharToOemW_Thunk
  jmp _CharToOemW_Thunk
end;

procedure CharUpperBuffW_Thunk;
asm
  mov eax, fnCharUpperBuffW
  lea edx, _CharUpperBuffW_Thunk
  jmp _CharUpperBuffW_Thunk
end;

procedure CharUpperW_Thunk;
asm
  mov eax, fnCharUpperW
  lea edx, _CharUpperW_Thunk
  jmp _CharUpperW_Thunk
end;

procedure ChooseColorW_Thunk;
asm
  mov eax, fnChooseColorW
  lea edx, _ChooseColorW_Thunk
  jmp _ChooseColorW_Thunk
end;

procedure ChooseFontW_Thunk;
asm
  mov eax, fnChooseFontW
  lea edx, _ChooseFontW_Thunk
  jmp _ChooseFontW_Thunk
end;

procedure CommConfigDialogW_Thunk;
asm
  mov eax, fnCommConfigDialogW
  lea edx, _CommConfigDialogW_Thunk
  jmp _CommConfigDialogW_Thunk
end;

procedure CompareStringW_Thunk;
asm
  mov eax, fnCompareStringW
  lea edx, _CompareStringW_Thunk
  jmp _CompareStringW_Thunk
end;

procedure ConfigurePortW_Thunk;
asm
  mov eax, fnConfigurePortW
  lea edx, _ConfigurePortW_Thunk
  jmp _ConfigurePortW_Thunk
end;

procedure CopyAcceleratorTableW_Thunk;
asm
  mov eax, fnCopyAcceleratorTableW
  lea edx, _CopyAcceleratorTableW_Thunk
  jmp _CopyAcceleratorTableW_Thunk
end;

procedure CopyEnhMetaFileW_Thunk;
asm
  mov eax, fnCopyEnhMetaFileW
  lea edx, _CopyEnhMetaFileW_Thunk
  jmp _CopyEnhMetaFileW_Thunk
end;

procedure CopyFileExW_Thunk;
asm
  mov eax, fnCopyFileExW
  lea edx, _CopyFileExW_Thunk
  jmp _CopyFileExW_Thunk
end;

procedure CopyFileW_Thunk;
asm
  mov eax, fnCopyFileW
  lea edx, _CopyFileW_Thunk
  jmp _CopyFileW_Thunk
end;

procedure CopyMetaFileW_Thunk;
asm
  mov eax, fnCopyMetaFileW
  lea edx, _CopyMetaFileW_Thunk
  jmp _CopyMetaFileW_Thunk
end;

procedure CreateAcceleratorTableW_Thunk;
asm
  mov eax, fnCreateAcceleratorTableW
  lea edx, _CreateAcceleratorTableW_Thunk
  jmp _CreateAcceleratorTableW_Thunk
end;

procedure CreateColorSpaceW_Thunk;
asm
  mov eax, fnCreateColorSpaceW
  lea edx, _CreateColorSpaceW_Thunk
  jmp _CreateColorSpaceW_Thunk
end;

procedure CreateDCW_Thunk;
asm
  mov eax, fnCreateDCW
  lea edx, _CreateDCW_Thunk
  jmp _CreateDCW_Thunk
end;

procedure CreateDialogIndirectParamW_Thunk;
asm
  mov eax, fnCreateDialogIndirectParamW
  lea edx, _CreateDialogIndirectParamW_Thunk
  jmp _CreateDialogIndirectParamW_Thunk
end;

procedure CreateDialogParamW_Thunk;
asm
  mov eax, fnCreateDialogParamW
  lea edx, _CreateDialogParamW_Thunk
  jmp _CreateDialogParamW_Thunk
end;

procedure CreateDirectoryExW_Thunk;
asm
  mov eax, fnCreateDirectoryExW
  lea edx, _CreateDirectoryExW_Thunk
  jmp _CreateDirectoryExW_Thunk
end;

procedure CreateDirectoryW_Thunk;
asm
  mov eax, fnCreateDirectoryW
  lea edx, _CreateDirectoryW_Thunk
  jmp _CreateDirectoryW_Thunk
end;

procedure CreateEnhMetaFileW_Thunk;
asm
  mov eax, fnCreateEnhMetaFileW
  lea edx, _CreateEnhMetaFileW_Thunk
  jmp _CreateEnhMetaFileW_Thunk
end;

procedure CreateEventW_Thunk;
asm
  mov eax, fnCreateEventW
  lea edx, _CreateEventW_Thunk
  jmp _CreateEventW_Thunk
end;

procedure CreateFileMappingW_Thunk;
asm
  mov eax, fnCreateFileMappingW
  lea edx, _CreateFileMappingW_Thunk
  jmp _CreateFileMappingW_Thunk
end;

procedure CreateFileW_Thunk;
asm
  mov eax, fnCreateFileW
  lea edx, _CreateFileW_Thunk
  jmp _CreateFileW_Thunk
end;

procedure CreateFontIndirectW_Thunk;
asm
  mov eax, fnCreateFontIndirectW
  lea edx, _CreateFontIndirectW_Thunk
  jmp _CreateFontIndirectW_Thunk
end;

procedure CreateFontW_Thunk;
asm
  mov eax, fnCreateFontW
  lea edx, _CreateFontW_Thunk
  jmp _CreateFontW_Thunk
end;

procedure CreateICW_Thunk;
asm
  mov eax, fnCreateICW
  lea edx, _CreateICW_Thunk
  jmp _CreateICW_Thunk
end;

procedure CreateMDIWindowW_Thunk;
asm
  mov eax, fnCreateMDIWindowW
  lea edx, _CreateMDIWindowW_Thunk
  jmp _CreateMDIWindowW_Thunk
end;

procedure CreateMailslotW_Thunk;
asm
  mov eax, fnCreateMailslotW
  lea edx, _CreateMailslotW_Thunk
  jmp _CreateMailslotW_Thunk
end;

procedure CreateMetaFileW_Thunk;
asm
  mov eax, fnCreateMetaFileW
  lea edx, _CreateMetaFileW_Thunk
  jmp _CreateMetaFileW_Thunk
end;

procedure CreateMutexW_Thunk;
asm
  mov eax, fnCreateMutexW
  lea edx, _CreateMutexW_Thunk
  jmp _CreateMutexW_Thunk
end;

procedure CreateNamedPipeW_Thunk;
asm
  mov eax, fnCreateNamedPipeW
  lea edx, _CreateNamedPipeW_Thunk
  jmp _CreateNamedPipeW_Thunk
end;

procedure CreateProcessW_Thunk;
asm
  mov eax, fnCreateProcessW
  lea edx, _CreateProcessW_Thunk
  jmp _CreateProcessW_Thunk
end;

procedure CreateScalableFontResourceW_Thunk;
asm
  mov eax, fnCreateScalableFontResourceW
  lea edx, _CreateScalableFontResourceW_Thunk
  jmp _CreateScalableFontResourceW_Thunk
end;

procedure CreateSemaphoreW_Thunk;
asm
  mov eax, fnCreateSemaphoreW
  lea edx, _CreateSemaphoreW_Thunk
  jmp _CreateSemaphoreW_Thunk
end;

procedure CreateStdAccessibleProxyW_Thunk;
asm
  mov eax, fnCreateStdAccessibleProxyW
  lea edx, _CreateStdAccessibleProxyW_Thunk
  jmp _CreateStdAccessibleProxyW_Thunk
end;

procedure CreateWaitableTimerW_Thunk;
asm
  mov eax, fnCreateWaitableTimerW
  lea edx, _CreateWaitableTimerW_Thunk
  jmp _CreateWaitableTimerW_Thunk
end;

procedure CreateWindowExW_Thunk;
asm
  mov eax, fnCreateWindowExW
  lea edx, _CreateWindowExW_Thunk
  jmp _CreateWindowExW_Thunk
end;

procedure CryptAcquireContextW_Thunk;
asm
  mov eax, fnCryptAcquireContextW
  lea edx, _CryptAcquireContextW_Thunk
  jmp _CryptAcquireContextW_Thunk
end;

procedure CryptEnumProviderTypesW_Thunk;
asm
  mov eax, fnCryptEnumProviderTypesW
  lea edx, _CryptEnumProviderTypesW_Thunk
  jmp _CryptEnumProviderTypesW_Thunk
end;

procedure CryptEnumProvidersW_Thunk;
asm
  mov eax, fnCryptEnumProvidersW
  lea edx, _CryptEnumProvidersW_Thunk
  jmp _CryptEnumProvidersW_Thunk
end;

procedure CryptGetDefaultProviderW_Thunk;
asm
  mov eax, fnCryptGetDefaultProviderW
  lea edx, _CryptGetDefaultProviderW_Thunk
  jmp _CryptGetDefaultProviderW_Thunk
end;

procedure CryptSetProviderExW_Thunk;
asm
  mov eax, fnCryptSetProviderExW
  lea edx, _CryptSetProviderExW_Thunk
  jmp _CryptSetProviderExW_Thunk
end;

procedure CryptSetProviderW_Thunk;
asm
  mov eax, fnCryptSetProviderW
  lea edx, _CryptSetProviderW_Thunk
  jmp _CryptSetProviderW_Thunk
end;

procedure CryptSignHashW_Thunk;
asm
  mov eax, fnCryptSignHashW
  lea edx, _CryptSignHashW_Thunk
  jmp _CryptSignHashW_Thunk
end;

procedure CryptVerifySignatureW_Thunk;
asm
  mov eax, fnCryptVerifySignatureW
  lea edx, _CryptVerifySignatureW_Thunk
  jmp _CryptVerifySignatureW_Thunk
end;

procedure DdeConnect_Thunk;
asm
  mov eax, fnDdeConnect
  lea edx, _DdeConnect_Thunk
  jmp _DdeConnect_Thunk
end;

procedure DdeConnectList_Thunk;
asm
  mov eax, fnDdeConnectList
  lea edx, _DdeConnectList_Thunk
  jmp _DdeConnectList_Thunk
end;

procedure DdeCreateStringHandleW_Thunk;
asm
  mov eax, fnDdeCreateStringHandleW
  lea edx, _DdeCreateStringHandleW_Thunk
  jmp _DdeCreateStringHandleW_Thunk
end;

procedure DdeInitializeW_Thunk;
asm
  mov eax, fnDdeInitializeW
  lea edx, _DdeInitializeW_Thunk
  jmp _DdeInitializeW_Thunk
end;

procedure DdeQueryConvInfo_Thunk;
asm
  mov eax, fnDdeQueryConvInfo
  lea edx, _DdeQueryConvInfo_Thunk
  jmp _DdeQueryConvInfo_Thunk
end;

procedure DdeQueryStringW_Thunk;
asm
  mov eax, fnDdeQueryStringW
  lea edx, _DdeQueryStringW_Thunk
  jmp _DdeQueryStringW_Thunk
end;

procedure DefDlgProcW_Thunk;
asm
  mov eax, fnDefDlgProcW
  lea edx, _DefDlgProcW_Thunk
  jmp _DefDlgProcW_Thunk
end;

procedure DefFrameProcW_Thunk;
asm
  mov eax, fnDefFrameProcW
  lea edx, _DefFrameProcW_Thunk
  jmp _DefFrameProcW_Thunk
end;

procedure DefMDIChildProcW_Thunk;
asm
  mov eax, fnDefMDIChildProcW
  lea edx, _DefMDIChildProcW_Thunk
  jmp _DefMDIChildProcW_Thunk
end;

procedure DefWindowProcW_Thunk;
asm
  mov eax, fnDefWindowProcW
  lea edx, _DefWindowProcW_Thunk
  jmp _DefWindowProcW_Thunk
end;

procedure DeleteFileW_Thunk;
asm
  mov eax, fnDeleteFileW
  lea edx, _DeleteFileW_Thunk
  jmp _DeleteFileW_Thunk
end;

procedure DeleteMonitorW_Thunk;
asm
  mov eax, fnDeleteMonitorW
  lea edx, _DeleteMonitorW_Thunk
  jmp _DeleteMonitorW_Thunk
end;

procedure DeletePortW_Thunk;
asm
  mov eax, fnDeletePortW
  lea edx, _DeletePortW_Thunk
  jmp _DeletePortW_Thunk
end;

procedure DeletePrintProcessorW_Thunk;
asm
  mov eax, fnDeletePrintProcessorW
  lea edx, _DeletePrintProcessorW_Thunk
  jmp _DeletePrintProcessorW_Thunk
end;

procedure DeletePrintProvidorW_Thunk;
asm
  mov eax, fnDeletePrintProvidorW
  lea edx, _DeletePrintProvidorW_Thunk
  jmp _DeletePrintProvidorW_Thunk
end;

procedure DeletePrinterDriverW_Thunk;
asm
  mov eax, fnDeletePrinterDriverW
  lea edx, _DeletePrinterDriverW_Thunk
  jmp _DeletePrinterDriverW_Thunk
end;

procedure DeviceCapabilitiesW_Thunk;
asm
  mov eax, fnDeviceCapabilitiesW
  lea edx, _DeviceCapabilitiesW_Thunk
  jmp _DeviceCapabilitiesW_Thunk
end;

procedure DialogBoxIndirectParamW_Thunk;
asm
  mov eax, fnDialogBoxIndirectParamW
  lea edx, _DialogBoxIndirectParamW_Thunk
  jmp _DialogBoxIndirectParamW_Thunk
end;

procedure DialogBoxParamW_Thunk;
asm
  mov eax, fnDialogBoxParamW
  lea edx, _DialogBoxParamW_Thunk
  jmp _DialogBoxParamW_Thunk
end;

procedure DispatchMessageW_Thunk;
asm
  mov eax, fnDispatchMessageW
  lea edx, _DispatchMessageW_Thunk
  jmp _DispatchMessageW_Thunk
end;

procedure DlgDirListComboBoxW_Thunk;
asm
  mov eax, fnDlgDirListComboBoxW
  lea edx, _DlgDirListComboBoxW_Thunk
  jmp _DlgDirListComboBoxW_Thunk
end;

procedure DlgDirListW_Thunk;
asm
  mov eax, fnDlgDirListW
  lea edx, _DlgDirListW_Thunk
  jmp _DlgDirListW_Thunk
end;

procedure DlgDirSelectComboBoxExW_Thunk;
asm
  mov eax, fnDlgDirSelectComboBoxExW
  lea edx, _DlgDirSelectComboBoxExW_Thunk
  jmp _DlgDirSelectComboBoxExW_Thunk
end;

procedure DlgDirSelectExW_Thunk;
asm
  mov eax, fnDlgDirSelectExW
  lea edx, _DlgDirSelectExW_Thunk
  jmp _DlgDirSelectExW_Thunk
end;

procedure DocumentPropertiesW_Thunk;
asm
  mov eax, fnDocumentPropertiesW
  lea edx, _DocumentPropertiesW_Thunk
  jmp _DocumentPropertiesW_Thunk
end;

procedure DragQueryFileW_Thunk;
asm
  mov eax, fnDragQueryFileW
  lea edx, _DragQueryFileW_Thunk
  jmp _DragQueryFileW_Thunk
end;

procedure DrawStateW_Thunk;
asm
  mov eax, fnDrawStateW
  lea edx, _DrawStateW_Thunk
  jmp _DrawStateW_Thunk
end;

procedure DrawTextExW_Thunk;
asm
  mov eax, fnDrawTextExW
  lea edx, _DrawTextExW_Thunk
  jmp _DrawTextExW_Thunk
end;

procedure DrawTextW_Thunk;
asm
  mov eax, fnDrawTextW
  lea edx, _DrawTextW_Thunk
  jmp _DrawTextW_Thunk
end;

procedure EnableWindow_Thunk;
asm
  mov eax, fnEnableWindow
  lea edx, _EnableWindow_Thunk
  jmp _EnableWindow_Thunk
end;

procedure EndUpdateResourceA_Thunk;
asm
  mov eax, fnEndUpdateResourceA
  lea edx, _EndUpdateResourceA_Thunk
  jmp _EndUpdateResourceA_Thunk
end;

procedure EndUpdateResourceW_Thunk;
asm
  mov eax, fnEndUpdateResourceW
  lea edx, _EndUpdateResourceW_Thunk
  jmp _EndUpdateResourceW_Thunk
end;

procedure EnumCalendarInfoExW_Thunk;
asm
  mov eax, fnEnumCalendarInfoExW
  lea edx, _EnumCalendarInfoExW_Thunk
  jmp _EnumCalendarInfoExW_Thunk
end;

procedure EnumCalendarInfoW_Thunk;
asm
  mov eax, fnEnumCalendarInfoW
  lea edx, _EnumCalendarInfoW_Thunk
  jmp _EnumCalendarInfoW_Thunk
end;

procedure EnumClipboardFormats_Thunk;
asm
  mov eax, fnEnumClipboardFormats
  lea edx, _EnumClipboardFormats_Thunk
  jmp _EnumClipboardFormats_Thunk
end;

procedure EnumDateFormatsExW_Thunk;
asm
  mov eax, fnEnumDateFormatsExW
  lea edx, _EnumDateFormatsExW_Thunk
  jmp _EnumDateFormatsExW_Thunk
end;

procedure EnumDateFormatsW_Thunk;
asm
  mov eax, fnEnumDateFormatsW
  lea edx, _EnumDateFormatsW_Thunk
  jmp _EnumDateFormatsW_Thunk
end;

procedure EnumDisplayDevicesW_Thunk;
asm
  mov eax, fnEnumDisplayDevicesW
  lea edx, _EnumDisplayDevicesW_Thunk
  jmp _EnumDisplayDevicesW_Thunk
end;

procedure EnumDisplaySettingsExW_Thunk;
asm
  mov eax, fnEnumDisplaySettingsExW
  lea edx, _EnumDisplaySettingsExW_Thunk
  jmp _EnumDisplaySettingsExW_Thunk
end;

procedure EnumDisplaySettingsW_Thunk;
asm
  mov eax, fnEnumDisplaySettingsW
  lea edx, _EnumDisplaySettingsW_Thunk
  jmp _EnumDisplaySettingsW_Thunk
end;

procedure EnumFontFamiliesExW_Thunk;
asm
  mov eax, fnEnumFontFamiliesExW
  lea edx, _EnumFontFamiliesExW_Thunk
  jmp _EnumFontFamiliesExW_Thunk
end;

procedure EnumFontFamiliesW_Thunk;
asm
  mov eax, fnEnumFontFamiliesW
  lea edx, _EnumFontFamiliesW_Thunk
  jmp _EnumFontFamiliesW_Thunk
end;

procedure EnumFontsW_Thunk;
asm
  mov eax, fnEnumFontsW
  lea edx, _EnumFontsW_Thunk
  jmp _EnumFontsW_Thunk
end;

procedure EnumICMProfilesW_Thunk;
asm
  mov eax, fnEnumICMProfilesW
  lea edx, _EnumICMProfilesW_Thunk
  jmp _EnumICMProfilesW_Thunk
end;

procedure EnumMonitorsW_Thunk;
asm
  mov eax, fnEnumMonitorsW
  lea edx, _EnumMonitorsW_Thunk
  jmp _EnumMonitorsW_Thunk
end;

procedure EnumPortsW_Thunk;
asm
  mov eax, fnEnumPortsW
  lea edx, _EnumPortsW_Thunk
  jmp _EnumPortsW_Thunk
end;

procedure EnumPrintProcessorDatatypesW_Thunk;
asm
  mov eax, fnEnumPrintProcessorDatatypesW
  lea edx, _EnumPrintProcessorDatatypesW_Thunk
  jmp _EnumPrintProcessorDatatypesW_Thunk
end;

procedure EnumPrintProcessorsW_Thunk;
asm
  mov eax, fnEnumPrintProcessorsW
  lea edx, _EnumPrintProcessorsW_Thunk
  jmp _EnumPrintProcessorsW_Thunk
end;

procedure EnumPrinterDriversW_Thunk;
asm
  mov eax, fnEnumPrinterDriversW
  lea edx, _EnumPrinterDriversW_Thunk
  jmp _EnumPrinterDriversW_Thunk
end;

procedure EnumPrintersW_Thunk;
asm
  mov eax, fnEnumPrintersW
  lea edx, _EnumPrintersW_Thunk
  jmp _EnumPrintersW_Thunk
end;

procedure EnumPropsA_Thunk;
asm
  mov eax, fnEnumPropsA
  lea edx, _EnumPropsA_Thunk
  jmp _EnumPropsA_Thunk
end;

procedure EnumPropsExA_Thunk;
asm
  mov eax, fnEnumPropsExA
  lea edx, _EnumPropsExA_Thunk
  jmp _EnumPropsExA_Thunk
end;

procedure EnumPropsExW_Thunk;
asm
  mov eax, fnEnumPropsExW
  lea edx, _EnumPropsExW_Thunk
  jmp _EnumPropsExW_Thunk
end;

procedure EnumPropsW_Thunk;
asm
  mov eax, fnEnumPropsW
  lea edx, _EnumPropsW_Thunk
  jmp _EnumPropsW_Thunk
end;

procedure EnumSystemCodePagesW_Thunk;
asm
  mov eax, fnEnumSystemCodePagesW
  lea edx, _EnumSystemCodePagesW_Thunk
  jmp _EnumSystemCodePagesW_Thunk
end;

procedure EnumSystemLocalesW_Thunk;
asm
  mov eax, fnEnumSystemLocalesW
  lea edx, _EnumSystemLocalesW_Thunk
  jmp _EnumSystemLocalesW_Thunk
end;

procedure EnumTimeFormatsW_Thunk;
asm
  mov eax, fnEnumTimeFormatsW
  lea edx, _EnumTimeFormatsW_Thunk
  jmp _EnumTimeFormatsW_Thunk
end;

procedure EnumerateSecurityPackagesW_Thunk;
asm
  mov eax, fnEnumerateSecurityPackagesW
  lea edx, _EnumerateSecurityPackagesW_Thunk
  jmp _EnumerateSecurityPackagesW_Thunk
end;

procedure ExpandEnvironmentStringsW_Thunk;
asm
  mov eax, fnExpandEnvironmentStringsW
  lea edx, _ExpandEnvironmentStringsW_Thunk
  jmp _ExpandEnvironmentStringsW_Thunk
end;

procedure ExtTextOutW_Thunk;
asm
  mov eax, fnExtTextOutW
  lea edx, _ExtTextOutW_Thunk
  jmp _ExtTextOutW_Thunk
end;

procedure ExtractIconExW_Thunk;
asm
  mov eax, fnExtractIconExW
  lea edx, _ExtractIconExW_Thunk
  jmp _ExtractIconExW_Thunk
end;

procedure ExtractIconW_Thunk;
asm
  mov eax, fnExtractIconW
  lea edx, _ExtractIconW_Thunk
  jmp _ExtractIconW_Thunk
end;

procedure FatalAppExitW_Thunk;
asm
  mov eax, fnFatalAppExitW
  lea edx, _FatalAppExitW_Thunk
  jmp _FatalAppExitW_Thunk
end;

procedure FillConsoleOutputCharacterW_Thunk;
asm
  mov eax, fnFillConsoleOutputCharacterW
  lea edx, _FillConsoleOutputCharacterW_Thunk
  jmp _FillConsoleOutputCharacterW_Thunk
end;

procedure FindAtomW_Thunk;
asm
  mov eax, fnFindAtomW
  lea edx, _FindAtomW_Thunk
  jmp _FindAtomW_Thunk
end;

procedure FindExecutableW_Thunk;
asm
  mov eax, fnFindExecutableW
  lea edx, _FindExecutableW_Thunk
  jmp _FindExecutableW_Thunk
end;

procedure FindFirstChangeNotificationW_Thunk;
asm
  mov eax, fnFindFirstChangeNotificationW
  lea edx, _FindFirstChangeNotificationW_Thunk
  jmp _FindFirstChangeNotificationW_Thunk
end;

procedure FindFirstFileW_Thunk;
asm
  mov eax, fnFindFirstFileW
  lea edx, _FindFirstFileW_Thunk
  jmp _FindFirstFileW_Thunk
end;

procedure FindNextFileW_Thunk;
asm
  mov eax, fnFindNextFileW
  lea edx, _FindNextFileW_Thunk
  jmp _FindNextFileW_Thunk
end;

procedure FindResourceExW_Thunk;
asm
  mov eax, fnFindResourceExW
  lea edx, _FindResourceExW_Thunk
  jmp _FindResourceExW_Thunk
end;

procedure FindResourceW_Thunk;
asm
  mov eax, fnFindResourceW
  lea edx, _FindResourceW_Thunk
  jmp _FindResourceW_Thunk
end;

procedure FindTextW_Thunk;
asm
  mov eax, fnFindTextW
  lea edx, _FindTextW_Thunk
  jmp _FindTextW_Thunk
end;

procedure FindWindowExW_Thunk;
asm
  mov eax, fnFindWindowExW
  lea edx, _FindWindowExW_Thunk
  jmp _FindWindowExW_Thunk
end;

procedure FindWindowW_Thunk;
asm
  mov eax, fnFindWindowW
  lea edx, _FindWindowW_Thunk
  jmp _FindWindowW_Thunk
end;

procedure FormatMessageW_Thunk;
asm
  mov eax, fnFormatMessageW
  lea edx, _FormatMessageW_Thunk
  jmp _FormatMessageW_Thunk
end;

procedure FreeContextBuffer_Thunk;
asm
  mov eax, fnFreeContextBuffer
  lea edx, _FreeContextBuffer_Thunk
  jmp _FreeContextBuffer_Thunk
end;

procedure FreeEnvironmentStringsW_Thunk;
asm
  mov eax, fnFreeEnvironmentStringsW
  lea edx, _FreeEnvironmentStringsW_Thunk
  jmp _FreeEnvironmentStringsW_Thunk
end;

procedure GetAltTabInfoW_Thunk;
asm
  mov eax, fnGetAltTabInfoW
  lea edx, _GetAltTabInfoW_Thunk
  jmp _GetAltTabInfoW_Thunk
end;

procedure GetAtomNameW_Thunk;
asm
  mov eax, fnGetAtomNameW
  lea edx, _GetAtomNameW_Thunk
  jmp _GetAtomNameW_Thunk
end;

procedure GetCPInfo_Thunk;
asm
  mov eax, fnGetCPInfo
  lea edx, _GetCPInfo_Thunk
  jmp _GetCPInfo_Thunk
end;

procedure GetCPInfoExW_Thunk;
asm
  mov eax, fnGetCPInfoExW
  lea edx, _GetCPInfoExW_Thunk
  jmp _GetCPInfoExW_Thunk
end;

procedure GetCalendarInfoW_Thunk;
asm
  mov eax, fnGetCalendarInfoW
  lea edx, _GetCalendarInfoW_Thunk
  jmp _GetCalendarInfoW_Thunk
end;

procedure GetCharABCWidthsFloatW_Thunk;
asm
  mov eax, fnGetCharABCWidthsFloatW
  lea edx, _GetCharABCWidthsFloatW_Thunk
  jmp _GetCharABCWidthsFloatW_Thunk
end;

procedure GetCharABCWidthsW_Thunk;
asm
  mov eax, fnGetCharABCWidthsW
  lea edx, _GetCharABCWidthsW_Thunk
  jmp _GetCharABCWidthsW_Thunk
end;

procedure GetCharWidth32W_Thunk;
asm
  mov eax, fnGetCharWidth32W
  lea edx, _GetCharWidth32W_Thunk
  jmp _GetCharWidth32W_Thunk
end;

procedure GetCharWidthFloatW_Thunk;
asm
  mov eax, fnGetCharWidthFloatW
  lea edx, _GetCharWidthFloatW_Thunk
  jmp _GetCharWidthFloatW_Thunk
end;

procedure GetCharWidthW_Thunk;
asm
  mov eax, fnGetCharWidthW
  lea edx, _GetCharWidthW_Thunk
  jmp _GetCharWidthW_Thunk
end;

procedure GetCharacterPlacementW_Thunk;
asm
  mov eax, fnGetCharacterPlacementW
  lea edx, _GetCharacterPlacementW_Thunk
  jmp _GetCharacterPlacementW_Thunk
end;

procedure GetClassInfoExW_Thunk;
asm
  mov eax, fnGetClassInfoExW
  lea edx, _GetClassInfoExW_Thunk
  jmp _GetClassInfoExW_Thunk
end;

procedure GetClassInfoW_Thunk;
asm
  mov eax, fnGetClassInfoW
  lea edx, _GetClassInfoW_Thunk
  jmp _GetClassInfoW_Thunk
end;

procedure GetClassLongW_Thunk;
asm
  mov eax, fnGetClassLongW
  lea edx, _GetClassLongW_Thunk
  jmp _GetClassLongW_Thunk
end;

procedure GetClassNameW_Thunk;
asm
  mov eax, fnGetClassNameW
  lea edx, _GetClassNameW_Thunk
  jmp _GetClassNameW_Thunk
end;

procedure GetClipboardData_Thunk;
asm
  mov eax, fnGetClipboardData
  lea edx, _GetClipboardData_Thunk
  jmp _GetClipboardData_Thunk
end;

procedure GetClipboardFormatNameW_Thunk;
asm
  mov eax, fnGetClipboardFormatNameW
  lea edx, _GetClipboardFormatNameW_Thunk
  jmp _GetClipboardFormatNameW_Thunk
end;

procedure GetComputerNameW_Thunk;
asm
  mov eax, fnGetComputerNameW
  lea edx, _GetComputerNameW_Thunk
  jmp _GetComputerNameW_Thunk
end;

procedure GetConsoleTitleW_Thunk;
asm
  mov eax, fnGetConsoleTitleW
  lea edx, _GetConsoleTitleW_Thunk
  jmp _GetConsoleTitleW_Thunk
end;

procedure GetCurrencyFormatW_Thunk;
asm
  mov eax, fnGetCurrencyFormatW
  lea edx, _GetCurrencyFormatW_Thunk
  jmp _GetCurrencyFormatW_Thunk
end;

procedure GetCurrentDirectoryW_Thunk;
asm
  mov eax, fnGetCurrentDirectoryW
  lea edx, _GetCurrentDirectoryW_Thunk
  jmp _GetCurrentDirectoryW_Thunk
end;

procedure GetCurrentHwProfileW_Thunk;
asm
  mov eax, fnGetCurrentHwProfileW
  lea edx, _GetCurrentHwProfileW_Thunk
  jmp _GetCurrentHwProfileW_Thunk
end;

procedure GetDateFormatW_Thunk;
asm
  mov eax, fnGetDateFormatW
  lea edx, _GetDateFormatW_Thunk
  jmp _GetDateFormatW_Thunk
end;

procedure GetDefaultCommConfigW_Thunk;
asm
  mov eax, fnGetDefaultCommConfigW
  lea edx, _GetDefaultCommConfigW_Thunk
  jmp _GetDefaultCommConfigW_Thunk
end;

procedure GetDiskFreeSpaceExW_Thunk;
asm
  mov eax, fnGetDiskFreeSpaceExW
  lea edx, _GetDiskFreeSpaceExW_Thunk
  jmp _GetDiskFreeSpaceExW_Thunk
end;

procedure GetDiskFreeSpaceW_Thunk;
asm
  mov eax, fnGetDiskFreeSpaceW
  lea edx, _GetDiskFreeSpaceW_Thunk
  jmp _GetDiskFreeSpaceW_Thunk
end;

procedure GetDlgItemTextW_Thunk;
asm
  mov eax, fnGetDlgItemTextW
  lea edx, _GetDlgItemTextW_Thunk
  jmp _GetDlgItemTextW_Thunk
end;

procedure GetDriveTypeW_Thunk;
asm
  mov eax, fnGetDriveTypeW
  lea edx, _GetDriveTypeW_Thunk
  jmp _GetDriveTypeW_Thunk
end;

procedure GetEnhMetaFileDescriptionW_Thunk;
asm
  mov eax, fnGetEnhMetaFileDescriptionW
  lea edx, _GetEnhMetaFileDescriptionW_Thunk
  jmp _GetEnhMetaFileDescriptionW_Thunk
end;

procedure GetEnhMetaFileW_Thunk;
asm
  mov eax, fnGetEnhMetaFileW
  lea edx, _GetEnhMetaFileW_Thunk
  jmp _GetEnhMetaFileW_Thunk
end;

procedure GetEnvironmentStringsW_Thunk;
asm
  mov eax, fnGetEnvironmentStringsW
  lea edx, _GetEnvironmentStringsW_Thunk
  jmp _GetEnvironmentStringsW_Thunk
end;

procedure GetEnvironmentVariableW_Thunk;
asm
  mov eax, fnGetEnvironmentVariableW
  lea edx, _GetEnvironmentVariableW_Thunk
  jmp _GetEnvironmentVariableW_Thunk
end;

procedure GetFileAttributesExW_Thunk;
asm
  mov eax, fnGetFileAttributesExW
  lea edx, _GetFileAttributesExW_Thunk
  jmp _GetFileAttributesExW_Thunk
end;

procedure GetFileAttributesW_Thunk;
asm
  mov eax, fnGetFileAttributesW
  lea edx, _GetFileAttributesW_Thunk
  jmp _GetFileAttributesW_Thunk
end;

procedure GetFileTitleW_Thunk;
asm
  mov eax, fnGetFileTitleW
  lea edx, _GetFileTitleW_Thunk
  jmp _GetFileTitleW_Thunk
end;

procedure GetFileVersionInfoSizeW_Thunk;
asm
  mov eax, fnGetFileVersionInfoSizeW
  lea edx, _GetFileVersionInfoSizeW_Thunk
  jmp _GetFileVersionInfoSizeW_Thunk
end;

procedure GetFileVersionInfoW_Thunk;
asm
  mov eax, fnGetFileVersionInfoW
  lea edx, _GetFileVersionInfoW_Thunk
  jmp _GetFileVersionInfoW_Thunk
end;

procedure GetFullPathNameW_Thunk;
asm
  mov eax, fnGetFullPathNameW
  lea edx, _GetFullPathNameW_Thunk
  jmp _GetFullPathNameW_Thunk
end;

procedure GetGlyphOutlineW_Thunk;
asm
  mov eax, fnGetGlyphOutlineW
  lea edx, _GetGlyphOutlineW_Thunk
  jmp _GetGlyphOutlineW_Thunk
end;

procedure GetICMProfileW_Thunk;
asm
  mov eax, fnGetICMProfileW
  lea edx, _GetICMProfileW_Thunk
  jmp _GetICMProfileW_Thunk
end;

procedure GetJobW_Thunk;
asm
  mov eax, fnGetJobW
  lea edx, _GetJobW_Thunk
  jmp _GetJobW_Thunk
end;

procedure GetKerningPairsW_Thunk;
asm
  mov eax, fnGetKerningPairsW
  lea edx, _GetKerningPairsW_Thunk
  jmp _GetKerningPairsW_Thunk
end;

procedure GetKeyNameTextW_Thunk;
asm
  mov eax, fnGetKeyNameTextW
  lea edx, _GetKeyNameTextW_Thunk
  jmp _GetKeyNameTextW_Thunk
end;

procedure GetKeyboardLayoutNameW_Thunk;
asm
  mov eax, fnGetKeyboardLayoutNameW
  lea edx, _GetKeyboardLayoutNameW_Thunk
  jmp _GetKeyboardLayoutNameW_Thunk
end;

procedure GetLocaleInfoW_Thunk;
asm
  mov eax, fnGetLocaleInfoW
  lea edx, _GetLocaleInfoW_Thunk
  jmp _GetLocaleInfoW_Thunk
end;

procedure GetLogColorSpaceW_Thunk;
asm
  mov eax, fnGetLogColorSpaceW
  lea edx, _GetLogColorSpaceW_Thunk
  jmp _GetLogColorSpaceW_Thunk
end;

procedure GetLogicalDriveStringsW_Thunk;
asm
  mov eax, fnGetLogicalDriveStringsW
  lea edx, _GetLogicalDriveStringsW_Thunk
  jmp _GetLogicalDriveStringsW_Thunk
end;

procedure GetLongPathNameW_Thunk;
asm
  mov eax, fnGetLongPathNameW
  lea edx, _GetLongPathNameW_Thunk
  jmp _GetLongPathNameW_Thunk
end;

procedure GetMenuItemInfoW_Thunk;
asm
  mov eax, fnGetMenuItemInfoW
  lea edx, _GetMenuItemInfoW_Thunk
  jmp _GetMenuItemInfoW_Thunk
end;

procedure GetMenuStringW_Thunk;
asm
  mov eax, fnGetMenuStringW
  lea edx, _GetMenuStringW_Thunk
  jmp _GetMenuStringW_Thunk
end;

procedure GetMessageW_Thunk;
asm
  mov eax, fnGetMessageW
  lea edx, _GetMessageW_Thunk
  jmp _GetMessageW_Thunk
end;

procedure GetMetaFileW_Thunk;
asm
  mov eax, fnGetMetaFileW
  lea edx, _GetMetaFileW_Thunk
  jmp _GetMetaFileW_Thunk
end;

procedure GetModuleFileNameW_Thunk;
asm
  mov eax, fnGetModuleFileNameW
  lea edx, _GetModuleFileNameW_Thunk
  jmp _GetModuleFileNameW_Thunk
end;

procedure GetModuleHandleW_Thunk;
asm
  mov eax, fnGetModuleHandleW
  lea edx, _GetModuleHandleW_Thunk
  jmp _GetModuleHandleW_Thunk
end;

procedure GetMonitorInfoW_Thunk;
asm
  mov eax, fnGetMonitorInfoW
  lea edx, _GetMonitorInfoW_Thunk
  jmp _GetMonitorInfoW_Thunk
end;

procedure GetNamedPipeHandleStateW_Thunk;
asm
  mov eax, fnGetNamedPipeHandleStateW
  lea edx, _GetNamedPipeHandleStateW_Thunk
  jmp _GetNamedPipeHandleStateW_Thunk
end;

procedure GetNumberFormatW_Thunk;
asm
  mov eax, fnGetNumberFormatW
  lea edx, _GetNumberFormatW_Thunk
  jmp _GetNumberFormatW_Thunk
end;

procedure GetObjectW_Thunk;
asm
  mov eax, fnGetObjectW
  lea edx, _GetObjectW_Thunk
  jmp _GetObjectW_Thunk
end;

procedure GetOpenFileNamePreviewW_Thunk;
asm
  mov eax, fnGetOpenFileNamePreviewW
  lea edx, _GetOpenFileNamePreviewW_Thunk
  jmp _GetOpenFileNamePreviewW_Thunk
end;

procedure GetOpenFileNameW_Thunk;
asm
  mov eax, fnGetOpenFileNameW
  lea edx, _GetOpenFileNameW_Thunk
  jmp _GetOpenFileNameW_Thunk
end;

procedure GetOutlineTextMetricsW_Thunk;
asm
  mov eax, fnGetOutlineTextMetricsW
  lea edx, _GetOutlineTextMetricsW_Thunk
  jmp _GetOutlineTextMetricsW_Thunk
end;

procedure GetPrintProcessorDirectoryW_Thunk;
asm
  mov eax, fnGetPrintProcessorDirectoryW
  lea edx, _GetPrintProcessorDirectoryW_Thunk
  jmp _GetPrintProcessorDirectoryW_Thunk
end;

procedure GetPrinterDataW_Thunk;
asm
  mov eax, fnGetPrinterDataW
  lea edx, _GetPrinterDataW_Thunk
  jmp _GetPrinterDataW_Thunk
end;

procedure GetPrinterDriverDirectoryW_Thunk;
asm
  mov eax, fnGetPrinterDriverDirectoryW
  lea edx, _GetPrinterDriverDirectoryW_Thunk
  jmp _GetPrinterDriverDirectoryW_Thunk
end;

procedure GetPrinterDriverW_Thunk;
asm
  mov eax, fnGetPrinterDriverW
  lea edx, _GetPrinterDriverW_Thunk
  jmp _GetPrinterDriverW_Thunk
end;

procedure GetPrinterW_Thunk;
asm
  mov eax, fnGetPrinterW
  lea edx, _GetPrinterW_Thunk
  jmp _GetPrinterW_Thunk
end;

procedure GetPrivateProfileIntW_Thunk;
asm
  mov eax, fnGetPrivateProfileIntW
  lea edx, _GetPrivateProfileIntW_Thunk
  jmp _GetPrivateProfileIntW_Thunk
end;

procedure GetPrivateProfileSectionNamesW_Thunk;
asm
  mov eax, fnGetPrivateProfileSectionNamesW
  lea edx, _GetPrivateProfileSectionNamesW_Thunk
  jmp _GetPrivateProfileSectionNamesW_Thunk
end;

procedure GetPrivateProfileSectionW_Thunk;
asm
  mov eax, fnGetPrivateProfileSectionW
  lea edx, _GetPrivateProfileSectionW_Thunk
  jmp _GetPrivateProfileSectionW_Thunk
end;

procedure GetPrivateProfileStringW_Thunk;
asm
  mov eax, fnGetPrivateProfileStringW
  lea edx, _GetPrivateProfileStringW_Thunk
  jmp _GetPrivateProfileStringW_Thunk
end;

procedure GetPrivateProfileStructW_Thunk;
asm
  mov eax, fnGetPrivateProfileStructW
  lea edx, _GetPrivateProfileStructW_Thunk
  jmp _GetPrivateProfileStructW_Thunk
end;

procedure GetProcAddress_Thunk;
asm
  mov eax, fnGetProcAddress
  lea edx, _GetProcAddress_Thunk
  jmp _GetProcAddress_Thunk
end;

procedure GetProfileIntW_Thunk;
asm
  mov eax, fnGetProfileIntW
  lea edx, _GetProfileIntW_Thunk
  jmp _GetProfileIntW_Thunk
end;

procedure GetProfileSectionW_Thunk;
asm
  mov eax, fnGetProfileSectionW
  lea edx, _GetProfileSectionW_Thunk
  jmp _GetProfileSectionW_Thunk
end;

procedure GetProfileStringW_Thunk;
asm
  mov eax, fnGetProfileStringW
  lea edx, _GetProfileStringW_Thunk
  jmp _GetProfileStringW_Thunk
end;

procedure GetPropA_Thunk;
asm
  mov eax, fnGetPropA
  lea edx, _GetPropA_Thunk
  jmp _GetPropA_Thunk
end;

procedure GetPropW_Thunk;
asm
  mov eax, fnGetPropW
  lea edx, _GetPropW_Thunk
  jmp _GetPropW_Thunk
end;

procedure GetRoleTextW_Thunk;
asm
  mov eax, fnGetRoleTextW
  lea edx, _GetRoleTextW_Thunk
  jmp _GetRoleTextW_Thunk
end;

procedure GetSaveFileNamePreviewW_Thunk;
asm
  mov eax, fnGetSaveFileNamePreviewW
  lea edx, _GetSaveFileNamePreviewW_Thunk
  jmp _GetSaveFileNamePreviewW_Thunk
end;

procedure GetSaveFileNameW_Thunk;
asm
  mov eax, fnGetSaveFileNameW
  lea edx, _GetSaveFileNameW_Thunk
  jmp _GetSaveFileNameW_Thunk
end;

procedure GetShortPathNameW_Thunk;
asm
  mov eax, fnGetShortPathNameW
  lea edx, _GetShortPathNameW_Thunk
  jmp _GetShortPathNameW_Thunk
end;

procedure GetStartupInfoW_Thunk;
asm
  mov eax, fnGetStartupInfoW
  lea edx, _GetStartupInfoW_Thunk
  jmp _GetStartupInfoW_Thunk
end;

procedure GetStateTextW_Thunk;
asm
  mov eax, fnGetStateTextW
  lea edx, _GetStateTextW_Thunk
  jmp _GetStateTextW_Thunk
end;

procedure GetStringTypeExW_Thunk;
asm
  mov eax, fnGetStringTypeExW
  lea edx, _GetStringTypeExW_Thunk
  jmp _GetStringTypeExW_Thunk
end;

procedure GetStringTypeW_Thunk;
asm
  mov eax, fnGetStringTypeW
  lea edx, _GetStringTypeW_Thunk
  jmp _GetStringTypeW_Thunk
end;

procedure GetSystemDirectoryW_Thunk;
asm
  mov eax, fnGetSystemDirectoryW
  lea edx, _GetSystemDirectoryW_Thunk
  jmp _GetSystemDirectoryW_Thunk
end;

procedure GetSystemWindowsDirectoryW_Thunk;
asm
  mov eax, fnGetSystemWindowsDirectoryW
  lea edx, _GetSystemWindowsDirectoryW_Thunk
  jmp _GetSystemWindowsDirectoryW_Thunk
end;

procedure GetTabbedTextExtentW_Thunk;
asm
  mov eax, fnGetTabbedTextExtentW
  lea edx, _GetTabbedTextExtentW_Thunk
  jmp _GetTabbedTextExtentW_Thunk
end;

procedure GetTempFileNameW_Thunk;
asm
  mov eax, fnGetTempFileNameW
  lea edx, _GetTempFileNameW_Thunk
  jmp _GetTempFileNameW_Thunk
end;

procedure GetTempPathW_Thunk;
asm
  mov eax, fnGetTempPathW
  lea edx, _GetTempPathW_Thunk
  jmp _GetTempPathW_Thunk
end;

procedure GetTextExtentExPointW_Thunk;
asm
  mov eax, fnGetTextExtentExPointW
  lea edx, _GetTextExtentExPointW_Thunk
  jmp _GetTextExtentExPointW_Thunk
end;

procedure GetTextExtentPoint32W_Thunk;
asm
  mov eax, fnGetTextExtentPoint32W
  lea edx, _GetTextExtentPoint32W_Thunk
  jmp _GetTextExtentPoint32W_Thunk
end;

procedure GetTextExtentPointW_Thunk;
asm
  mov eax, fnGetTextExtentPointW
  lea edx, _GetTextExtentPointW_Thunk
  jmp _GetTextExtentPointW_Thunk
end;

procedure GetTextFaceW_Thunk;
asm
  mov eax, fnGetTextFaceW
  lea edx, _GetTextFaceW_Thunk
  jmp _GetTextFaceW_Thunk
end;

procedure GetTextMetricsW_Thunk;
asm
  mov eax, fnGetTextMetricsW
  lea edx, _GetTextMetricsW_Thunk
  jmp _GetTextMetricsW_Thunk
end;

procedure GetTimeFormatW_Thunk;
asm
  mov eax, fnGetTimeFormatW
  lea edx, _GetTimeFormatW_Thunk
  jmp _GetTimeFormatW_Thunk
end;

procedure GetUserNameW_Thunk;
asm
  mov eax, fnGetUserNameW
  lea edx, _GetUserNameW_Thunk
  jmp _GetUserNameW_Thunk
end;

procedure GetVersionExW_Thunk;
asm
  mov eax, fnGetVersionExW
  lea edx, _GetVersionExW_Thunk
  jmp _GetVersionExW_Thunk
end;

procedure GetVolumeInformationW_Thunk;
asm
  mov eax, fnGetVolumeInformationW
  lea edx, _GetVolumeInformationW_Thunk
  jmp _GetVolumeInformationW_Thunk
end;

procedure GetWindowLongA_Thunk;
asm
  mov eax, fnGetWindowLongA
  lea edx, _GetWindowLongA_Thunk
  jmp _GetWindowLongA_Thunk
end;

procedure GetWindowLongW_Thunk;
asm
  mov eax, fnGetWindowLongW
  lea edx, _GetWindowLongW_Thunk
  jmp _GetWindowLongW_Thunk
end;

procedure GetWindowModuleFileNameW_Thunk;
asm
  mov eax, fnGetWindowModuleFileNameW
  lea edx, _GetWindowModuleFileNameW_Thunk
  jmp _GetWindowModuleFileNameW_Thunk
end;

procedure GetWindowTextLengthW_Thunk;
asm
  mov eax, fnGetWindowTextLengthW
  lea edx, _GetWindowTextLengthW_Thunk
  jmp _GetWindowTextLengthW_Thunk
end;

procedure GetWindowTextW_Thunk;
asm
  mov eax, fnGetWindowTextW
  lea edx, _GetWindowTextW_Thunk
  jmp _GetWindowTextW_Thunk
end;

procedure GetWindowsDirectoryW_Thunk;
asm
  mov eax, fnGetWindowsDirectoryW
  lea edx, _GetWindowsDirectoryW_Thunk
  jmp _GetWindowsDirectoryW_Thunk
end;

procedure GlobalAddAtomW_Thunk;
asm
  mov eax, fnGlobalAddAtomW
  lea edx, _GlobalAddAtomW_Thunk
  jmp _GlobalAddAtomW_Thunk
end;

procedure GlobalFindAtomW_Thunk;
asm
  mov eax, fnGlobalFindAtomW
  lea edx, _GlobalFindAtomW_Thunk
  jmp _GlobalFindAtomW_Thunk
end;

procedure GlobalGetAtomNameW_Thunk;
asm
  mov eax, fnGlobalGetAtomNameW
  lea edx, _GlobalGetAtomNameW_Thunk
  jmp _GlobalGetAtomNameW_Thunk
end;

procedure GrayStringW_Thunk;
asm
  mov eax, fnGrayStringW
  lea edx, _GrayStringW_Thunk
  jmp _GrayStringW_Thunk
end;

procedure InitSecurityInterfaceW_Thunk;
asm
  mov eax, fnInitSecurityInterfaceW
  lea edx, _InitSecurityInterfaceW_Thunk
  jmp _InitSecurityInterfaceW_Thunk
end;

procedure InitializeSecurityContextW_Thunk;
asm
  mov eax, fnInitializeSecurityContextW
  lea edx, _InitializeSecurityContextW_Thunk
  jmp _InitializeSecurityContextW_Thunk
end;

procedure InsertMenuItemW_Thunk;
asm
  mov eax, fnInsertMenuItemW
  lea edx, _InsertMenuItemW_Thunk
  jmp _InsertMenuItemW_Thunk
end;

procedure InsertMenuW_Thunk;
asm
  mov eax, fnInsertMenuW
  lea edx, _InsertMenuW_Thunk
  jmp _InsertMenuW_Thunk
end;

procedure IsBadStringPtrW_Thunk;
asm
  mov eax, fnIsBadStringPtrW
  lea edx, _IsBadStringPtrW_Thunk
  jmp _IsBadStringPtrW_Thunk
end;

procedure IsCharAlphaNumericW_Thunk;
asm
  mov eax, fnIsCharAlphaNumericW
  lea edx, _IsCharAlphaNumericW_Thunk
  jmp _IsCharAlphaNumericW_Thunk
end;

procedure IsCharAlphaW_Thunk;
asm
  mov eax, fnIsCharAlphaW
  lea edx, _IsCharAlphaW_Thunk
  jmp _IsCharAlphaW_Thunk
end;

procedure IsCharLowerW_Thunk;
asm
  mov eax, fnIsCharLowerW
  lea edx, _IsCharLowerW_Thunk
  jmp _IsCharLowerW_Thunk
end;

procedure IsCharUpperW_Thunk;
asm
  mov eax, fnIsCharUpperW
  lea edx, _IsCharUpperW_Thunk
  jmp _IsCharUpperW_Thunk
end;

procedure IsClipboardFormatAvailable_Thunk;
asm
  mov eax, fnIsClipboardFormatAvailable
  lea edx, _IsClipboardFormatAvailable_Thunk
  jmp _IsClipboardFormatAvailable_Thunk
end;

procedure IsDestinationReachableW_Thunk;
asm
  mov eax, fnIsDestinationReachableW
  lea edx, _IsDestinationReachableW_Thunk
  jmp _IsDestinationReachableW_Thunk
end;

procedure IsDialogMessageW_Thunk;
asm
  mov eax, fnIsDialogMessageW
  lea edx, _IsDialogMessageW_Thunk
  jmp _IsDialogMessageW_Thunk
end;

procedure IsTextUnicode_Thunk;
asm
  mov eax, fnIsTextUnicode
  lea edx, _IsTextUnicode_Thunk
  jmp _IsTextUnicode_Thunk
end;

procedure IsValidCodePage_Thunk;
asm
  mov eax, fnIsValidCodePage
  lea edx, _IsValidCodePage_Thunk
  jmp _IsValidCodePage_Thunk
end;

procedure IsWindowUnicode_Thunk;
asm
  mov eax, fnIsWindowUnicode
  lea edx, _IsWindowUnicode_Thunk
  jmp _IsWindowUnicode_Thunk
end;

procedure LCMapStringW_Thunk;
asm
  mov eax, fnLCMapStringW
  lea edx, _LCMapStringW_Thunk
  jmp _LCMapStringW_Thunk
end;

procedure LoadAcceleratorsW_Thunk;
asm
  mov eax, fnLoadAcceleratorsW
  lea edx, _LoadAcceleratorsW_Thunk
  jmp _LoadAcceleratorsW_Thunk
end;

procedure LoadBitmapW_Thunk;
asm
  mov eax, fnLoadBitmapW
  lea edx, _LoadBitmapW_Thunk
  jmp _LoadBitmapW_Thunk
end;

procedure LoadCursorFromFileW_Thunk;
asm
  mov eax, fnLoadCursorFromFileW
  lea edx, _LoadCursorFromFileW_Thunk
  jmp _LoadCursorFromFileW_Thunk
end;

procedure LoadCursorW_Thunk;
asm
  mov eax, fnLoadCursorW
  lea edx, _LoadCursorW_Thunk
  jmp _LoadCursorW_Thunk
end;

procedure LoadIconW_Thunk;
asm
  mov eax, fnLoadIconW
  lea edx, _LoadIconW_Thunk
  jmp _LoadIconW_Thunk
end;

procedure LoadImageW_Thunk;
asm
  mov eax, fnLoadImageW
  lea edx, _LoadImageW_Thunk
  jmp _LoadImageW_Thunk
end;

procedure LoadKeyboardLayoutW_Thunk;
asm
  mov eax, fnLoadKeyboardLayoutW
  lea edx, _LoadKeyboardLayoutW_Thunk
  jmp _LoadKeyboardLayoutW_Thunk
end;

procedure LoadLibraryExW_Thunk;
asm
  mov eax, fnLoadLibraryExW
  lea edx, _LoadLibraryExW_Thunk
  jmp _LoadLibraryExW_Thunk
end;

procedure LoadLibraryW_Thunk;
asm
  mov eax, fnLoadLibraryW
  lea edx, _LoadLibraryW_Thunk
  jmp _LoadLibraryW_Thunk
end;

procedure LoadMenuIndirectW_Thunk;
asm
  mov eax, fnLoadMenuIndirectW
  lea edx, _LoadMenuIndirectW_Thunk
  jmp _LoadMenuIndirectW_Thunk
end;

procedure LoadMenuW_Thunk;
asm
  mov eax, fnLoadMenuW
  lea edx, _LoadMenuW_Thunk
  jmp _LoadMenuW_Thunk
end;

procedure LoadStringW_Thunk;
asm
  mov eax, fnLoadStringW
  lea edx, _LoadStringW_Thunk
  jmp _LoadStringW_Thunk
end;

procedure MCIWndCreateW_Thunk;
asm
  mov eax, fnMCIWndCreateW
  lea edx, _MCIWndCreateW_Thunk
  jmp _MCIWndCreateW_Thunk
end;

procedure MapVirtualKeyExW_Thunk;
asm
  mov eax, fnMapVirtualKeyExW
  lea edx, _MapVirtualKeyExW_Thunk
  jmp _MapVirtualKeyExW_Thunk
end;

procedure MapVirtualKeyW_Thunk;
asm
  mov eax, fnMapVirtualKeyW
  lea edx, _MapVirtualKeyW_Thunk
  jmp _MapVirtualKeyW_Thunk
end;

procedure MessageBoxExW_Thunk;
asm
  mov eax, fnMessageBoxExW
  lea edx, _MessageBoxExW_Thunk
  jmp _MessageBoxExW_Thunk
end;

procedure MessageBoxIndirectW_Thunk;
asm
  mov eax, fnMessageBoxIndirectW
  lea edx, _MessageBoxIndirectW_Thunk
  jmp _MessageBoxIndirectW_Thunk
end;

procedure MessageBoxW_Thunk;
asm
  mov eax, fnMessageBoxW
  lea edx, _MessageBoxW_Thunk
  jmp _MessageBoxW_Thunk
end;

procedure ModifyMenuW_Thunk;
asm
  mov eax, fnModifyMenuW
  lea edx, _ModifyMenuW_Thunk
  jmp _ModifyMenuW_Thunk
end;

procedure MoveFileW_Thunk;
asm
  mov eax, fnMoveFileW
  lea edx, _MoveFileW_Thunk
  jmp _MoveFileW_Thunk
end;

procedure MultiByteToWideChar_Thunk;
asm
  mov eax, fnMultiByteToWideChar
  lea edx, _MultiByteToWideChar_Thunk
  jmp _MultiByteToWideChar_Thunk
end;

procedure MultinetGetConnectionPerformanceW_Thunk;
asm
  mov eax, fnMultinetGetConnectionPerformanceW
  lea edx, _MultinetGetConnectionPerformanceW_Thunk
  jmp _MultinetGetConnectionPerformanceW_Thunk
end;

procedure OemToCharBuffW_Thunk;
asm
  mov eax, fnOemToCharBuffW
  lea edx, _OemToCharBuffW_Thunk
  jmp _OemToCharBuffW_Thunk
end;

procedure OemToCharW_Thunk;
asm
  mov eax, fnOemToCharW
  lea edx, _OemToCharW_Thunk
  jmp _OemToCharW_Thunk
end;

procedure OleUIAddVerbMenuW_Thunk;
asm
  mov eax, fnOleUIAddVerbMenuW
  lea edx, _OleUIAddVerbMenuW_Thunk
  jmp _OleUIAddVerbMenuW_Thunk
end;

procedure OleUIBusyW_Thunk;
asm
  mov eax, fnOleUIBusyW
  lea edx, _OleUIBusyW_Thunk
  jmp _OleUIBusyW_Thunk
end;

procedure OleUIChangeIconW_Thunk;
asm
  mov eax, fnOleUIChangeIconW
  lea edx, _OleUIChangeIconW_Thunk
  jmp _OleUIChangeIconW_Thunk
end;

procedure OleUIChangeSourceW_Thunk;
asm
  mov eax, fnOleUIChangeSourceW
  lea edx, _OleUIChangeSourceW_Thunk
  jmp _OleUIChangeSourceW_Thunk
end;

procedure OleUIConvertW_Thunk;
asm
  mov eax, fnOleUIConvertW
  lea edx, _OleUIConvertW_Thunk
  jmp _OleUIConvertW_Thunk
end;

procedure OleUIEditLinksW_Thunk;
asm
  mov eax, fnOleUIEditLinksW
  lea edx, _OleUIEditLinksW_Thunk
  jmp _OleUIEditLinksW_Thunk
end;

procedure OleUIInsertObjectW_Thunk;
asm
  mov eax, fnOleUIInsertObjectW
  lea edx, _OleUIInsertObjectW_Thunk
  jmp _OleUIInsertObjectW_Thunk
end;

procedure OleUIObjectPropertiesW_Thunk;
asm
  mov eax, fnOleUIObjectPropertiesW
  lea edx, _OleUIObjectPropertiesW_Thunk
  jmp _OleUIObjectPropertiesW_Thunk
end;

procedure OleUIPasteSpecialW_Thunk;
asm
  mov eax, fnOleUIPasteSpecialW
  lea edx, _OleUIPasteSpecialW_Thunk
  jmp _OleUIPasteSpecialW_Thunk
end;

procedure OleUIPromptUserW_Thunk;
asm
  mov eax, fnOleUIPromptUserW
  lea edx, _OleUIPromptUserW_Thunk
  jmp _OleUIPromptUserW_Thunk
end;

procedure OleUIUpdateLinksW_Thunk;
asm
  mov eax, fnOleUIUpdateLinksW
  lea edx, _OleUIUpdateLinksW_Thunk
  jmp _OleUIUpdateLinksW_Thunk
end;

procedure OpenEventW_Thunk;
asm
  mov eax, fnOpenEventW
  lea edx, _OpenEventW_Thunk
  jmp _OpenEventW_Thunk
end;

procedure OpenFileMappingW_Thunk;
asm
  mov eax, fnOpenFileMappingW
  lea edx, _OpenFileMappingW_Thunk
  jmp _OpenFileMappingW_Thunk
end;

procedure OpenMutexW_Thunk;
asm
  mov eax, fnOpenMutexW
  lea edx, _OpenMutexW_Thunk
  jmp _OpenMutexW_Thunk
end;

procedure OpenPrinterW_Thunk;
asm
  mov eax, fnOpenPrinterW
  lea edx, _OpenPrinterW_Thunk
  jmp _OpenPrinterW_Thunk
end;

procedure OpenSemaphoreW_Thunk;
asm
  mov eax, fnOpenSemaphoreW
  lea edx, _OpenSemaphoreW_Thunk
  jmp _OpenSemaphoreW_Thunk
end;

procedure OpenWaitableTimerW_Thunk;
asm
  mov eax, fnOpenWaitableTimerW
  lea edx, _OpenWaitableTimerW_Thunk
  jmp _OpenWaitableTimerW_Thunk
end;

procedure OutputDebugStringW_Thunk;
asm
  mov eax, fnOutputDebugStringW
  lea edx, _OutputDebugStringW_Thunk
  jmp _OutputDebugStringW_Thunk
end;

procedure PageSetupDlgW_Thunk;
asm
  mov eax, fnPageSetupDlgW
  lea edx, _PageSetupDlgW_Thunk
  jmp _PageSetupDlgW_Thunk
end;

procedure PeekConsoleInputW_Thunk;
asm
  mov eax, fnPeekConsoleInputW
  lea edx, _PeekConsoleInputW_Thunk
  jmp _PeekConsoleInputW_Thunk
end;

procedure PeekMessageW_Thunk;
asm
  mov eax, fnPeekMessageW
  lea edx, _PeekMessageW_Thunk
  jmp _PeekMessageW_Thunk
end;

procedure PlaySoundW_Thunk;
asm
  mov eax, fnPlaySoundW
  lea edx, _PlaySoundW_Thunk
  jmp _PlaySoundW_Thunk
end;

procedure PolyTextOutW_Thunk;
asm
  mov eax, fnPolyTextOutW
  lea edx, _PolyTextOutW_Thunk
  jmp _PolyTextOutW_Thunk
end;

procedure PostMessageW_Thunk;
asm
  mov eax, fnPostMessageW
  lea edx, _PostMessageW_Thunk
  jmp _PostMessageW_Thunk
end;

procedure PostThreadMessageW_Thunk;
asm
  mov eax, fnPostThreadMessageW
  lea edx, _PostThreadMessageW_Thunk
  jmp _PostThreadMessageW_Thunk
end;

procedure PrintDlgW_Thunk;
asm
  mov eax, fnPrintDlgW
  lea edx, _PrintDlgW_Thunk
  jmp _PrintDlgW_Thunk
end;

procedure QueryContextAttributesW_Thunk;
asm
  mov eax, fnQueryContextAttributesW
  lea edx, _QueryContextAttributesW_Thunk
  jmp _QueryContextAttributesW_Thunk
end;

procedure QueryCredentialsAttributesW_Thunk;
asm
  mov eax, fnQueryCredentialsAttributesW
  lea edx, _QueryCredentialsAttributesW_Thunk
  jmp _QueryCredentialsAttributesW_Thunk
end;

procedure QueryDosDeviceW_Thunk;
asm
  mov eax, fnQueryDosDeviceW
  lea edx, _QueryDosDeviceW_Thunk
  jmp _QueryDosDeviceW_Thunk
end;

procedure QuerySecurityPackageInfoW_Thunk;
asm
  mov eax, fnQuerySecurityPackageInfoW
  lea edx, _QuerySecurityPackageInfoW_Thunk
  jmp _QuerySecurityPackageInfoW_Thunk
end;

procedure RasConnectionNotificationW_Thunk;
asm
  mov eax, fnRasConnectionNotificationW
  lea edx, _RasConnectionNotificationW_Thunk
  jmp _RasConnectionNotificationW_Thunk
end;

procedure RasCreatePhonebookEntryW_Thunk;
asm
  mov eax, fnRasCreatePhonebookEntryW
  lea edx, _RasCreatePhonebookEntryW_Thunk
  jmp _RasCreatePhonebookEntryW_Thunk
end;

procedure RasDeleteEntryW_Thunk;
asm
  mov eax, fnRasDeleteEntryW
  lea edx, _RasDeleteEntryW_Thunk
  jmp _RasDeleteEntryW_Thunk
end;

procedure RasDeleteSubEntryW_Thunk;
asm
  mov eax, fnRasDeleteSubEntryW
  lea edx, _RasDeleteSubEntryW_Thunk
  jmp _RasDeleteSubEntryW_Thunk
end;

procedure RasDialW_Thunk;
asm
  mov eax, fnRasDialW
  lea edx, _RasDialW_Thunk
  jmp _RasDialW_Thunk
end;

procedure RasEditPhonebookEntryW_Thunk;
asm
  mov eax, fnRasEditPhonebookEntryW
  lea edx, _RasEditPhonebookEntryW_Thunk
  jmp _RasEditPhonebookEntryW_Thunk
end;

procedure RasEnumConnectionsW_Thunk;
asm
  mov eax, fnRasEnumConnectionsW
  lea edx, _RasEnumConnectionsW_Thunk
  jmp _RasEnumConnectionsW_Thunk
end;

procedure RasEnumDevicesW_Thunk;
asm
  mov eax, fnRasEnumDevicesW
  lea edx, _RasEnumDevicesW_Thunk
  jmp _RasEnumDevicesW_Thunk
end;

procedure RasEnumEntriesW_Thunk;
asm
  mov eax, fnRasEnumEntriesW
  lea edx, _RasEnumEntriesW_Thunk
  jmp _RasEnumEntriesW_Thunk
end;

procedure RasGetConnectStatusW_Thunk;
asm
  mov eax, fnRasGetConnectStatusW
  lea edx, _RasGetConnectStatusW_Thunk
  jmp _RasGetConnectStatusW_Thunk
end;

procedure RasGetEntryDialParamsW_Thunk;
asm
  mov eax, fnRasGetEntryDialParamsW
  lea edx, _RasGetEntryDialParamsW_Thunk
  jmp _RasGetEntryDialParamsW_Thunk
end;

procedure RasGetEntryPropertiesW_Thunk;
asm
  mov eax, fnRasGetEntryPropertiesW
  lea edx, _RasGetEntryPropertiesW_Thunk
  jmp _RasGetEntryPropertiesW_Thunk
end;

procedure RasGetErrorStringW_Thunk;
asm
  mov eax, fnRasGetErrorStringW
  lea edx, _RasGetErrorStringW_Thunk
  jmp _RasGetErrorStringW_Thunk
end;

procedure RasGetProjectionInfoW_Thunk;
asm
  mov eax, fnRasGetProjectionInfoW
  lea edx, _RasGetProjectionInfoW_Thunk
  jmp _RasGetProjectionInfoW_Thunk
end;

procedure RasHangUpW_Thunk;
asm
  mov eax, fnRasHangUpW
  lea edx, _RasHangUpW_Thunk
  jmp _RasHangUpW_Thunk
end;

procedure RasRenameEntryW_Thunk;
asm
  mov eax, fnRasRenameEntryW
  lea edx, _RasRenameEntryW_Thunk
  jmp _RasRenameEntryW_Thunk
end;

procedure RasSetEntryDialParamsW_Thunk;
asm
  mov eax, fnRasSetEntryDialParamsW
  lea edx, _RasSetEntryDialParamsW_Thunk
  jmp _RasSetEntryDialParamsW_Thunk
end;

procedure RasSetEntryPropertiesW_Thunk;
asm
  mov eax, fnRasSetEntryPropertiesW
  lea edx, _RasSetEntryPropertiesW_Thunk
  jmp _RasSetEntryPropertiesW_Thunk
end;

procedure RasSetSubEntryPropertiesW_Thunk;
asm
  mov eax, fnRasSetSubEntryPropertiesW
  lea edx, _RasSetSubEntryPropertiesW_Thunk
  jmp _RasSetSubEntryPropertiesW_Thunk
end;

procedure RasValidateEntryNameW_Thunk;
asm
  mov eax, fnRasValidateEntryNameW
  lea edx, _RasValidateEntryNameW_Thunk
  jmp _RasValidateEntryNameW_Thunk
end;

procedure ReadConsoleInputW_Thunk;
asm
  mov eax, fnReadConsoleInputW
  lea edx, _ReadConsoleInputW_Thunk
  jmp _ReadConsoleInputW_Thunk
end;

procedure ReadConsoleOutputCharacterW_Thunk;
asm
  mov eax, fnReadConsoleOutputCharacterW
  lea edx, _ReadConsoleOutputCharacterW_Thunk
  jmp _ReadConsoleOutputCharacterW_Thunk
end;

procedure ReadConsoleOutputW_Thunk;
asm
  mov eax, fnReadConsoleOutputW
  lea edx, _ReadConsoleOutputW_Thunk
  jmp _ReadConsoleOutputW_Thunk
end;

procedure ReadConsoleW_Thunk;
asm
  mov eax, fnReadConsoleW
  lea edx, _ReadConsoleW_Thunk
  jmp _ReadConsoleW_Thunk
end;

procedure RegConnectRegistryW_Thunk;
asm
  mov eax, fnRegConnectRegistryW
  lea edx, _RegConnectRegistryW_Thunk
  jmp _RegConnectRegistryW_Thunk
end;

procedure RegCreateKeyExW_Thunk;
asm
  mov eax, fnRegCreateKeyExW
  lea edx, _RegCreateKeyExW_Thunk
  jmp _RegCreateKeyExW_Thunk
end;

procedure RegCreateKeyW_Thunk;
asm
  mov eax, fnRegCreateKeyW
  lea edx, _RegCreateKeyW_Thunk
  jmp _RegCreateKeyW_Thunk
end;

procedure RegDeleteKeyW_Thunk;
asm
  mov eax, fnRegDeleteKeyW
  lea edx, _RegDeleteKeyW_Thunk
  jmp _RegDeleteKeyW_Thunk
end;

procedure RegDeleteValueW_Thunk;
asm
  mov eax, fnRegDeleteValueW
  lea edx, _RegDeleteValueW_Thunk
  jmp _RegDeleteValueW_Thunk
end;

procedure RegEnumKeyExW_Thunk;
asm
  mov eax, fnRegEnumKeyExW
  lea edx, _RegEnumKeyExW_Thunk
  jmp _RegEnumKeyExW_Thunk
end;

procedure RegEnumKeyW_Thunk;
asm
  mov eax, fnRegEnumKeyW
  lea edx, _RegEnumKeyW_Thunk
  jmp _RegEnumKeyW_Thunk
end;

procedure RegEnumValueW_Thunk;
asm
  mov eax, fnRegEnumValueW
  lea edx, _RegEnumValueW_Thunk
  jmp _RegEnumValueW_Thunk
end;

procedure RegLoadKeyW_Thunk;
asm
  mov eax, fnRegLoadKeyW
  lea edx, _RegLoadKeyW_Thunk
  jmp _RegLoadKeyW_Thunk
end;

procedure RegOpenKeyExW_Thunk;
asm
  mov eax, fnRegOpenKeyExW
  lea edx, _RegOpenKeyExW_Thunk
  jmp _RegOpenKeyExW_Thunk
end;

procedure RegOpenKeyW_Thunk;
asm
  mov eax, fnRegOpenKeyW
  lea edx, _RegOpenKeyW_Thunk
  jmp _RegOpenKeyW_Thunk
end;

procedure RegQueryInfoKeyW_Thunk;
asm
  mov eax, fnRegQueryInfoKeyW
  lea edx, _RegQueryInfoKeyW_Thunk
  jmp _RegQueryInfoKeyW_Thunk
end;

procedure RegQueryMultipleValuesW_Thunk;
asm
  mov eax, fnRegQueryMultipleValuesW
  lea edx, _RegQueryMultipleValuesW_Thunk
  jmp _RegQueryMultipleValuesW_Thunk
end;

procedure RegQueryValueExW_Thunk;
asm
  mov eax, fnRegQueryValueExW
  lea edx, _RegQueryValueExW_Thunk
  jmp _RegQueryValueExW_Thunk
end;

procedure RegQueryValueW_Thunk;
asm
  mov eax, fnRegQueryValueW
  lea edx, _RegQueryValueW_Thunk
  jmp _RegQueryValueW_Thunk
end;

procedure RegReplaceKeyW_Thunk;
asm
  mov eax, fnRegReplaceKeyW
  lea edx, _RegReplaceKeyW_Thunk
  jmp _RegReplaceKeyW_Thunk
end;

procedure RegSaveKeyW_Thunk;
asm
  mov eax, fnRegSaveKeyW
  lea edx, _RegSaveKeyW_Thunk
  jmp _RegSaveKeyW_Thunk
end;

procedure RegSetValueExW_Thunk;
asm
  mov eax, fnRegSetValueExW
  lea edx, _RegSetValueExW_Thunk
  jmp _RegSetValueExW_Thunk
end;

procedure RegSetValueW_Thunk;
asm
  mov eax, fnRegSetValueW
  lea edx, _RegSetValueW_Thunk
  jmp _RegSetValueW_Thunk
end;

procedure RegUnLoadKeyW_Thunk;
asm
  mov eax, fnRegUnLoadKeyW
  lea edx, _RegUnLoadKeyW_Thunk
  jmp _RegUnLoadKeyW_Thunk
end;

procedure RegisterClassExW_Thunk;
asm
  mov eax, fnRegisterClassExW
  lea edx, _RegisterClassExW_Thunk
  jmp _RegisterClassExW_Thunk
end;

procedure RegisterClassW_Thunk;
asm
  mov eax, fnRegisterClassW
  lea edx, _RegisterClassW_Thunk
  jmp _RegisterClassW_Thunk
end;

procedure RegisterClipboardFormatW_Thunk;
asm
  mov eax, fnRegisterClipboardFormatW
  lea edx, _RegisterClipboardFormatW_Thunk
  jmp _RegisterClipboardFormatW_Thunk
end;

procedure RegisterDeviceNotificationW_Thunk;
asm
  mov eax, fnRegisterDeviceNotificationW
  lea edx, _RegisterDeviceNotificationW_Thunk
  jmp _RegisterDeviceNotificationW_Thunk
end;

procedure RegisterWindowMessageW_Thunk;
asm
  mov eax, fnRegisterWindowMessageW
  lea edx, _RegisterWindowMessageW_Thunk
  jmp _RegisterWindowMessageW_Thunk
end;

procedure RemoveDirectoryW_Thunk;
asm
  mov eax, fnRemoveDirectoryW
  lea edx, _RemoveDirectoryW_Thunk
  jmp _RemoveDirectoryW_Thunk
end;

procedure RemoveFontResourceW_Thunk;
asm
  mov eax, fnRemoveFontResourceW
  lea edx, _RemoveFontResourceW_Thunk
  jmp _RemoveFontResourceW_Thunk
end;

procedure RemovePropA_Thunk;
asm
  mov eax, fnRemovePropA
  lea edx, _RemovePropA_Thunk
  jmp _RemovePropA_Thunk
end;

procedure RemovePropW_Thunk;
asm
  mov eax, fnRemovePropW
  lea edx, _RemovePropW_Thunk
  jmp _RemovePropW_Thunk
end;

procedure ReplaceTextW_Thunk;
asm
  mov eax, fnReplaceTextW
  lea edx, _ReplaceTextW_Thunk
  jmp _ReplaceTextW_Thunk
end;

procedure ResetDCW_Thunk;
asm
  mov eax, fnResetDCW
  lea edx, _ResetDCW_Thunk
  jmp _ResetDCW_Thunk
end;

procedure ResetPrinterW_Thunk;
asm
  mov eax, fnResetPrinterW
  lea edx, _ResetPrinterW_Thunk
  jmp _ResetPrinterW_Thunk
end;

procedure SHBrowseForFolderW_Thunk;
asm
  mov eax, fnSHBrowseForFolderW
  lea edx, _SHBrowseForFolderW_Thunk
  jmp _SHBrowseForFolderW_Thunk
end;

procedure SHChangeNotify_Thunk;
asm
  mov eax, fnSHChangeNotify
  lea edx, _SHChangeNotify_Thunk
  jmp _SHChangeNotify_Thunk
end;

procedure SHFileOperationW_Thunk;
asm
  mov eax, fnSHFileOperationW
  lea edx, _SHFileOperationW_Thunk
  jmp _SHFileOperationW_Thunk
end;

procedure SHGetFileInfoW_Thunk;
asm
  mov eax, fnSHGetFileInfoW
  lea edx, _SHGetFileInfoW_Thunk
  jmp _SHGetFileInfoW_Thunk
end;

procedure SHGetNewLinkInfoW_Thunk;
asm
  mov eax, fnSHGetNewLinkInfoW
  lea edx, _SHGetNewLinkInfoW_Thunk
  jmp _SHGetNewLinkInfoW_Thunk
end;

procedure SHGetPathFromIDListW_Thunk;
asm
  mov eax, fnSHGetPathFromIDListW
  lea edx, _SHGetPathFromIDListW_Thunk
  jmp _SHGetPathFromIDListW_Thunk
end;

procedure ScrollConsoleScreenBufferW_Thunk;
asm
  mov eax, fnScrollConsoleScreenBufferW
  lea edx, _ScrollConsoleScreenBufferW_Thunk
  jmp _ScrollConsoleScreenBufferW_Thunk
end;

procedure SearchPathW_Thunk;
asm
  mov eax, fnSearchPathW
  lea edx, _SearchPathW_Thunk
  jmp _SearchPathW_Thunk
end;

procedure SendDlgItemMessageW_Thunk;
asm
  mov eax, fnSendDlgItemMessageW
  lea edx, _SendDlgItemMessageW_Thunk
  jmp _SendDlgItemMessageW_Thunk
end;

procedure SendMessageCallbackW_Thunk;
asm
  mov eax, fnSendMessageCallbackW
  lea edx, _SendMessageCallbackW_Thunk
  jmp _SendMessageCallbackW_Thunk
end;

procedure SendMessageTimeoutW_Thunk;
asm
  mov eax, fnSendMessageTimeoutW
  lea edx, _SendMessageTimeoutW_Thunk
  jmp _SendMessageTimeoutW_Thunk
end;

procedure SendMessageW_Thunk;
asm
  mov eax, fnSendMessageW
  lea edx, _SendMessageW_Thunk
  jmp _SendMessageW_Thunk
end;

procedure SendNotifyMessageW_Thunk;
asm
  mov eax, fnSendNotifyMessageW
  lea edx, _SendNotifyMessageW_Thunk
  jmp _SendNotifyMessageW_Thunk
end;

procedure SetCalendarInfoW_Thunk;
asm
  mov eax, fnSetCalendarInfoW
  lea edx, _SetCalendarInfoW_Thunk
  jmp _SetCalendarInfoW_Thunk
end;

procedure SetClassLongW_Thunk;
asm
  mov eax, fnSetClassLongW
  lea edx, _SetClassLongW_Thunk
  jmp _SetClassLongW_Thunk
end;

procedure SetComputerNameW_Thunk;
asm
  mov eax, fnSetComputerNameW
  lea edx, _SetComputerNameW_Thunk
  jmp _SetComputerNameW_Thunk
end;

procedure SetConsoleTitleW_Thunk;
asm
  mov eax, fnSetConsoleTitleW
  lea edx, _SetConsoleTitleW_Thunk
  jmp _SetConsoleTitleW_Thunk
end;

procedure SetCurrentDirectoryW_Thunk;
asm
  mov eax, fnSetCurrentDirectoryW
  lea edx, _SetCurrentDirectoryW_Thunk
  jmp _SetCurrentDirectoryW_Thunk
end;

procedure SetDefaultCommConfigW_Thunk;
asm
  mov eax, fnSetDefaultCommConfigW
  lea edx, _SetDefaultCommConfigW_Thunk
  jmp _SetDefaultCommConfigW_Thunk
end;

procedure SetDlgItemTextW_Thunk;
asm
  mov eax, fnSetDlgItemTextW
  lea edx, _SetDlgItemTextW_Thunk
  jmp _SetDlgItemTextW_Thunk
end;

procedure SetEnvironmentVariableW_Thunk;
asm
  mov eax, fnSetEnvironmentVariableW
  lea edx, _SetEnvironmentVariableW_Thunk
  jmp _SetEnvironmentVariableW_Thunk
end;

procedure SetFileAttributesW_Thunk;
asm
  mov eax, fnSetFileAttributesW
  lea edx, _SetFileAttributesW_Thunk
  jmp _SetFileAttributesW_Thunk
end;

procedure SetICMProfileW_Thunk;
asm
  mov eax, fnSetICMProfileW
  lea edx, _SetICMProfileW_Thunk
  jmp _SetICMProfileW_Thunk
end;

procedure SetJobW_Thunk;
asm
  mov eax, fnSetJobW
  lea edx, _SetJobW_Thunk
  jmp _SetJobW_Thunk
end;

procedure SetLocaleInfoW_Thunk;
asm
  mov eax, fnSetLocaleInfoW
  lea edx, _SetLocaleInfoW_Thunk
  jmp _SetLocaleInfoW_Thunk
end;

procedure SetMenuItemInfoW_Thunk;
asm
  mov eax, fnSetMenuItemInfoW
  lea edx, _SetMenuItemInfoW_Thunk
  jmp _SetMenuItemInfoW_Thunk
end;

procedure SetPrinterDataW_Thunk;
asm
  mov eax, fnSetPrinterDataW
  lea edx, _SetPrinterDataW_Thunk
  jmp _SetPrinterDataW_Thunk
end;

procedure SetPrinterW_Thunk;
asm
  mov eax, fnSetPrinterW
  lea edx, _SetPrinterW_Thunk
  jmp _SetPrinterW_Thunk
end;

procedure SetPropA_Thunk;
asm
  mov eax, fnSetPropA
  lea edx, _SetPropA_Thunk
  jmp _SetPropA_Thunk
end;

procedure SetPropW_Thunk;
asm
  mov eax, fnSetPropW
  lea edx, _SetPropW_Thunk
  jmp _SetPropW_Thunk
end;

procedure SetVolumeLabelW_Thunk;
asm
  mov eax, fnSetVolumeLabelW
  lea edx, _SetVolumeLabelW_Thunk
  jmp _SetVolumeLabelW_Thunk
end;

procedure SetWindowLongA_Thunk;
asm
  mov eax, fnSetWindowLongA
  lea edx, _SetWindowLongA_Thunk
  jmp _SetWindowLongA_Thunk
end;

procedure SetWindowLongW_Thunk;
asm
  mov eax, fnSetWindowLongW
  lea edx, _SetWindowLongW_Thunk
  jmp _SetWindowLongW_Thunk
end;

procedure SetWindowTextW_Thunk;
asm
  mov eax, fnSetWindowTextW
  lea edx, _SetWindowTextW_Thunk
  jmp _SetWindowTextW_Thunk
end;

procedure SetWindowsHookExW_Thunk;
asm
  mov eax, fnSetWindowsHookExW
  lea edx, _SetWindowsHookExW_Thunk
  jmp _SetWindowsHookExW_Thunk
end;

procedure SetWindowsHookW_Thunk;
asm
  mov eax, fnSetWindowsHookW
  lea edx, _SetWindowsHookW_Thunk
  jmp _SetWindowsHookW_Thunk
end;

procedure ShellAboutW_Thunk;
asm
  mov eax, fnShellAboutW
  lea edx, _ShellAboutW_Thunk
  jmp _ShellAboutW_Thunk
end;

procedure ShellExecuteExW_Thunk;
asm
  mov eax, fnShellExecuteExW
  lea edx, _ShellExecuteExW_Thunk
  jmp _ShellExecuteExW_Thunk
end;

procedure ShellExecuteW_Thunk;
asm
  mov eax, fnShellExecuteW
  lea edx, _ShellExecuteW_Thunk
  jmp _ShellExecuteW_Thunk
end;

procedure Shell_NotifyIconW_Thunk;
asm
  mov eax, fnShell_NotifyIconW
  lea edx, _Shell_NotifyIconW_Thunk
  jmp _Shell_NotifyIconW_Thunk
end;

procedure StartDocPrinterW_Thunk;
asm
  mov eax, fnStartDocPrinterW
  lea edx, _StartDocPrinterW_Thunk
  jmp _StartDocPrinterW_Thunk
end;

procedure StartDocW_Thunk;
asm
  mov eax, fnStartDocW
  lea edx, _StartDocW_Thunk
  jmp _StartDocW_Thunk
end;

procedure SystemParametersInfoW_Thunk;
asm
  mov eax, fnSystemParametersInfoW
  lea edx, _SystemParametersInfoW_Thunk
  jmp _SystemParametersInfoW_Thunk
end;

procedure TabbedTextOutW_Thunk;
asm
  mov eax, fnTabbedTextOutW
  lea edx, _TabbedTextOutW_Thunk
  jmp _TabbedTextOutW_Thunk
end;

procedure TextOutW_Thunk;
asm
  mov eax, fnTextOutW
  lea edx, _TextOutW_Thunk
  jmp _TextOutW_Thunk
end;

procedure TranslateAcceleratorW_Thunk;
asm
  mov eax, fnTranslateAcceleratorW
  lea edx, _TranslateAcceleratorW_Thunk
  jmp _TranslateAcceleratorW_Thunk
end;

procedure UnregisterClassW_Thunk;
asm
  mov eax, fnUnregisterClassW
  lea edx, _UnregisterClassW_Thunk
  jmp _UnregisterClassW_Thunk
end;

procedure UpdateICMRegKeyW_Thunk;
asm
  mov eax, fnUpdateICMRegKeyW
  lea edx, _UpdateICMRegKeyW_Thunk
  jmp _UpdateICMRegKeyW_Thunk
end;

procedure UpdateResourceA_Thunk;
asm
  mov eax, fnUpdateResourceA
  lea edx, _UpdateResourceA_Thunk
  jmp _UpdateResourceA_Thunk
end;

procedure UpdateResourceW_Thunk;
asm
  mov eax, fnUpdateResourceW
  lea edx, _UpdateResourceW_Thunk
  jmp _UpdateResourceW_Thunk
end;

procedure VerFindFileW_Thunk;
asm
  mov eax, fnVerFindFileW
  lea edx, _VerFindFileW_Thunk
  jmp _VerFindFileW_Thunk
end;

procedure VerInstallFileW_Thunk;
asm
  mov eax, fnVerInstallFileW
  lea edx, _VerInstallFileW_Thunk
  jmp _VerInstallFileW_Thunk
end;

procedure VerLanguageNameW_Thunk;
asm
  mov eax, fnVerLanguageNameW
  lea edx, _VerLanguageNameW_Thunk
  jmp _VerLanguageNameW_Thunk
end;

procedure VerQueryValueW_Thunk;
asm
  mov eax, fnVerQueryValueW
  lea edx, _VerQueryValueW_Thunk
  jmp _VerQueryValueW_Thunk
end;

procedure VkKeyScanExW_Thunk;
asm
  mov eax, fnVkKeyScanExW
  lea edx, _VkKeyScanExW_Thunk
  jmp _VkKeyScanExW_Thunk
end;

procedure VkKeyScanW_Thunk;
asm
  mov eax, fnVkKeyScanW
  lea edx, _VkKeyScanW_Thunk
  jmp _VkKeyScanW_Thunk
end;

procedure WNetAddConnection2W_Thunk;
asm
  mov eax, fnWNetAddConnection2W
  lea edx, _WNetAddConnection2W_Thunk
  jmp _WNetAddConnection2W_Thunk
end;

procedure WNetAddConnection3W_Thunk;
asm
  mov eax, fnWNetAddConnection3W
  lea edx, _WNetAddConnection3W_Thunk
  jmp _WNetAddConnection3W_Thunk
end;

procedure WNetAddConnectionW_Thunk;
asm
  mov eax, fnWNetAddConnectionW
  lea edx, _WNetAddConnectionW_Thunk
  jmp _WNetAddConnectionW_Thunk
end;

procedure WNetCancelConnection2W_Thunk;
asm
  mov eax, fnWNetCancelConnection2W
  lea edx, _WNetCancelConnection2W_Thunk
  jmp _WNetCancelConnection2W_Thunk
end;

procedure WNetCancelConnectionW_Thunk;
asm
  mov eax, fnWNetCancelConnectionW
  lea edx, _WNetCancelConnectionW_Thunk
  jmp _WNetCancelConnectionW_Thunk
end;

procedure WNetConnectionDialog1W_Thunk;
asm
  mov eax, fnWNetConnectionDialog1W
  lea edx, _WNetConnectionDialog1W_Thunk
  jmp _WNetConnectionDialog1W_Thunk
end;

procedure WNetDisconnectDialog1W_Thunk;
asm
  mov eax, fnWNetDisconnectDialog1W
  lea edx, _WNetDisconnectDialog1W_Thunk
  jmp _WNetDisconnectDialog1W_Thunk
end;

procedure WNetEnumResourceW_Thunk;
asm
  mov eax, fnWNetEnumResourceW
  lea edx, _WNetEnumResourceW_Thunk
  jmp _WNetEnumResourceW_Thunk
end;

procedure WNetGetConnectionW_Thunk;
asm
  mov eax, fnWNetGetConnectionW
  lea edx, _WNetGetConnectionW_Thunk
  jmp _WNetGetConnectionW_Thunk
end;

procedure WNetGetLastErrorW_Thunk;
asm
  mov eax, fnWNetGetLastErrorW
  lea edx, _WNetGetLastErrorW_Thunk
  jmp _WNetGetLastErrorW_Thunk
end;

procedure WNetGetNetworkInformationW_Thunk;
asm
  mov eax, fnWNetGetNetworkInformationW
  lea edx, _WNetGetNetworkInformationW_Thunk
  jmp _WNetGetNetworkInformationW_Thunk
end;

procedure WNetGetProviderNameW_Thunk;
asm
  mov eax, fnWNetGetProviderNameW
  lea edx, _WNetGetProviderNameW_Thunk
  jmp _WNetGetProviderNameW_Thunk
end;

procedure WNetGetResourceInformationW_Thunk;
asm
  mov eax, fnWNetGetResourceInformationW
  lea edx, _WNetGetResourceInformationW_Thunk
  jmp _WNetGetResourceInformationW_Thunk
end;

procedure WNetGetResourceParentW_Thunk;
asm
  mov eax, fnWNetGetResourceParentW
  lea edx, _WNetGetResourceParentW_Thunk
  jmp _WNetGetResourceParentW_Thunk
end;

procedure WNetGetUniversalNameW_Thunk;
asm
  mov eax, fnWNetGetUniversalNameW
  lea edx, _WNetGetUniversalNameW_Thunk
  jmp _WNetGetUniversalNameW_Thunk
end;

procedure WNetGetUserW_Thunk;
asm
  mov eax, fnWNetGetUserW
  lea edx, _WNetGetUserW_Thunk
  jmp _WNetGetUserW_Thunk
end;

procedure WNetOpenEnumW_Thunk;
asm
  mov eax, fnWNetOpenEnumW
  lea edx, _WNetOpenEnumW_Thunk
  jmp _WNetOpenEnumW_Thunk
end;

procedure WNetUseConnectionW_Thunk;
asm
  mov eax, fnWNetUseConnectionW
  lea edx, _WNetUseConnectionW_Thunk
  jmp _WNetUseConnectionW_Thunk
end;

procedure WaitNamedPipeW_Thunk;
asm
  mov eax, fnWaitNamedPipeW
  lea edx, _WaitNamedPipeW_Thunk
  jmp _WaitNamedPipeW_Thunk
end;

procedure WideCharToMultiByte_Thunk;
asm
  mov eax, fnWideCharToMultiByte
  lea edx, _WideCharToMultiByte_Thunk
  jmp _WideCharToMultiByte_Thunk
end;

procedure WinHelpW_Thunk;
asm
  mov eax, fnWinHelpW
  lea edx, _WinHelpW_Thunk
  jmp _WinHelpW_Thunk
end;

procedure WriteConsoleInputW_Thunk;
asm
  mov eax, fnWriteConsoleInputW
  lea edx, _WriteConsoleInputW_Thunk
  jmp _WriteConsoleInputW_Thunk
end;

procedure WriteConsoleOutputCharacterW_Thunk;
asm
  mov eax, fnWriteConsoleOutputCharacterW
  lea edx, _WriteConsoleOutputCharacterW_Thunk
  jmp _WriteConsoleOutputCharacterW_Thunk
end;

procedure WriteConsoleOutputW_Thunk;
asm
  mov eax, fnWriteConsoleOutputW
  lea edx, _WriteConsoleOutputW_Thunk
  jmp _WriteConsoleOutputW_Thunk
end;

procedure WriteConsoleW_Thunk;
asm
  mov eax, fnWriteConsoleW
  lea edx, _WriteConsoleW_Thunk
  jmp _WriteConsoleW_Thunk
end;

procedure WritePrivateProfileSectionW_Thunk;
asm
  mov eax, fnWritePrivateProfileSectionW
  lea edx, _WritePrivateProfileSectionW_Thunk
  jmp _WritePrivateProfileSectionW_Thunk
end;

procedure WritePrivateProfileStringW_Thunk;
asm
  mov eax, fnWritePrivateProfileStringW
  lea edx, _WritePrivateProfileStringW_Thunk
  jmp _WritePrivateProfileStringW_Thunk
end;

procedure WritePrivateProfileStructW_Thunk;
asm
  mov eax, fnWritePrivateProfileStructW
  lea edx, _WritePrivateProfileStructW_Thunk
  jmp _WritePrivateProfileStructW_Thunk
end;

procedure WriteProfileSectionW_Thunk;
asm
  mov eax, fnWriteProfileSectionW
  lea edx, _WriteProfileSectionW_Thunk
  jmp _WriteProfileSectionW_Thunk
end;

procedure WriteProfileStringW_Thunk;
asm
  mov eax, fnWriteProfileStringW
  lea edx, _WriteProfileStringW_Thunk
  jmp _WriteProfileStringW_Thunk
end;

procedure auxGetDevCapsW_Thunk;
asm
  mov eax, fnauxGetDevCapsW
  lea edx, _auxGetDevCapsW_Thunk
  jmp _auxGetDevCapsW_Thunk
end;

procedure capCreateCaptureWindowW_Thunk;
asm
  mov eax, fncapCreateCaptureWindowW
  lea edx, _capCreateCaptureWindowW_Thunk
  jmp _capCreateCaptureWindowW_Thunk
end;

procedure capGetDriverDescriptionW_Thunk;
asm
  mov eax, fncapGetDriverDescriptionW
  lea edx, _capGetDriverDescriptionW_Thunk
  jmp _capGetDriverDescriptionW_Thunk
end;

procedure joyGetDevCapsW_Thunk;
asm
  mov eax, fnjoyGetDevCapsW
  lea edx, _joyGetDevCapsW_Thunk
  jmp _joyGetDevCapsW_Thunk
end;

procedure lstrcatW_Thunk;
asm
  mov eax, fnlstrcatW
  lea edx, _lstrcatW_Thunk
  jmp _lstrcatW_Thunk
end;

procedure lstrcmpW_Thunk;
asm
  mov eax, fnlstrcmpW
  lea edx, _lstrcmpW_Thunk
  jmp _lstrcmpW_Thunk
end;

procedure lstrcmpiW_Thunk;
asm
  mov eax, fnlstrcmpiW
  lea edx, _lstrcmpiW_Thunk
  jmp _lstrcmpiW_Thunk
end;

procedure lstrcpyW_Thunk;
asm
  mov eax, fnlstrcpyW
  lea edx, _lstrcpyW_Thunk
  jmp _lstrcpyW_Thunk
end;

procedure lstrcpynW_Thunk;
asm
  mov eax, fnlstrcpynW
  lea edx, _lstrcpynW_Thunk
  jmp _lstrcpynW_Thunk
end;

procedure lstrlenW_Thunk;
asm
  mov eax, fnlstrlenW
  lea edx, _lstrlenW_Thunk
  jmp _lstrlenW_Thunk
end;

procedure mciGetDeviceIDW_Thunk;
asm
  mov eax, fnmciGetDeviceIDW
  lea edx, _mciGetDeviceIDW_Thunk
  jmp _mciGetDeviceIDW_Thunk
end;

procedure mciGetErrorStringW_Thunk;
asm
  mov eax, fnmciGetErrorStringW
  lea edx, _mciGetErrorStringW_Thunk
  jmp _mciGetErrorStringW_Thunk
end;

procedure mciSendCommandW_Thunk;
asm
  mov eax, fnmciSendCommandW
  lea edx, _mciSendCommandW_Thunk
  jmp _mciSendCommandW_Thunk
end;

procedure mciSendStringW_Thunk;
asm
  mov eax, fnmciSendStringW
  lea edx, _mciSendStringW_Thunk
  jmp _mciSendStringW_Thunk
end;

procedure midiInGetDevCapsW_Thunk;
asm
  mov eax, fnmidiInGetDevCapsW
  lea edx, _midiInGetDevCapsW_Thunk
  jmp _midiInGetDevCapsW_Thunk
end;

procedure midiInGetErrorTextW_Thunk;
asm
  mov eax, fnmidiInGetErrorTextW
  lea edx, _midiInGetErrorTextW_Thunk
  jmp _midiInGetErrorTextW_Thunk
end;

procedure midiOutGetDevCapsW_Thunk;
asm
  mov eax, fnmidiOutGetDevCapsW
  lea edx, _midiOutGetDevCapsW_Thunk
  jmp _midiOutGetDevCapsW_Thunk
end;

procedure midiOutGetErrorTextW_Thunk;
asm
  mov eax, fnmidiOutGetErrorTextW
  lea edx, _midiOutGetErrorTextW_Thunk
  jmp _midiOutGetErrorTextW_Thunk
end;

procedure mixerGetControlDetailsW_Thunk;
asm
  mov eax, fnmixerGetControlDetailsW
  lea edx, _mixerGetControlDetailsW_Thunk
  jmp _mixerGetControlDetailsW_Thunk
end;

procedure mixerGetDevCapsW_Thunk;
asm
  mov eax, fnmixerGetDevCapsW
  lea edx, _mixerGetDevCapsW_Thunk
  jmp _mixerGetDevCapsW_Thunk
end;

procedure mixerGetLineControlsW_Thunk;
asm
  mov eax, fnmixerGetLineControlsW
  lea edx, _mixerGetLineControlsW_Thunk
  jmp _mixerGetLineControlsW_Thunk
end;

procedure mixerGetLineInfoW_Thunk;
asm
  mov eax, fnmixerGetLineInfoW
  lea edx, _mixerGetLineInfoW_Thunk
  jmp _mixerGetLineInfoW_Thunk
end;

procedure mmioInstallIOProcW_Thunk;
asm
  mov eax, fnmmioInstallIOProcW
  lea edx, _mmioInstallIOProcW_Thunk
  jmp _mmioInstallIOProcW_Thunk
end;

procedure mmioOpenW_Thunk;
asm
  mov eax, fnmmioOpenW
  lea edx, _mmioOpenW_Thunk
  jmp _mmioOpenW_Thunk
end;

procedure mmioRenameW_Thunk;
asm
  mov eax, fnmmioRenameW
  lea edx, _mmioRenameW_Thunk
  jmp _mmioRenameW_Thunk
end;

procedure mmioStringToFOURCCW_Thunk;
asm
  mov eax, fnmmioStringToFOURCCW
  lea edx, _mmioStringToFOURCCW_Thunk
  jmp _mmioStringToFOURCCW_Thunk
end;

procedure sndPlaySoundW_Thunk;
asm
  mov eax, fnsndPlaySoundW
  lea edx, _sndPlaySoundW_Thunk
  jmp _sndPlaySoundW_Thunk
end;

procedure waveInGetDevCapsW_Thunk;
asm
  mov eax, fnwaveInGetDevCapsW
  lea edx, _waveInGetDevCapsW_Thunk
  jmp _waveInGetDevCapsW_Thunk
end;

procedure waveInGetErrorTextW_Thunk;
asm
  mov eax, fnwaveInGetErrorTextW
  lea edx, _waveInGetErrorTextW_Thunk
  jmp _waveInGetErrorTextW_Thunk
end;

procedure waveOutGetDevCapsW_Thunk;
asm
  mov eax, fnwaveOutGetDevCapsW
  lea edx, _waveOutGetDevCapsW_Thunk
  jmp _waveOutGetDevCapsW_Thunk
end;

procedure waveOutGetErrorTextW_Thunk;
asm
  mov eax, fnwaveOutGetErrorTextW
  lea edx, _waveOutGetErrorTextW_Thunk
  jmp _waveOutGetErrorTextW_Thunk
end;

procedure wsprintfW_Thunk;
asm
  mov eax, fnwsprintfW
  lea edx, _wsprintfW_Thunk
  jmp _wsprintfW_Thunk
end;

procedure wvsprintfW_Thunk;
asm
  mov eax, fnwvsprintfW
  lea edx, _wvsprintfW_Thunk
  jmp _wvsprintfW_Thunk
end;
{$ENDREGION}

// This variable holds information about all the MSLU functions, including their
// names, the modules they reside in, which Unicows_X variables override them,
// which thunk variables resolve to them, and which functions get called when
// the MSLU functions are not available.
{$REGION ' MSLU Function Data '}
var
  MSLUData: TMSLUProcInfoArray = (
    (Name: 'AcquireCredentialsHandleW'; Module: mSecur32; Override: @Unicows_AcquireCredentialsHandleW;
      Thunk: AcquireCredentialsHandleW_Thunk; ErrorHandler: ThunkError; ParamBytes: 36; ErrorReturn: $1305{!!!Sec_E_SecPkg_Not_Found}),
    (Name: 'AddAtomW'; Module: mKernel32; Override: @@Unicows_AddAtomW;
      Thunk: AddAtomW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'AddFontResourceW'; Module: mGDI32; Override: @@Unicows_AddFontResourceW;
      Thunk: AddFontResourceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: 0),
    (Name: 'AddJobW'; Module: mWinSpool; Override: @@Unicows_AddJobW;
      Thunk: AddJobW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'AddMonitorW'; Module: mWinSpool; Override: @@Unicows_AddMonitorW;
      Thunk: AddMonitorW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'AddPortW'; Module: mWinSpool; Override: @@Unicows_AddPortW;
      Thunk: AddPortW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'AddPrintProcessorW'; Module: mWinSpool; Override: @@Unicows_AddPrintProcessorW;
      Thunk: AddPrintProcessorW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'AddPrintProvidorW'; Module: mWinSpool; Override: @@Unicows_AddPrintProvidorW;
      Thunk: AddPrintProvidorW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'AddPrinterDriverW'; Module: mWinSpool; Override: @@Unicows_AddPrinterDriverW;
      Thunk: AddPrinterDriverW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'AddPrinterW'; Module: mWinSpool; Override: @@Unicows_AddPrinterW;
      Thunk: AddPrinterW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'AdvancedDocumentPropertiesW'; Module: mWinSpool; Override: @@Unicows_AdvancedDocumentPropertiesW;
      Thunk: AdvancedDocumentPropertiesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'AppendMenuW'; Module: mUser32; Override: @@Unicows_AppendMenuW;
      Thunk: AppendMenuW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'BeginUpdateResourceA'; Module: mKernel32; Override: @@Unicows_BeginUpdateResourceA;
      Thunk: BeginUpdateResourceA_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'BeginUpdateResourceW'; Module: mKernel32; Override: @@Unicows_BeginUpdateResourceW;
      Thunk: BeginUpdateResourceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'BroadcastSystemMessageW'; Module: mUser32; Override: @@Unicows_BroadcastSystemMessageW;
      Thunk: BroadcastSystemMessageW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: Cardinal(-1); LastError: Error_Call_Not_Implemented),
    (Name: 'BuildCommDCBAndTimeoutsW'; Module: mKernel32; Override: @@Unicows_BuildCommDCBAndTimeoutsW;
      Thunk: BuildCommDCBAndTimeoutsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'BuildCommDCBW'; Module: mKernel32; Override: @@Unicows_BuildCommDCBW;
      Thunk: BuildCommDCBW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'CallMsgFilterW'; Module: mUser32; Override: @@Unicows_CallMsgFilterW;
      Thunk: CallMsgFilterW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'CallNamedPipeW'; Module: mKernel32; Override: @@Unicows_CallNamedPipeW;
      Thunk: CallNamedPipeW_Thunk; ErrorHandler: ThunkError; ParamBytes: 28; LastError: Error_Call_Not_Implemented),
    (Name: 'CallWindowProcA'; Module: mUser32; Override: @@Unicows_CallWindowProcA;
      Thunk: CallWindowProcA_Thunk; ErrorHandler: ThunkError; ParamBytes: 20),
    (Name: 'CallWindowProcW'; Module: mUser32; Override: @@Unicows_CallWindowProcW;
      Thunk: CallWindowProcW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20),
    (Name: 'ChangeDisplaySettingsExW'; Module: mUser32; Override: @@Unicows_ChangeDisplaySettingsExW;
      Thunk: ChangeDisplaySettingsExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: Cardinal(Disp_Change_BadFlags)),
    (Name: 'ChangeDisplaySettingsW'; Module: mUser32; Override: @@Unicows_ChangeDisplaySettingsW;
      Thunk: ChangeDisplaySettingsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Cardinal(Disp_Change_BadFlags)),
    (Name: 'ChangeMenuW'; Module: mUser32; Override: @@Unicows_ChangeMenuW;
      Thunk: ChangeMenuW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'CharLowerBuffW'; Module: mUser32; Override: @@Unicows_CharLowerBuffW;
      Thunk: CharLowerBuffW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'CharLowerW'; Module: mUser32; Override: @@Unicows_CharLowerW;
      Thunk: CharLowerW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'CharNextW'; Module: mUser32; Override: @@Unicows_CharNextW;
      Thunk: CharNextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'CharPrevW'; Module: mUser32; Override: @@Unicows_CharPrevW;
      Thunk: CharPrevW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'CharToOemBuffW'; Module: mUser32; Override: @@Unicows_CharToOemBuffW;
      Thunk: CharToOemBuffW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'CharToOemW'; Module: mUser32; Override: @@Unicows_CharToOemW;
      Thunk: CharToOemW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'CharUpperBuffW'; Module: mUser32; Override: @@Unicows_CharUpperBuffW;
      Thunk: CharUpperBuffW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'CharUpperW'; Module: mUser32; Override: @@Unicows_CharUpperW;
      Thunk: CharUpperW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'ChooseColorW'; Module: mComDlg32; Override: @@Unicows_ChooseColorW;
      Thunk: ChooseColorW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'ChooseFontW'; Module: mComDlg32; Override: @@Unicows_ChooseFontW;
      Thunk: ChooseFontW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'CommConfigDialogW'; Module: mKernel32; Override: @@Unicows_CommConfigDialogW;
      Thunk: CommConfigDialogW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'CompareStringW'; Module: mKernel32; Override: @@Unicows_CompareStringW;
      Thunk: CompareStringW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'ConfigurePortW'; Module: mWinSpool; Override: @@Unicows_ConfigurePortW;
      Thunk: ConfigurePortW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'CopyAcceleratorTableW'; Module: mUser32; Override: @@Unicows_CopyAcceleratorTableW;
      Thunk: CopyAcceleratorTableW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'CopyEnhMetaFileW'; Module: mGDI32; Override: @@Unicows_CopyEnhMetaFileW;
      Thunk: CopyEnhMetaFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'CopyFileExW'; Module: mKernel32; Override: @@Unicows_CopyFileExW;
      Thunk: CopyFileExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'CopyFileW'; Module: mKernel32; Override: @@Unicows_CopyFileW;
      Thunk: CopyFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'CopyMetaFileW'; Module: mGDI32; Override: @@Unicows_CopyMetaFileW;
      Thunk: CopyMetaFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateAcceleratorTableW'; Module: mUser32; Override: @@Unicows_CreateAcceleratorTableW;
      Thunk: CreateAcceleratorTableW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateColorSpaceW'; Module: mGDI32; Override: @@Unicows_CreateColorSpaceW;
      Thunk: CreateColorSpaceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'CreateDCW'; Module: mGDI32; Override: @@Unicows_CreateDCW;
      Thunk: CreateDCW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateDialogIndirectParamW'; Module: mUser32; Override: @@Unicows_CreateDialogIndirectParamW;
      Thunk: CreateDialogIndirectParamW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateDialogParamW'; Module: mUser32; Override: @@Unicows_CreateDialogParamW;
      Thunk: CreateDialogParamW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateDirectoryExW'; Module: mKernel32; Override: @@Unicows_CreateDirectoryExW;
      Thunk: CreateDirectoryExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateDirectoryW'; Module: mKernel32; Override: @@Unicows_CreateDirectoryW;
      Thunk: CreateDirectoryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateEnhMetaFileW'; Module: mGDI32; Override: @@Unicows_CreateEnhMetaFileW;
      Thunk: CreateEnhMetaFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateEventW'; Module: mKernel32; Override: @@Unicows_CreateEventW;
      Thunk: CreateEventW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateFileMappingW'; Module: mKernel32; Override: @@Unicows_CreateFileMappingW;
      Thunk: CreateFileMappingW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateFileW'; Module: mKernel32; Override: @@Unicows_CreateFileW;
      Thunk: CreateFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 28; ErrorReturn: Invalid_Handle_Value; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateFontIndirectW'; Module: mGDI32; Override: @@Unicows_CreateFontIndirectW;
      Thunk: CreateFontIndirectW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateFontW'; Module: mGDI32; Override: @@Unicows_CreateFontW;
      Thunk: CreateFontW_Thunk; ErrorHandler: ThunkError; ParamBytes: 56; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateICW'; Module: mGDI32; Override: @@Unicows_CreateICW;
      Thunk: CreateICW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateMDIWindowW'; Module: mUser32; Override: @@Unicows_CreateMDIWindowW;
      Thunk: CreateMDIWindowW_Thunk; ErrorHandler: ThunkError; ParamBytes: 40; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateMailslotW'; Module: mKernel32; Override: @@Unicows_CreateMailslotW;
      Thunk: CreateMailslotW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: Invalid_Handle_Value; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateMetaFileW'; Module: mGDI32; Override: @@Unicows_CreateMetaFileW;
      Thunk: CreateMetaFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateMutexW'; Module: mKernel32; Override: @@Unicows_CreateMutexW;
      Thunk: CreateMutexW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateNamedPipeW'; Module: mKernel32; Override: @@Unicows_CreateNamedPipeW;
      Thunk: CreateNamedPipeW_Thunk; ErrorHandler: ThunkError; ParamBytes: 32; ErrorReturn: Invalid_Handle_Value; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateProcessW'; Module: mKernel32; Override: @@Unicows_CreateProcessW;
      Thunk: CreateProcessW_Thunk; ErrorHandler: ThunkError; ParamBytes: 40; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateScalableFontResourceW'; Module: mGDI32; Override: @@Unicows_CreateScalableFontResourceW;
      Thunk: CreateScalableFontResourceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateSemaphoreW'; Module: mKernel32; Override: @@Unicows_CreateSemaphoreW;
      Thunk: CreateSemaphoreW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateStdAccessibleProxyW'; Module: mOleAcc; Override: @@Unicows_CreateStdAccessibleProxyW;
      Thunk: CreateStdAccessibleProxyW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: Cardinal(E_NotImpl)),
    (Name: 'CreateWaitableTimerW'; Module: mKernel32; Override: @@Unicows_CreateWaitableTimerW;
      Thunk: CreateWaitableTimerW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'CreateWindowExW'; Module: mUser32; Override: @@Unicows_CreateWindowExW;
      Thunk: CreateWindowExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 48; LastError: Error_Call_Not_Implemented),
    (Name: 'CryptAcquireContextW'; Module: mAdvAPI32; Override: @Unicows_CryptAcquireContextW;
      Thunk: CryptAcquireContextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'CryptEnumProviderTypesW'; Module: mAdvAPI32; Override: @@Unicows_CryptEnumProviderTypesW;
      Thunk: CryptEnumProviderTypesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'CryptEnumProvidersW'; Module: mAdvAPI32; Override: @@Unicows_CryptEnumProvidersW;
      Thunk: CryptEnumProvidersW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'CryptGetDefaultProviderW'; Module: mAdvAPI32; Override: @@Unicows_CryptGetDefaultProviderW;
      Thunk: CryptGetDefaultProviderW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'CryptSetProviderExW'; Module: mAdvAPI32; Override: @@Unicows_CryptSetProviderExW;
      Thunk: CryptSetProviderExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'CryptSetProviderW'; Module: mAdvAPI32; Override: @@Unicows_CryptSetProviderW;
      Thunk: CryptSetProviderW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'CryptSignHashW'; Module: mAdvAPI32; Override: @Unicows_CryptSignHashW;
      Thunk: CryptSignHashW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'CryptVerifySignatureW'; Module: mAdvAPI32; Override: @Unicows_CryptVerifySignatureW;
      Thunk: CryptVerifySignatureW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'DdeConnect'; Module: mUser32; Override: @@Unicows_DdeConnect;
      Thunk: DdeConnect_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: 0),
    (Name: 'DdeConnectList'; Module: mUser32; Override: @@Unicows_DdeConnectList;
      Thunk: DdeConnectList_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: 0),
    (Name: 'DdeCreateStringHandleW'; Module: mUser32; Override: @@Unicows_DdeCreateStringHandleW;
      Thunk: DdeCreateStringHandleW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'DdeInitializeW'; Module: mUser32; Override: @@Unicows_DdeInitializeW;
      Thunk: DdeInitializeW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: DmlErr_InvalidParameter),
    (Name: 'DdeQueryConvInfo'; Module: mUser32; Override: @@Unicows_DdeQueryConvInfo;
      Thunk: DdeQueryConvInfo_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'DdeQueryStringW'; Module: mUser32; Override: @@Unicows_DdeQueryStringW;
      Thunk: DdeQueryStringW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: 0),
    (Name: 'DefDlgProcW'; Module: mUser32; Override: @@Unicows_DefDlgProcW;
      Thunk: DefDlgProcW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: 0),
    (Name: 'DefFrameProcW'; Module: mUser32; Override: @@Unicows_DefFrameProcW;
      Thunk: DefFrameProcW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: 0),
    (Name: 'DefMDIChildProcW'; Module: mUser32; Override: @@Unicows_DefMDIChildProcW;
      Thunk: DefMDIChildProcW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: 0),
    (Name: 'DefWindowProcW'; Module: mUser32; Override: @@Unicows_DefWindowProcW;
      Thunk: DefWindowProcW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: 0),
    (Name: 'DeleteFileW'; Module: mKernel32; Override: @@Unicows_DeleteFileW;
      Thunk: DeleteFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'DeleteMonitorW'; Module: mWinSpool; Override: @@Unicows_DeleteMonitorW;
      Thunk: DeleteMonitorW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'DeletePortW'; Module: mWinSpool; Override: @@Unicows_DeletePortW;
      Thunk: DeletePortW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'DeletePrintProcessorW'; Module: mWinSpool; Override: @@Unicows_DeletePrintProcessorW;
      Thunk: DeletePrintProcessorW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'DeletePrintProvidorW'; Module: mWinSpool; Override: @@Unicows_DeletePrintProvidorW;
      Thunk: DeletePrintProvidorW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'DeletePrinterDriverW'; Module: mWinSpool; Override: @@Unicows_DeletePrinterDriverW;
      Thunk: DeletePrinterDriverW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'DeviceCapabilitiesW'; Module: mWinSpool; Override: @@Unicows_DeviceCapabilitiesW;
      Thunk: DeviceCapabilitiesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: Cardinal(-1); LastError: Error_Call_Not_Implemented),
    (Name: 'DialogBoxIndirectParamW'; Module: mUser32; Override: @@Unicows_DialogBoxIndirectParamW;
      Thunk: DialogBoxIndirectParamW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: Cardinal(-1); LastError: Error_Call_Not_Implemented),
    (Name: 'DialogBoxParamW'; Module: mUser32; Override: @@Unicows_DialogBoxParamW;
      Thunk: DialogBoxParamW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: Cardinal(-1); LastError: Error_Call_Not_Implemented),
    (Name: 'DispatchMessageW'; Module: mUser32; Override: @@Unicows_DispatchMessageW;
      Thunk: DispatchMessageW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4),
    (Name: 'DlgDirListComboBoxW'; Module: mUser32; Override: @@Unicows_DlgDirListComboBoxW;
      Thunk: DlgDirListComboBoxW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'DlgDirListW'; Module: mUser32; Override: @@Unicows_DlgDirListW;
      Thunk: DlgDirListW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'DlgDirSelectComboBoxExW'; Module: mUser32; Override: @@Unicows_DlgDirSelectComboBoxExW;
      Thunk: DlgDirSelectComboBoxExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'DlgDirSelectExW'; Module: mUser32; Override: @@Unicows_DlgDirSelectExW;
      Thunk: DlgDirSelectExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'DocumentPropertiesW'; Module: mWinSpool; Override: @@Unicows_DocumentPropertiesW;
      Thunk: DocumentPropertiesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; ErrorReturn: Cardinal(-1); LastError: Error_Call_Not_Implemented),
    (Name: 'DragQueryFileW'; Module: mShell32; Override: @@Unicows_DragQueryFileW;
      Thunk: DragQueryFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: 0),
    (Name: 'DrawStateW'; Module: mUser32; Override: @@Unicows_DrawStateW;
      Thunk: DrawStateW_Thunk; ErrorHandler: ThunkError; ParamBytes: 40; LastError: Error_Call_Not_Implemented),
    (Name: 'DrawTextExW'; Module: mUser32; Override: @@Unicows_DrawTextExW;
      Thunk: DrawTextExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'DrawTextW'; Module: mUser32; Override: @@Unicows_DrawTextW;
      Thunk: DrawTextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'EnableWindow'; Module: mUser32; Override: @@Unicows_EnableWindow;
      Thunk: EnableWindow_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'EndUpdateResourceA'; Module: mKernel32; Override: @@Unicows_EndUpdateResourceA;
      Thunk: EndUpdateResourceA_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'EndUpdateResourceW'; Module: mKernel32; Override: @@Unicows_EndUpdateResourceW;
      Thunk: EndUpdateResourceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumCalendarInfoExW'; Module: mKernel32; Override: @Unicows_EnumCalendarInfoExW;
      Thunk: EnumCalendarInfoExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumCalendarInfoW'; Module: mKernel32; Override: @Unicows_EnumCalendarInfoW;
      Thunk: EnumCalendarInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumClipboardFormats'; Module: mUser32; Override: @@Unicows_EnumClipboardFormats;
      Thunk: EnumClipboardFormats_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumDateFormatsExW'; Module: mKernel32; Override: @Unicows_EnumDateFormatsExW;
      Thunk: EnumDateFormatsExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumDateFormatsW'; Module: mKernel32; Override: @Unicows_EnumDateFormatsW;
      Thunk: EnumDateFormatsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumDisplayDevicesW'; Module: mUser32; Override: @@Unicows_EnumDisplayDevicesW;
      Thunk: EnumDisplayDevicesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: 0),
    (Name: 'EnumDisplaySettingsExW'; Module: mUser32; Override: @@Unicows_EnumDisplaySettingsExW;
      Thunk: EnumDisplaySettingsExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumDisplaySettingsW'; Module: mUser32; Override: @@Unicows_EnumDisplaySettingsW;
      Thunk: EnumDisplaySettingsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumFontFamiliesExW'; Module: mGDI32; Override: @@Unicows_EnumFontFamiliesExW;
      Thunk: EnumFontFamiliesExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: 0),
    (Name: 'EnumFontFamiliesW'; Module: mGDI32; Override: @@Unicows_EnumFontFamiliesW;
      Thunk: EnumFontFamiliesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: 0),
    (Name: 'EnumFontsW'; Module: mGDI32; Override: @@Unicows_EnumFontsW;
      Thunk: EnumFontsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: 0),
    (Name: 'EnumICMProfilesW'; Module: mGDI32; Override: @@Unicows_EnumICMProfilesW;
      Thunk: EnumICMProfilesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Cardinal(-1)),
    (Name: 'EnumMonitorsW'; Module: mWinSpool; Override: @@Unicows_EnumMonitorsW;
      Thunk: EnumMonitorsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumPortsW'; Module: mWinSpool; Override: @@Unicows_EnumPortsW;
      Thunk: EnumPortsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumPrintProcessorDatatypesW'; Module: mWinSpool; Override: @@Unicows_EnumPrintProcessorDatatypesW;
      Thunk: EnumPrintProcessorDatatypesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 28; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumPrintProcessorsW'; Module: mWinSpool; Override: @@Unicows_EnumPrintProcessorsW;
      Thunk: EnumPrintProcessorsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 28; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumPrinterDriversW'; Module: mWinSpool; Override: @@Unicows_EnumPrinterDriversW;
      Thunk: EnumPrinterDriversW_Thunk; ErrorHandler: ThunkError; ParamBytes: 28; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumPrintersW'; Module: mWinSpool; Override: @@Unicows_EnumPrintersW;
      Thunk: EnumPrintersW_Thunk; ErrorHandler: ThunkError; ParamBytes: 28; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumPropsA'; Module: mUser32; Override: @@Unicows_EnumPropsA;
      Thunk: EnumPropsA_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Cardinal(-1)),
    (Name: 'EnumPropsExA'; Module: mUser32; Override: @@Unicows_EnumPropsExA;
      Thunk: EnumPropsExA_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Cardinal(-1)),
    (Name: 'EnumPropsExW'; Module: mUser32; Override: @@Unicows_EnumPropsExW;
      Thunk: EnumPropsExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Cardinal(-1)),
    (Name: 'EnumPropsW'; Module: mUser32; Override: @@Unicows_EnumPropsW;
      Thunk: EnumPropsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Cardinal(-1)),
    (Name: 'EnumSystemCodePagesW'; Module: mKernel32; Override: @@Unicows_EnumSystemCodePagesW;
      Thunk: EnumSystemCodePagesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumSystemLocalesW'; Module: mKernel32; Override: @@Unicows_EnumSystemLocalesW;
      Thunk: EnumSystemLocalesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumTimeFormatsW'; Module: mKernel32; Override: @@Unicows_EnumTimeFormatsW;
      Thunk: EnumTimeFormatsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'EnumerateSecurityPackagesW'; Module: mSecur32; Override: @Unicows_EnumerateSecurityPackagesW;
      Thunk: EnumerateSecurityPackagesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'ExpandEnvironmentStringsW'; Module: mKernel32; Override: @@Unicows_ExpandEnvironmentStringsW;
      Thunk: ExpandEnvironmentStringsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'ExtTextOutW'; Module: mGDI32; Override: @@Unicows_ExtTextOutW;
      Thunk: ExtTextOutW_Thunk; ErrorHandler: ThunkError; ParamBytes: 32; LastError: Error_Call_Not_Implemented),
    (Name: 'ExtractIconExW'; Module: mShell32; Override: @@Unicows_ExtractIconExW;
      Thunk: ExtractIconExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: 0),
    (Name: 'ExtractIconW'; Module: mShell32; Override: @@Unicows_ExtractIconW;
      Thunk: ExtractIconW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'FatalAppExitW'; Module: mKernel32; Override: @@Unicows_FatalAppExitW;
      Thunk: FatalAppExitW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8),
    (Name: 'FillConsoleOutputCharacterW'; Module: mKernel32; Override: @@Unicows_FillConsoleOutputCharacterW;
      Thunk: FillConsoleOutputCharacterW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'FindAtomW'; Module: mKernel32; Override: @@Unicows_FindAtomW;
      Thunk: FindAtomW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'FindExecutableW'; Module: mShell32; Override: @@Unicows_FindExecutableW;
      Thunk: FindExecutableW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: se_Err_FNF),
    (Name: 'FindFirstChangeNotificationW'; Module: mKernel32; Override: @@Unicows_FindFirstChangeNotificationW;
      Thunk: FindFirstChangeNotificationW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Invalid_Handle_Value; LastError: Error_Call_Not_Implemented),
    (Name: 'FindFirstFileW'; Module: mKernel32; Override: @@Unicows_FindFirstFileW;
      Thunk: FindFirstFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Invalid_Handle_Value; LastError: Error_Call_Not_Implemented),
    (Name: 'FindNextFileW'; Module: mKernel32; Override: @@Unicows_FindNextFileW;
      Thunk: FindNextFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'FindResourceExW'; Module: mKernel32; Override: @@Unicows_FindResourceExW;
      Thunk: FindResourceExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'FindResourceW'; Module: mKernel32; Override: @@Unicows_FindResourceW;
      Thunk: FindResourceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'FindTextW'; Module: mComDlg32; Override: @@Unicows_FindTextW;
      Thunk: FindTextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'FindWindowExW'; Module: mUser32; Override: @@Unicows_FindWindowExW;
      Thunk: FindWindowExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'FindWindowW'; Module: mUser32; Override: @@Unicows_FindWindowW;
      Thunk: FindWindowW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'FormatMessageW'; Module: mKernel32; Override: @@Unicows_FormatMessageW;
      Thunk: FormatMessageW_Thunk; ErrorHandler: ThunkError; ParamBytes: 28; LastError: Error_Call_Not_Implemented),
    (Name: 'FreeContextBuffer'; Module: mSecur32; Override: @Unicows_FreeContextBuffer;
      Thunk: FreeContextBuffer_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'FreeEnvironmentStringsW'; Module: mKernel32; Override: @@Unicows_FreeEnvironmentStringsW;
      Thunk: FreeEnvironmentStringsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'GetAltTabInfoW'; Module: mUser32; Override: @@Unicows_GetAltTabInfoW;
      Thunk: GetAltTabInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'GetAtomNameW'; Module: mKernel32; Override: @@Unicows_GetAtomNameW;
      Thunk: GetAtomNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetCPInfo'; Module: mKernel32; Override: @@Unicows_GetCPInfo;
      Thunk: GetCPInfo_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetCPInfoExW'; Module: mKernel32; Override: @Unicows_GetCPInfoExW;
      Thunk: GetCPInfoExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetCalendarInfoW'; Module: mKernel32; Override: @@Unicows_GetCalendarInfoW;
      Thunk: GetCalendarInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'GetCharABCWidthsFloatW'; Module: mGDI32; Override: @@Unicows_GetCharABCWidthsFloatW;
      Thunk: GetCharABCWidthsFloatW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetCharABCWidthsW'; Module: mGDI32; Override: @@Unicows_GetCharABCWidthsW;
      Thunk: GetCharABCWidthsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetCharWidth32W'; Module: mGDI32; Override: @@Unicows_GetCharWidth32W;
      Thunk: GetCharWidth32W_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetCharWidthFloatW'; Module: mGDI32; Override: @@Unicows_GetCharWidthFloatW;
      Thunk: GetCharWidthFloatW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetCharWidthW'; Module: mGDI32; Override: @@Unicows_GetCharWidthW;
      Thunk: GetCharWidthW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetCharacterPlacementW'; Module: mGDI32; Override: @@Unicows_GetCharacterPlacementW;
      Thunk: GetCharacterPlacementW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'GetClassInfoExW'; Module: mUser32; Override: @@Unicows_GetClassInfoExW;
      Thunk: GetClassInfoExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetClassInfoW'; Module: mUser32; Override: @@Unicows_GetClassInfoW;
      Thunk: GetClassInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetClassLongW'; Module: mUser32; Override: @@Unicows_GetClassLongW;
      Thunk: GetClassLongW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetClassNameW'; Module: mUser32; Override: @@Unicows_GetClassNameW;
      Thunk: GetClassNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetClipboardData'; Module: mUser32; Override: @@Unicows_GetClipboardData;
      Thunk: GetClipboardData_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'GetClipboardFormatNameW'; Module: mUser32; Override: @@Unicows_GetClipboardFormatNameW;
      Thunk: GetClipboardFormatNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetComputerNameW'; Module: mKernel32; Override: @@Unicows_GetComputerNameW;
      Thunk: GetComputerNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetConsoleTitleW'; Module: mKernel32; Override: @@Unicows_GetConsoleTitleW;
      Thunk: GetConsoleTitleW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetCurrencyFormatW'; Module: mKernel32; Override: @@Unicows_GetCurrencyFormatW;
      Thunk: GetCurrencyFormatW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'GetCurrentDirectoryW'; Module: mKernel32; Override: @@Unicows_GetCurrentDirectoryW;
      Thunk: GetCurrentDirectoryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetCurrentHwProfileW'; Module: mAdvAPI32; Override: @@Unicows_GetCurrentHwProfileW;
      Thunk: GetCurrentHwProfileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'GetDateFormatW'; Module: mKernel32; Override: @@Unicows_GetDateFormatW;
      Thunk: GetDateFormatW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'GetDefaultCommConfigW'; Module: mKernel32; Override: @@Unicows_GetDefaultCommConfigW;
      Thunk: GetDefaultCommConfigW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetDiskFreeSpaceExW'; Module: mKernel32; Override: @@Unicows_GetDiskFreeSpaceExW;
      Thunk: GetDiskFreeSpaceExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetDiskFreeSpaceW'; Module: mKernel32; Override: @@Unicows_GetDiskFreeSpaceW;
      Thunk: GetDiskFreeSpaceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'GetDlgItemTextW'; Module: mUser32; Override: @@Unicows_GetDlgItemTextW;
      Thunk: GetDlgItemTextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetDriveTypeW'; Module: mKernel32; Override: @@Unicows_GetDriveTypeW;
      Thunk: GetDriveTypeW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: Drive_Unknown),
    (Name: 'GetEnhMetaFileDescriptionW'; Module: mGDI32; Override: @@Unicows_GetEnhMetaFileDescriptionW;
      Thunk: GetEnhMetaFileDescriptionW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Gdi_Error; LastError: Error_Call_Not_Implemented),
    (Name: 'GetEnhMetaFileW'; Module: mGDI32; Override: @@Unicows_GetEnhMetaFileW;
      Thunk: GetEnhMetaFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'GetEnvironmentStringsW'; Module: mKernel32; Override: @@Unicows_GetEnvironmentStringsW;
      Thunk: GetEnvironmentStringsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 0; ErrorReturn: 0),
    (Name: 'GetEnvironmentVariableW'; Module: mKernel32; Override: @@Unicows_GetEnvironmentVariableW;
      Thunk: GetEnvironmentVariableW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetFileAttributesExW'; Module: mKernel32; Override: @@Unicows_GetFileAttributesExW;
      Thunk: GetFileAttributesExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetFileAttributesW'; Module: mKernel32; Override: @@Unicows_GetFileAttributesW;
      Thunk: GetFileAttributesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: Cardinal(-1){!!!Invalid_File_Attributes}; LastError: Error_Call_Not_Implemented),
    (Name: 'GetFileTitleW'; Module: mComDlg32; Override: @@Unicows_GetFileTitleW;
      Thunk: GetFileTitleW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Cardinal(-1)),
    (Name: 'GetFileVersionInfoSizeW'; Module: mVersion; Override: @@Unicows_GetFileVersionInfoSizeW;
      Thunk: GetFileVersionInfoSizeW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetFileVersionInfoW'; Module: mVersion; Override: @@Unicows_GetFileVersionInfoW;
      Thunk: GetFileVersionInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetFullPathNameW'; Module: mKernel32; Override: @@Unicows_GetFullPathNameW;
      Thunk: GetFullPathNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetGlyphOutlineW'; Module: mGDI32; Override: @@Unicows_GetGlyphOutlineW;
      Thunk: GetGlyphOutlineW_Thunk; ErrorHandler: ThunkError; ParamBytes: 28; ErrorReturn: Gdi_Error; LastError: Error_Call_Not_Implemented),
    (Name: 'GetICMProfileW'; Module: mGDI32; Override: @@Unicows_GetICMProfileW;
      Thunk: GetICMProfileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'GetJobW'; Module: mWinSpool; Override: @@Unicows_GetJobW;
      Thunk: GetJobW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'GetKerningPairsW'; Module: mGDI32; Override: @Unicows_GetKerningPairsW;
      Thunk: GetKerningPairsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetKeyNameTextW'; Module: mUser32; Override: @@Unicows_GetKeyNameTextW;
      Thunk: GetKeyNameTextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetKeyboardLayoutNameW'; Module: mUser32; Override: @@Unicows_GetKeyboardLayoutNameW;
      Thunk: GetKeyboardLayoutNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'GetLocaleInfoW'; Module: mKernel32; Override: @@Unicows_GetLocaleInfoW;
      Thunk: GetLocaleInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetLogColorSpaceW'; Module: mGDI32; Override: @@Unicows_GetLogColorSpaceW;
      Thunk: GetLogColorSpaceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'GetLogicalDriveStringsW'; Module: mKernel32; Override: @@Unicows_GetLogicalDriveStringsW;
      Thunk: GetLogicalDriveStringsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetLongPathNameW'; Module: mKernel32; Override: @@Unicows_GetLongPathNameW;
      Thunk: GetLongPathNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetMenuItemInfoW'; Module: mUser32; Override: @@Unicows_GetMenuItemInfoW;
      Thunk: GetMenuItemInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetMenuStringW'; Module: mUser32; Override: @@Unicows_GetMenuStringW;
      Thunk: GetMenuStringW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: 0),
    (Name: 'GetMessageW'; Module: mUser32; Override: @@Unicows_GetMessageW;
      Thunk: GetMessageW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: Cardinal(-1); LastError: Error_Call_Not_Implemented),
    (Name: 'GetMetaFileW'; Module: mGDI32; Override: @@Unicows_GetMetaFileW;
      Thunk: GetMetaFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'GetModuleFileNameW'; Module: mKernel32; Override: @@Unicows_GetModuleFileNameW;
      Thunk: GetModuleFileNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetModuleHandleW'; Module: mKernel32; Override: @@Unicows_GetModuleHandleW;
      Thunk: GetModuleHandleW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'GetMonitorInfoW'; Module: mUser32; Override: @@Unicows_GetMonitorInfoW;
      Thunk: GetMonitorInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetNamedPipeHandleStateW'; Module: mKernel32; Override: @@Unicows_GetNamedPipeHandleStateW;
      Thunk: GetNamedPipeHandleStateW_Thunk; ErrorHandler: ThunkError; ParamBytes: 28; LastError: Error_Call_Not_Implemented),
    (Name: 'GetNumberFormatW'; Module: mKernel32; Override: @@Unicows_GetNumberFormatW;
      Thunk: GetNumberFormatW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'GetObjectW'; Module: mGDI32; Override: @@Unicows_GetObjectW;
      Thunk: GetObjectW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetOpenFileNamePreviewW'; Module: mVFW32; Override: @@Unicows_GetOpenFileNamePreviewW;
      Thunk: GetOpenFileNamePreviewW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: Invalid_Handle_Value),
    (Name: 'GetOpenFileNameW'; Module: mComDlg32; Override: @@Unicows_GetOpenFileNameW;
      Thunk: GetOpenFileNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'GetOutlineTextMetricsW'; Module: mGDI32; Override: @@Unicows_GetOutlineTextMetricsW;
      Thunk: GetOutlineTextMetricsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetPrintProcessorDirectoryW'; Module: mWinSpool; Override: @@Unicows_GetPrintProcessorDirectoryW;
      Thunk: GetPrintProcessorDirectoryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'GetPrinterDataW'; Module: mWinSpool; Override: @@Unicows_GetPrinterDataW;
      Thunk: GetPrinterDataW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'GetPrinterDriverDirectoryW'; Module: mWinSpool; Override: @@Unicows_GetPrinterDriverDirectoryW;
      Thunk: GetPrinterDriverDirectoryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'GetPrinterDriverW'; Module: mWinSpool; Override: @@Unicows_GetPrinterDriverW;
      Thunk: GetPrinterDriverW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'GetPrinterW'; Module: mWinSpool; Override: @@Unicows_GetPrinterW;
      Thunk: GetPrinterW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'GetPrivateProfileIntW'; Module: mKernel32; Override: @@Unicows_GetPrivateProfileIntW;
      Thunk: GetPrivateProfileIntW_Thunk; ErrorHandler: _GodotFailGetPrivateProfileIntW; ParamBytes: 16),
    (Name: 'GetPrivateProfileSectionNamesW'; Module: mKernel32; Override: @@Unicows_GetPrivateProfileSectionNamesW;
      Thunk: GetPrivateProfileSectionNamesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'GetPrivateProfileSectionW'; Module: mKernel32; Override: @@Unicows_GetPrivateProfileSectionW;
      Thunk: GetPrivateProfileSectionW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: 0),
    (Name: 'GetPrivateProfileStringW'; Module: mKernel32; Override: @@Unicows_GetPrivateProfileStringW;
      Thunk: GetPrivateProfileStringW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; ErrorReturn: 0),
    (Name: 'GetPrivateProfileStructW'; Module: mKernel32; Override: @@Unicows_GetPrivateProfileStructW;
      Thunk: GetPrivateProfileStructW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: 0),
    (Name: 'GetProfileIntW'; Module: mKernel32; Override: @@Unicows_GetProfileIntW;
      Thunk: GetProfileIntW_Thunk; ErrorHandler: _GodotFailGetProfileIntW; ParamBytes: 12),
    (Name: 'GetProfileSectionW'; Module: mKernel32; Override: @@Unicows_GetProfileSectionW;
      Thunk: GetProfileSectionW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'GetProfileStringW'; Module: mKernel32; Override: @@Unicows_GetProfileStringW;
      Thunk: GetProfileStringW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: 0),
    (Name: 'GetPropA'; Module: mUser32; Override: @@Unicows_GetPropA;
      Thunk: GetPropA_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'GetPropW'; Module: mUser32; Override: @@Unicows_GetPropW;
      Thunk: GetPropW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'GetRoleTextW'; Module: mOleAcc; Override: @@Unicows_GetRoleTextW;
      Thunk: GetRoleTextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetSaveFileNamePreviewW'; Module: mVFW32; Override: @@Unicows_GetSaveFileNamePreviewW;
      Thunk: GetSaveFileNamePreviewW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: Invalid_Handle_Value),
    (Name: 'GetSaveFileNameW'; Module: mComDlg32; Override: @@Unicows_GetSaveFileNameW;
      Thunk: GetSaveFileNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'GetShortPathNameW'; Module: mKernel32; Override: @@Unicows_GetShortPathNameW;
      Thunk: GetShortPathNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetStartupInfoW'; Module: mKernel32; Override: @@Unicows_GetStartupInfoW;
      Thunk: GetStartupInfoW_Thunk; ErrorHandler: _GodotFailGetStartupInfoW; ParamBytes: 4),
    (Name: 'GetStateTextW'; Module: mOleAcc; Override: @@Unicows_GetStateTextW;
      Thunk: GetStateTextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetStringTypeExW'; Module: mKernel32; Override: @@Unicows_GetStringTypeExW;
      Thunk: GetStringTypeExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'GetStringTypeW'; Module: mKernel32; Override: @@Unicows_GetStringTypeW;
      Thunk: GetStringTypeW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetSystemDirectoryW'; Module: mKernel32; Override: @@Unicows_GetSystemDirectoryW;
      Thunk: GetSystemDirectoryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetSystemWindowsDirectoryW'; Module: mKernel32; Override: @@Unicows_GetSystemWindowsDirectoryW;
      Thunk: GetSystemWindowsDirectoryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetTabbedTextExtentW'; Module: mUser32; Override: @@Unicows_GetTabbedTextExtentW;
      Thunk: GetTabbedTextExtentW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'GetTempFileNameW'; Module: mKernel32; Override: @@Unicows_GetTempFileNameW;
      Thunk: GetTempFileNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetTempPathW'; Module: mKernel32; Override: @@Unicows_GetTempPathW;
      Thunk: GetTempPathW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetTextExtentExPointW'; Module: mGDI32; Override: @@Unicows_GetTextExtentExPointW;
      Thunk: GetTextExtentExPointW_Thunk; ErrorHandler: ThunkError; ParamBytes: 28; LastError: Error_Call_Not_Implemented),
    (Name: 'GetTextExtentPoint32W'; Module: mGDI32; Override: @@Unicows_GetTextExtentPoint32W;
      Thunk: GetTextExtentPoint32W_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetTextExtentPointW'; Module: mGDI32; Override: @@Unicows_GetTextExtentPointW;
      Thunk: GetTextExtentPointW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'GetTextFaceW'; Module: mGDI32; Override: @@Unicows_GetTextFaceW;
      Thunk: GetTextFaceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetTextMetricsW'; Module: mGDI32; Override: @@Unicows_GetTextMetricsW;
      Thunk: GetTextMetricsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetTimeFormatW'; Module: mKernel32; Override: @@Unicows_GetTimeFormatW;
      Thunk: GetTimeFormatW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'GetUserNameW'; Module: mAdvAPI32; Override: @@Unicows_GetUserNameW;
      Thunk: GetUserNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetVersionExW'; Module: mKernel32; Override: @@Unicows_GetVersionExW;
      Thunk: GetVersionExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'GetVolumeInformationW'; Module: mKernel32; Override: @@Unicows_GetVolumeInformationW;
      Thunk: GetVolumeInformationW_Thunk; ErrorHandler: ThunkError; ParamBytes: 32; LastError: Error_Call_Not_Implemented),
    (Name: 'GetWindowLongA'; Module: mUser32; Override: @@Unicows_GetWindowLongA;
      Thunk: GetWindowLongA_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetWindowLongW'; Module: mUser32; Override: @@Unicows_GetWindowLongW;
      Thunk: GetWindowLongW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GetWindowModuleFileNameW'; Module: mUser32; Override: @@Unicows_GetWindowModuleFileNameW;
      Thunk: GetWindowModuleFileNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'GetWindowTextLengthW'; Module: mUser32; Override: @@Unicows_GetWindowTextLengthW;
      Thunk: GetWindowTextLengthW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'GetWindowTextW'; Module: mUser32; Override: @@Unicows_GetWindowTextW;
      Thunk: GetWindowTextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetWindowsDirectoryW'; Module: mKernel32; Override: @@Unicows_GetWindowsDirectoryW;
      Thunk: GetWindowsDirectoryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'GlobalAddAtomW'; Module: mKernel32; Override: @@Unicows_GlobalAddAtomW;
      Thunk: GlobalAddAtomW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'GlobalFindAtomW'; Module: mKernel32; Override: @@Unicows_GlobalFindAtomW;
      Thunk: GlobalFindAtomW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'GlobalGetAtomNameW'; Module: mKernel32; Override: @@Unicows_GlobalGetAtomNameW;
      Thunk: GlobalGetAtomNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GrayStringW'; Module: mUser32; Override: @@Unicows_GrayStringW;
      Thunk: GrayStringW_Thunk; ErrorHandler: ThunkError; ParamBytes: 36; LastError: Error_Call_Not_Implemented),
    (Name: 'InitSecurityInterfaceW'; Module: mSecur32; Override: @Unicows_InitSecurityInterfaceW;
      Thunk: InitSecurityInterfaceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 0; ErrorReturn: 0),
    (Name: 'InitializeSecurityContextW'; Module: mSecur32; Override: @Unicows_InitializeSecurityContextW;
      Thunk: InitializeSecurityContextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 48; ErrorReturn: $1304{!!!Sec_E_Internal_Error}),
    (Name: 'InsertMenuItemW'; Module: mUser32; Override: @@Unicows_InsertMenuItemW;
      Thunk: InsertMenuItemW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'InsertMenuW'; Module: mUser32; Override: @@Unicows_InsertMenuW;
      Thunk: InsertMenuW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'IsBadStringPtrW'; Module: mKernel32; Override: @@Unicows_IsBadStringPtrW;
      Thunk: IsBadStringPtrW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 1),
    (Name: 'IsCharAlphaNumericW'; Module: mUser32; Override: @@Unicows_IsCharAlphaNumericW;
      Thunk: IsCharAlphaNumericW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'IsCharAlphaW'; Module: mUser32; Override: @@Unicows_IsCharAlphaW;
      Thunk: IsCharAlphaW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'IsCharLowerW'; Module: mUser32; Override: @@Unicows_IsCharLowerW;
      Thunk: IsCharLowerW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'IsCharUpperW'; Module: mUser32; Override: @@Unicows_IsCharUpperW;
      Thunk: IsCharUpperW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'IsClipboardFormatAvailable'; Module: mUser32; Override: @@Unicows_IsClipboardFormatAvailable;
      Thunk: IsClipboardFormatAvailable_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'IsDestinationReachableW'; Module: mSensAPI; Override: @Unicows_IsDestinationReachableW;
      Thunk: IsDestinationReachableW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'IsDialogMessageW'; Module: mUser32; Override: @@Unicows_IsDialogMessageW;
      Thunk: IsDialogMessageW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'IsTextUnicode'; Module: mAdvAPI32; Override: @@Unicows_IsTextUnicode;
      Thunk: IsTextUnicode_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'IsValidCodePage'; Module: mKernel32; Override: @@Unicows_IsValidCodePage;
      Thunk: IsValidCodePage_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'IsWindowUnicode'; Module: mUser32; Override: @@Unicows_IsWindowUnicode;
      Thunk: IsWindowUnicode_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'LCMapStringW'; Module: mKernel32; Override: @@Unicows_LCMapStringW;
      Thunk: LCMapStringW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'LoadAcceleratorsW'; Module: mUser32; Override: @@Unicows_LoadAcceleratorsW;
      Thunk: LoadAcceleratorsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'LoadBitmapW'; Module: mUser32; Override: @@Unicows_LoadBitmapW;
      Thunk: LoadBitmapW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'LoadCursorFromFileW'; Module: mUser32; Override: @@Unicows_LoadCursorFromFileW;
      Thunk: LoadCursorFromFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'LoadCursorW'; Module: mUser32; Override: @@Unicows_LoadCursorW;
      Thunk: LoadCursorW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'LoadIconW'; Module: mUser32; Override: @@Unicows_LoadIconW;
      Thunk: LoadIconW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'LoadImageW'; Module: mUser32; Override: @@Unicows_LoadImageW;
      Thunk: LoadImageW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'LoadKeyboardLayoutW'; Module: mUser32; Override: @@Unicows_LoadKeyboardLayoutW;
      Thunk: LoadKeyboardLayoutW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'LoadLibraryExW'; Module: mKernel32; Override: @@Unicows_LoadLibraryExW;
      Thunk: LoadLibraryExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'LoadLibraryW'; Module: mKernel32; Override: @@Unicows_LoadLibraryW;
      Thunk: LoadLibraryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'LoadMenuIndirectW'; Module: mUser32; Override: @@Unicows_LoadMenuIndirectW;
      Thunk: LoadMenuIndirectW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'LoadMenuW'; Module: mUser32; Override: @@Unicows_LoadMenuW;
      Thunk: LoadMenuW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'LoadStringW'; Module: mUser32; Override: @@Unicows_LoadStringW;
      Thunk: LoadStringW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'MCIWndCreateW'; Module: mVFW32; Override: @@Unicows_MCIWndCreateW;
      Thunk: MCIWndCreateW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'MapVirtualKeyExW'; Module: mUser32; Override: @@Unicows_MapVirtualKeyExW;
      Thunk: MapVirtualKeyExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'MapVirtualKeyW'; Module: mUser32; Override: @@Unicows_MapVirtualKeyW;
      Thunk: MapVirtualKeyW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'MessageBoxExW'; Module: mUser32; Override: @@Unicows_MessageBoxExW;
      Thunk: MessageBoxExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'MessageBoxIndirectW'; Module: mUser32; Override: @@Unicows_MessageBoxIndirectW;
      Thunk: MessageBoxIndirectW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'MessageBoxW'; Module: mUser32; Override: @@Unicows_MessageBoxW;
      Thunk: MessageBoxW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'ModifyMenuW'; Module: mUser32; Override: @@Unicows_ModifyMenuW;
      Thunk: ModifyMenuW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'MoveFileW'; Module: mKernel32; Override: @@Unicows_MoveFileW;
      Thunk: MoveFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'MultiByteToWideChar'; Module: mKernel32; Override: @@Unicows_MultiByteToWideChar;
      Thunk: MultiByteToWideChar_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'MultinetGetConnectionPerformanceW'; Module: mMPR; Override: @@Unicows_MultinetGetConnectionPerformanceW;
      Thunk: MultinetGetConnectionPerformanceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'OemToCharBuffW'; Module: mUser32; Override: @@Unicows_OemToCharBuffW;
      Thunk: OemToCharBuffW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'OemToCharW'; Module: mUser32; Override: @@Unicows_OemToCharW;
      Thunk: OemToCharW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'OleUIAddVerbMenuW'; Module: mOleDlg; Override: @@Unicows_OleUIAddVerbMenuW;
      Thunk: OleUIAddVerbMenuW_Thunk; ErrorHandler: ThunkError; ParamBytes: 36; ErrorReturn: 0),
    (Name: 'OleUIBusyW'; Module: mOleDlg; Override: @Unicows_OleUIBusyW;
      Thunk: OleUIBusyW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: OleUI_False),
    (Name: 'OleUIChangeIconW'; Module: mOleDlg; Override: @Unicows_OleUIChangeIconW;
      Thunk: OleUIChangeIconW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: OleUI_False),
    (Name: 'OleUIChangeSourceW'; Module: mOleDlg; Override: @Unicows_OleUIChangeSourceW;
      Thunk: OleUIChangeSourceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: OleUI_False),
    (Name: 'OleUIConvertW'; Module: mOleDlg; Override: @Unicows_OleUIConvertW;
      Thunk: OleUIConvertW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: OleUI_False),
    (Name: 'OleUIEditLinksW'; Module: mOleDlg; Override: @Unicows_OleUIEditLinksW;
      Thunk: OleUIEditLinksW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: OleUI_False),
    (Name: 'OleUIInsertObjectW'; Module: mOleDlg; Override: @Unicows_OleUIInsertObjectW;
      Thunk: OleUIInsertObjectW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: OleUI_False),
    (Name: 'OleUIObjectPropertiesW'; Module: mOleDlg; Override: @Unicows_OleUIObjectPropertiesW;
      Thunk: OleUIObjectPropertiesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: OleUI_False),
    (Name: 'OleUIPasteSpecialW'; Module: mOleDlg; Override: @Unicows_OleUIPasteSpecialW;
      Thunk: OleUIPasteSpecialW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: OleUI_False),
    (Name: 'OleUIPromptUserW'; Module: mOleDlg; Override: @@Unicows_OleUIPromptUserW;
      Thunk: OleUIPromptUserW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: OleUI_False),
    (Name: 'OleUIUpdateLinksW'; Module: mOleDlg; Override: @@Unicows_OleUIUpdateLinksW;
      Thunk: OleUIUpdateLinksW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: 0),
    (Name: 'OpenEventW'; Module: mKernel32; Override: @@Unicows_OpenEventW;
      Thunk: OpenEventW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'OpenFileMappingW'; Module: mKernel32; Override: @@Unicows_OpenFileMappingW;
      Thunk: OpenFileMappingW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'OpenMutexW'; Module: mKernel32; Override: @@Unicows_OpenMutexW;
      Thunk: OpenMutexW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'OpenPrinterW'; Module: mWinSpool; Override: @@Unicows_OpenPrinterW;
      Thunk: OpenPrinterW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'OpenSemaphoreW'; Module: mKernel32; Override: @@Unicows_OpenSemaphoreW;
      Thunk: OpenSemaphoreW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'OpenWaitableTimerW'; Module: mKernel32; Override: @@Unicows_OpenWaitableTimerW;
      Thunk: OpenWaitableTimerW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'OutputDebugStringW'; Module: mKernel32; Override: @@Unicows_OutputDebugStringW;
      Thunk: OutputDebugStringW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4),
    (Name: 'PageSetupDlgW'; Module: mComDlg32; Override: @@Unicows_PageSetupDlgW;
      Thunk: PageSetupDlgW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'PeekConsoleInputW'; Module: mKernel32; Override: @@Unicows_PeekConsoleInputW;
      Thunk: PeekConsoleInputW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'PeekMessageW'; Module: mUser32; Override: @@Unicows_PeekMessageW;
      Thunk: PeekMessageW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: 0),
    (Name: 'PlaySoundW'; Module: mWinMM; Override: @@Unicows_PlaySoundW;
      Thunk: PlaySoundW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'PolyTextOutW'; Module: mGDI32; Override: @@Unicows_PolyTextOutW;
      Thunk: PolyTextOutW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'PostMessageW'; Module: mUser32; Override: @@Unicows_PostMessageW;
      Thunk: PostMessageW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'PostThreadMessageW'; Module: mUser32; Override: @@Unicows_PostThreadMessageW;
      Thunk: PostThreadMessageW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'PrintDlgW'; Module: mComDlg32; Override: @@Unicows_PrintDlgW;
      Thunk: PrintDlgW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'QueryContextAttributesW'; Module: mSecur32; Override: @Unicows_QueryContextAttributesW;
      Thunk: QueryContextAttributesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'QueryCredentialsAttributesW'; Module: mSecur32; Override: @Unicows_QueryCredentialsAttributesW;
      Thunk: QueryCredentialsAttributesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0{!!!Sec_E_Unsupported_Function}),
    (Name: 'QueryDosDeviceW'; Module: mKernel32; Override: @@Unicows_QueryDosDeviceW;
      Thunk: QueryDosDeviceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'QuerySecurityPackageInfoW'; Module: mSecur32; Override: @Unicows_QuerySecurityPackageInfoW;
      Thunk: QuerySecurityPackageInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasConnectionNotificationW'; Module: mRasAPI32; Override: @Unicows_RasConnectionNotificationW;
      Thunk: RasConnectionNotificationW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasCreatePhonebookEntryW'; Module: mRasAPI32; Override: @@Unicows_RasCreatePhonebookEntryW;
      Thunk: RasCreatePhonebookEntryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: $1302{!!!Error_Cannot_Open_Phonebook}),
    (Name: 'RasDeleteEntryW'; Module: mRasAPI32; Override: @@Unicows_RasDeleteEntryW;
      Thunk: RasDeleteEntryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Error_Invalid_Name),
    (Name: 'RasDeleteSubEntryW'; Module: mRasAPI32; Override: @@Unicows_RasDeleteSubEntryW;
      Thunk: RasDeleteSubEntryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Invalid_Name),
    (Name: 'RasDialW'; Module: mRasAPI32; Override: @Unicows_RasDialW;
      Thunk: RasDialW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasEditPhonebookEntryW'; Module: mRasAPI32; Override: @@Unicows_RasEditPhonebookEntryW;
      Thunk: RasEditPhonebookEntryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasEnumConnectionsW'; Module: mRasAPI32; Override: @Unicows_RasEnumConnectionsW;
      Thunk: RasEnumConnectionsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasEnumDevicesW'; Module: mRasAPI32; Override: @Unicows_RasEnumDevicesW;
      Thunk: RasEnumDevicesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasEnumEntriesW'; Module: mRasAPI32; Override: @Unicows_RasEnumEntriesW;
      Thunk: RasEnumEntriesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasGetConnectStatusW'; Module: mRasAPI32; Override: @Unicows_RasGetConnectStatusW;
      Thunk: RasGetConnectStatusW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasGetEntryDialParamsW'; Module: mRasAPI32; Override: @Unicows_RasGetEntryDialParamsW;
      Thunk: RasGetEntryDialParamsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasGetEntryPropertiesW'; Module: mRasAPI32; Override: @Unicows_RasGetEntryPropertiesW;
      Thunk: RasGetEntryPropertiesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasGetErrorStringW'; Module: mRasAPI32; Override: @@Unicows_RasGetErrorStringW;
      Thunk: RasGetErrorStringW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasGetProjectionInfoW'; Module: mRasAPI32; Override: @Unicows_RasGetProjectionInfoW;
      Thunk: RasGetProjectionInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasHangUpW'; Module: mRasAPI32; Override: @Unicows_RasHangUpW;
      Thunk: RasHangUpW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: Invalid_Handle_Value),
    (Name: 'RasRenameEntryW'; Module: mRasAPI32; Override: @@Unicows_RasRenameEntryW;
      Thunk: RasRenameEntryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Invalid_Name),
    (Name: 'RasSetEntryDialParamsW'; Module: mRasAPI32; Override: @Unicows_RasSetEntryDialParamsW;
      Thunk: RasSetEntryDialParamsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasSetEntryPropertiesW'; Module: mRasAPI32; Override: @Unicows_RasSetEntryPropertiesW;
      Thunk: RasSetEntryPropertiesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasSetSubEntryPropertiesW'; Module: mRasAPI32; Override: @Unicows_RasSetSubEntryPropertiesW;
      Thunk: RasSetSubEntryPropertiesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 28; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RasValidateEntryNameW'; Module: mRasAPI32; Override: @@Unicows_RasValidateEntryNameW;
      Thunk: RasValidateEntryNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Error_Invalid_Name),
    (Name: 'ReadConsoleInputW'; Module: mKernel32; Override: @@Unicows_ReadConsoleInputW;
      Thunk: ReadConsoleInputW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'ReadConsoleOutputCharacterW'; Module: mKernel32; Override: @@Unicows_ReadConsoleOutputCharacterW;
      Thunk: ReadConsoleOutputCharacterW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'ReadConsoleOutputW'; Module: mKernel32; Override: @@Unicows_ReadConsoleOutputW;
      Thunk: ReadConsoleOutputW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'ReadConsoleW'; Module: mKernel32; Override: @@Unicows_ReadConsoleW;
      Thunk: ReadConsoleW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'RegConnectRegistryW'; Module: mAdvAPI32; Override: @@Unicows_RegConnectRegistryW;
      Thunk: RegConnectRegistryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegCreateKeyExW'; Module: mAdvAPI32; Override: @@Unicows_RegCreateKeyExW;
      Thunk: RegCreateKeyExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 36; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegCreateKeyW'; Module: mAdvAPI32; Override: @@Unicows_RegCreateKeyW;
      Thunk: RegCreateKeyW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegDeleteKeyW'; Module: mAdvAPI32; Override: @@Unicows_RegDeleteKeyW;
      Thunk: RegDeleteKeyW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegDeleteValueW'; Module: mAdvAPI32; Override: @@Unicows_RegDeleteValueW;
      Thunk: RegDeleteValueW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegEnumKeyExW'; Module: mAdvAPI32; Override: @@Unicows_RegEnumKeyExW;
      Thunk: RegEnumKeyExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 32; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegEnumKeyW'; Module: mAdvAPI32; Override: @@Unicows_RegEnumKeyW;
      Thunk: RegEnumKeyW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegEnumValueW'; Module: mAdvAPI32; Override: @@Unicows_RegEnumValueW;
      Thunk: RegEnumValueW_Thunk; ErrorHandler: ThunkError; ParamBytes: 32; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegLoadKeyW'; Module: mAdvAPI32; Override: @@Unicows_RegLoadKeyW;
      Thunk: RegLoadKeyW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegOpenKeyExW'; Module: mAdvAPI32; Override: @@Unicows_RegOpenKeyExW;
      Thunk: RegOpenKeyExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegOpenKeyW'; Module: mAdvAPI32; Override: @@Unicows_RegOpenKeyW;
      Thunk: RegOpenKeyW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegQueryInfoKeyW'; Module: mAdvAPI32; Override: @@Unicows_RegQueryInfoKeyW;
      Thunk: RegQueryInfoKeyW_Thunk; ErrorHandler: ThunkError; ParamBytes: 48; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegQueryMultipleValuesW'; Module: mAdvAPI32; Override: @@Unicows_RegQueryMultipleValuesW;
      Thunk: RegQueryMultipleValuesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegQueryValueExW'; Module: mAdvAPI32; Override: @@Unicows_RegQueryValueExW;
      Thunk: RegQueryValueExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegQueryValueW'; Module: mAdvAPI32; Override: @@Unicows_RegQueryValueW;
      Thunk: RegQueryValueW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegReplaceKeyW'; Module: mAdvAPI32; Override: @@Unicows_RegReplaceKeyW;
      Thunk: RegReplaceKeyW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegSaveKeyW'; Module: mAdvAPI32; Override: @@Unicows_RegSaveKeyW;
      Thunk: RegSaveKeyW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegSetValueExW'; Module: mAdvAPI32; Override: @@Unicows_RegSetValueExW;
      Thunk: RegSetValueExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegSetValueW'; Module: mAdvAPI32; Override: @@Unicows_RegSetValueW;
      Thunk: RegSetValueW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegUnLoadKeyW'; Module: mAdvAPI32; Override: @@Unicows_RegUnLoadKeyW;
      Thunk: RegUnLoadKeyW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'RegisterClassExW'; Module: mUser32; Override: @@Unicows_RegisterClassExW;
      Thunk: RegisterClassExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'RegisterClassW'; Module: mUser32; Override: @@Unicows_RegisterClassW;
      Thunk: RegisterClassW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'RegisterClipboardFormatW'; Module: mUser32; Override: @@Unicows_RegisterClipboardFormatW;
      Thunk: RegisterClipboardFormatW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'RegisterDeviceNotificationW'; Module: mUser32; Override: @@Unicows_RegisterDeviceNotificationW;
      Thunk: RegisterDeviceNotificationW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'RegisterWindowMessageW'; Module: mUser32; Override: @@Unicows_RegisterWindowMessageW;
      Thunk: RegisterWindowMessageW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'RemoveDirectoryW'; Module: mKernel32; Override: @@Unicows_RemoveDirectoryW;
      Thunk: RemoveDirectoryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'RemoveFontResourceW'; Module: mGDI32; Override: @@Unicows_RemoveFontResourceW;
      Thunk: RemoveFontResourceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'RemovePropA'; Module: mUser32; Override: @@Unicows_RemovePropA;
      Thunk: RemovePropA_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'RemovePropW'; Module: mUser32; Override: @@Unicows_RemovePropW;
      Thunk: RemovePropW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'ReplaceTextW'; Module: mComDlg32; Override: @@Unicows_ReplaceTextW;
      Thunk: ReplaceTextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'ResetDCW'; Module: mGDI32; Override: @@Unicows_ResetDCW;
      Thunk: ResetDCW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'ResetPrinterW'; Module: mWinSpool; Override: @@Unicows_ResetPrinterW;
      Thunk: ResetPrinterW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'SHBrowseForFolderW'; Module: mShell32; Override: @@Unicows_SHBrowseForFolderW;
      Thunk: SHBrowseForFolderW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'SHChangeNotify'; Module: mShell32; Override: @@Unicows_SHChangeNotify;
      Thunk: SHChangeNotify_Thunk; ErrorHandler: ThunkError; ParamBytes: 16),
    (Name: 'SHFileOperationW'; Module: mShell32; Override: @@Unicows_SHFileOperationW;
      Thunk: SHFileOperationW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 1),
    (Name: 'SHGetFileInfoW'; Module: mShell32; Override: @@Unicows_SHGetFileInfoW;
      Thunk: SHGetFileInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: 0),
    (Name: 'SHGetNewLinkInfoW'; Module: mShell32; Override: @@Unicows_SHGetNewLinkInfoW;
      Thunk: SHGetNewLinkInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: 0),
    (Name: 'SHGetPathFromIDListW'; Module: mShell32; Override: @@Unicows_SHGetPathFromIDListW;
      Thunk: SHGetPathFromIDListW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'ScrollConsoleScreenBufferW'; Module: mKernel32; Override: @@Unicows_ScrollConsoleScreenBufferW;
      Thunk: ScrollConsoleScreenBufferW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'SearchPathW'; Module: mKernel32; Override: @@Unicows_SearchPathW;
      Thunk: SearchPathW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'SendDlgItemMessageW'; Module: mUser32; Override: @@Unicows_SendDlgItemMessageW;
      Thunk: SendDlgItemMessageW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'SendMessageCallbackW'; Module: mUser32; Override: @@Unicows_SendMessageCallbackW;
      Thunk: SendMessageCallbackW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'SendMessageTimeoutW'; Module: mUser32; Override: @@Unicows_SendMessageTimeoutW;
      Thunk: SendMessageTimeoutW_Thunk; ErrorHandler: ThunkError; ParamBytes: 28; LastError: Error_Call_Not_Implemented),
    (Name: 'SendMessageW'; Module: mUser32; Override: @@Unicows_SendMessageW;
      Thunk: SendMessageW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: 0),
    (Name: 'SendNotifyMessageW'; Module: mUser32; Override: @@Unicows_SendNotifyMessageW;
      Thunk: SendNotifyMessageW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'SetCalendarInfoW'; Module: mKernel32; Override: @@Unicows_SetCalendarInfoW;
      Thunk: SetCalendarInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'SetClassLongW'; Module: mUser32; Override: @@Unicows_SetClassLongW;
      Thunk: SetClassLongW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'SetComputerNameW'; Module: mKernel32; Override: @@Unicows_SetComputerNameW;
      Thunk: SetComputerNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'SetConsoleTitleW'; Module: mKernel32; Override: @@Unicows_SetConsoleTitleW;
      Thunk: SetConsoleTitleW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'SetCurrentDirectoryW'; Module: mKernel32; Override: @@Unicows_SetCurrentDirectoryW;
      Thunk: SetCurrentDirectoryW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'SetDefaultCommConfigW'; Module: mKernel32; Override: @@Unicows_SetDefaultCommConfigW;
      Thunk: SetDefaultCommConfigW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'SetDlgItemTextW'; Module: mUser32; Override: @@Unicows_SetDlgItemTextW;
      Thunk: SetDlgItemTextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'SetEnvironmentVariableW'; Module: mKernel32; Override: @@Unicows_SetEnvironmentVariableW;
      Thunk: SetEnvironmentVariableW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'SetFileAttributesW'; Module: mKernel32; Override: @@Unicows_SetFileAttributesW;
      Thunk: SetFileAttributesW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'SetICMProfileW'; Module: mGDI32; Override: @@Unicows_SetICMProfileW;
      Thunk: SetICMProfileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'SetJobW'; Module: mWinSpool; Override: @@Unicows_SetJobW;
      Thunk: SetJobW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'SetLocaleInfoW'; Module: mKernel32; Override: @@Unicows_SetLocaleInfoW;
      Thunk: SetLocaleInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'SetMenuItemInfoW'; Module: mUser32; Override: @@Unicows_SetMenuItemInfoW;
      Thunk: SetMenuItemInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'SetPrinterDataW'; Module: mWinSpool; Override: @@Unicows_SetPrinterDataW;
      Thunk: SetPrinterDataW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'SetPrinterW'; Module: mWinSpool; Override: @@Unicows_SetPrinterW;
      Thunk: SetPrinterW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'SetPropA'; Module: mUser32; Override: @@Unicows_SetPropA;
      Thunk: SetPropA_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'SetPropW'; Module: mUser32; Override: @@Unicows_SetPropW;
      Thunk: SetPropW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'SetVolumeLabelW'; Module: mKernel32; Override: @@Unicows_SetVolumeLabelW;
      Thunk: SetVolumeLabelW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'SetWindowLongA'; Module: mUser32; Override: @@Unicows_SetWindowLongA;
      Thunk: SetWindowLongA_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'SetWindowLongW'; Module: mUser32; Override: @@Unicows_SetWindowLongW;
      Thunk: SetWindowLongW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'SetWindowTextW'; Module: mUser32; Override: @@Unicows_SetWindowTextW;
      Thunk: SetWindowTextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'SetWindowsHookExW'; Module: mUser32; Override: @@Unicows_SetWindowsHookExW;
      Thunk: SetWindowsHookExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'SetWindowsHookW'; Module: mUser32; Override: @@Unicows_SetWindowsHookW;
      Thunk: SetWindowsHookW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'ShellAboutW'; Module: mShell32; Override: @@Unicows_ShellAboutW;
      Thunk: ShellAboutW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: 0),
    (Name: 'ShellExecuteExW'; Module: mShell32; Override: @@Unicows_ShellExecuteExW;
      Thunk: ShellExecuteExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; LastError: Error_Call_Not_Implemented),
    (Name: 'ShellExecuteW'; Module: mShell32; Override: @@Unicows_ShellExecuteW;
      Thunk: ShellExecuteW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; ErrorReturn: 0),
    (Name: 'Shell_NotifyIconW'; Module: mShell32; Override: @@Unicows_Shell_NotifyIconW;
      Thunk: Shell_NotifyIconW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'StartDocPrinterW'; Module: mWinSpool; Override: @@Unicows_StartDocPrinterW;
      Thunk: StartDocPrinterW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'StartDocW'; Module: mWinSpool; Override: @@Unicows_StartDocW;
      Thunk: StartDocW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'SystemParametersInfoW'; Module: mUser32; Override: @@Unicows_SystemParametersInfoW;
      Thunk: SystemParametersInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'TabbedTextOutW'; Module: mUser32; Override: @@Unicows_TabbedTextOutW;
      Thunk: TabbedTextOutW_Thunk; ErrorHandler: ThunkError; ParamBytes: 32; LastError: Error_Call_Not_Implemented),
    (Name: 'TextOutW'; Module: mUser32; Override: @@Unicows_TextOutW;
      Thunk: TextOutW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'TranslateAcceleratorW'; Module: mUser32; Override: @@Unicows_TranslateAcceleratorW;
      Thunk: TranslateAcceleratorW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'UnregisterClassW'; Module: mUser32; Override: @@Unicows_UnregisterClassW;
      Thunk: UnregisterClassW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'UpdateICMRegKeyW'; Module: mGDI32; Override: @@Unicows_UpdateICMRegKeyW;
      Thunk: UpdateICMRegKeyW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: 0),
    (Name: 'UpdateResourceA'; Module: mKernel32; Override: @@Unicows_UpdateResourceA;
      Thunk: UpdateResourceA_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'UpdateResourceW'; Module: mKernel32; Override: @@Unicows_UpdateResourceW;
      Thunk: UpdateResourceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 24; LastError: Error_Call_Not_Implemented),
    (Name: 'VerFindFileW'; Module: mVersion; Override: @@Unicows_VerFindFileW;
      Thunk: VerFindFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 32; ErrorReturn: vff_FileInUse),
    (Name: 'VerInstallFileW'; Module: mVersion; Override: @@Unicows_VerInstallFileW;
      Thunk: VerInstallFileW_Thunk; ErrorHandler: ThunkError; ParamBytes: 32; ErrorReturn: vif_AccessViolation),
    (Name: 'VerLanguageNameW'; Module: mKernel32; Override: @@Unicows_VerLanguageNameW;
      Thunk: VerLanguageNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'VerQueryValueW'; Module: mVersion; Override: @@Unicows_VerQueryValueW;
      Thunk: VerQueryValueW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: 0),
    (Name: 'VkKeyScanExW'; Module: mUser32; Override: @@Unicows_VkKeyScanExW;
      Thunk: VkKeyScanExW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Cardinal(-1)),
    (Name: 'VkKeyScanW'; Module: mUser32; Override: @@Unicows_VkKeyScanW;
      Thunk: VkKeyScanW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: Cardinal(-1)),
    (Name: 'WNetAddConnection2W'; Module: mMPR; Override: @@Unicows_WNetAddConnection2W;
      Thunk: WNetAddConnection2W_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetAddConnection3W'; Module: mMPR; Override: @@Unicows_WNetAddConnection3W;
      Thunk: WNetAddConnection3W_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetAddConnectionW'; Module: mMPR; Override: @@Unicows_WNetAddConnectionW;
      Thunk: WNetAddConnectionW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetCancelConnection2W'; Module: mMPR; Override: @@Unicows_WNetCancelConnection2W;
      Thunk: WNetCancelConnection2W_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetCancelConnectionW'; Module: mMPR; Override: @@Unicows_WNetCancelConnectionW;
      Thunk: WNetCancelConnectionW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetConnectionDialog1W'; Module: mMPR; Override: @@Unicows_WNetConnectionDialog1W;
      Thunk: WNetConnectionDialog1W_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetDisconnectDialog1W'; Module: mMPR; Override: @@Unicows_WNetDisconnectDialog1W;
      Thunk: WNetDisconnectDialog1W_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetEnumResourceW'; Module: mMPR; Override: @@Unicows_WNetEnumResourceW;
      Thunk: WNetEnumResourceW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetGetConnectionW'; Module: mMPR; Override: @@Unicows_WNetGetConnectionW;
      Thunk: WNetGetConnectionW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetGetLastErrorW'; Module: mMPR; Override: @@Unicows_WNetGetLastErrorW;
      Thunk: WNetGetLastErrorW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetGetNetworkInformationW'; Module: mMPR; Override: @@Unicows_WNetGetNetworkInformationW;
      Thunk: WNetGetNetworkInformationW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetGetProviderNameW'; Module: mMPR; Override: @@Unicows_WNetGetProviderNameW;
      Thunk: WNetGetProviderNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetGetResourceInformationW'; Module: mMPR; Override: @@Unicows_WNetGetResourceInformationW;
      Thunk: WNetGetResourceInformationW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetGetResourceParentW'; Module: mMPR; Override: @@Unicows_WNetGetResourceParentW;
      Thunk: WNetGetResourceParentW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetGetUniversalNameW'; Module: mMPR; Override: @@Unicows_WNetGetUniversalNameW;
      Thunk: WNetGetUniversalNameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetGetUserW'; Module: mMPR; Override: @@Unicows_WNetGetUserW;
      Thunk: WNetGetUserW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetOpenEnumW'; Module: mMPR; Override: @@Unicows_WNetOpenEnumW;
      Thunk: WNetOpenEnumW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WNetUseConnectionW'; Module: mMPR; Override: @@Unicows_WNetUseConnectionW;
      Thunk: WNetUseConnectionW_Thunk; ErrorHandler: ThunkError; ParamBytes: 32; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'WaitNamedPipeW'; Module: mKernel32; Override: @@Unicows_WaitNamedPipeW;
      Thunk: WaitNamedPipeW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'WideCharToMultiByte'; Module: mKernel32; Override: @@Unicows_WideCharToMultiByte;
      Thunk: WideCharToMultiByte_Thunk; ErrorHandler: ThunkError; ParamBytes: 32; LastError: Error_Call_Not_Implemented),
    (Name: 'WinHelpW'; Module: mUser32; Override: @@Unicows_WinHelpW;
      Thunk: WinHelpW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'WriteConsoleInputW'; Module: mKernel32; Override: @@Unicows_WriteConsoleInputW;
      Thunk: WriteConsoleInputW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'WriteConsoleOutputCharacterW'; Module: mKernel32; Override: @@Unicows_WriteConsoleOutputCharacterW;
      Thunk: WriteConsoleOutputCharacterW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'WriteConsoleOutputW'; Module: mKernel32; Override: @@Unicows_WriteConsoleOutputW;
      Thunk: WriteConsoleOutputW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'WriteConsoleW'; Module: mKernel32; Override: @@Unicows_WriteConsoleW;
      Thunk: WriteConsoleW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'WritePrivateProfileSectionW'; Module: mKernel32; Override: @@Unicows_WritePrivateProfileSectionW;
      Thunk: WritePrivateProfileSectionW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'WritePrivateProfileStringW'; Module: mKernel32; Override: @@Unicows_WritePrivateProfileStringW;
      Thunk: WritePrivateProfileStringW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; LastError: Error_Call_Not_Implemented),
    (Name: 'WritePrivateProfileStructW'; Module: mKernel32; Override: @@Unicows_WritePrivateProfileStructW;
      Thunk: WritePrivateProfileStructW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; LastError: Error_Call_Not_Implemented),
    (Name: 'WriteProfileSectionW'; Module: mKernel32; Override: @@Unicows_WriteProfileSectionW;
      Thunk: WriteProfileSectionW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented),
    (Name: 'WriteProfileStringW'; Module: mKernel32; Override: @@Unicows_WriteProfileStringW;
      Thunk: WriteProfileStringW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'auxGetDevCapsW'; Module: mWinMM; Override: @@Unicows_auxGetDevCapsW;
      Thunk: auxGetDevCapsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: mmSysErr_Error),
    (Name: 'capCreateCaptureWindowW'; Module: mVFW32; Override: @@Unicows_capCreateCaptureWindowW;
      Thunk: capCreateCaptureWindowW_Thunk; ErrorHandler: ThunkError; ParamBytes: 32; ErrorReturn: 0),
    (Name: 'capGetDriverDescriptionW'; Module: mVFW32; Override: @@Unicows_capGetDriverDescriptionW;
      Thunk: capGetDriverDescriptionW_Thunk; ErrorHandler: ThunkError; ParamBytes: 20; ErrorReturn: 0),
    (Name: 'joyGetDevCapsW'; Module: mWinMM; Override: @@Unicows_joyGetDevCapsW;
      Thunk: joyGetDevCapsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: mmSysErr_Error),
    (Name: 'lstrcatW'; Module: mKernel32; Override: @@Unicows_lstrcatW;
      Thunk: lstrcatW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'lstrcmpW'; Module: mKernel32; Override: @@Unicows_lstrcmpW;
      Thunk: lstrcmpW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'lstrcmpiW'; Module: mKernel32; Override: @@Unicows_lstrcmpiW;
      Thunk: lstrcmpiW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'lstrcpyW'; Module: mKernel32; Override: @@Unicows_lstrcpyW;
      Thunk: lstrcpyW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'lstrcpynW'; Module: mKernel32; Override: @@Unicows_lstrcpynW;
      Thunk: lstrcpynW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'lstrlenW'; Module: mKernel32; Override: @@Unicows_lstrlenW;
      Thunk: lstrlenW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'mciGetDeviceIDW'; Module: mWinMM; Override: @@Unicows_mciGetDeviceIDW;
      Thunk: mciGetDeviceIDW_Thunk; ErrorHandler: ThunkError; ParamBytes: 4; ErrorReturn: 0),
    (Name: 'mciGetErrorStringW'; Module: mWinMM; Override: @@Unicows_mciGetErrorStringW;
      Thunk: mciGetErrorStringW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'mciSendCommandW'; Module: mWinMM; Override: @@Unicows_mciSendCommandW;
      Thunk: mciSendCommandW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: mciErr_Internal),
    (Name: 'mciSendStringW'; Module: mWinMM; Override: @@Unicows_mciSendStringW;
      Thunk: mciSendStringW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: mciErr_Internal),
    (Name: 'midiInGetDevCapsW'; Module: mWinMM; Override: @@Unicows_midiInGetDevCapsW;
      Thunk: midiInGetDevCapsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: mmSysErr_Error),
    (Name: 'midiInGetErrorTextW'; Module: mWinMM; Override: @@Unicows_midiInGetErrorTextW;
      Thunk: midiInGetErrorTextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: mmSysErr_Error),
    (Name: 'midiOutGetDevCapsW'; Module: mWinMM; Override: @@Unicows_midiOutGetDevCapsW;
      Thunk: midiOutGetDevCapsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: mmSysErr_Error),
    (Name: 'midiOutGetErrorTextW'; Module: mWinMM; Override: @@Unicows_midiOutGetErrorTextW;
      Thunk: midiOutGetErrorTextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 0; ErrorReturn: mmSysErr_Error),
    (Name: 'mixerGetControlDetailsW'; Module: mWinMM; Override: @@Unicows_mixerGetControlDetailsW;
      Thunk: mixerGetControlDetailsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: mmSysErr_Error),
    (Name: 'mixerGetDevCapsW'; Module: mWinMM; Override: @@Unicows_mixerGetDevCapsW;
      Thunk: mixerGetDevCapsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: mmSysErr_Error),
    (Name: 'mixerGetLineControlsW'; Module: mWinMM; Override: @@Unicows_mixerGetLineControlsW;
      Thunk: mixerGetLineControlsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: mmSysErr_Error),
    (Name: 'mixerGetLineInfoW'; Module: mWinMM; Override: @@Unicows_mixerGetLineInfoW;
      Thunk: mixerGetLineInfoW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: mmSysErr_Error),
    (Name: 'mmioInstallIOProcW'; Module: mWinMM; Override: @@Unicows_mmioInstallIOProcW;
      Thunk: mmioInstallIOProcW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: 0),
    (Name: 'mmioOpenW'; Module: mWinMM; Override: @@Unicows_mmioOpenW;
      Thunk: mmioOpenW_Thunk; ErrorHandler: _GodotFailmmioOpenW; ParamBytes: 12),
    (Name: 'mmioRenameW'; Module: mWinMM; Override: @@Unicows_mmioRenameW;
      Thunk: mmioRenameW_Thunk; ErrorHandler: ThunkError; ParamBytes: 16; ErrorReturn: Error_Call_Not_Implemented),
    (Name: 'mmioStringToFOURCCW'; Module: mWinMM; Override: @@Unicows_mmioStringToFOURCCW;
      Thunk: mmioStringToFOURCCW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'sndPlaySoundW'; Module: mWinMM; Override: @@Unicows_sndPlaySoundW;
      Thunk: sndPlaySoundW_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; ErrorReturn: 0),
    (Name: 'waveInGetDevCapsW'; Module: mWinMM; Override: @@Unicows_waveInGetDevCapsW;
      Thunk: waveInGetDevCapsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: mmSysErr_Error),
    (Name: 'waveInGetErrorTextW'; Module: mWinMM; Override: @@Unicows_waveInGetErrorTextW;
      Thunk: waveInGetErrorTextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: mmSysErr_Error),
    (Name: 'waveOutGetDevCapsW'; Module: mWinMM; Override: @@Unicows_waveOutGetDevCapsW;
      Thunk: waveOutGetDevCapsW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: mmSysErr_Error),
    (Name: 'waveOutGetErrorTextW'; Module: mWinMM; Override: @@Unicows_waveOutGetErrorTextW;
      Thunk: waveOutGetErrorTextW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; ErrorReturn: mmSysErr_Error),
    (Name: 'wsprintfW'; Module: mUser32; Override: @Unicows_wsprintfW;
      Thunk: wsprintfW_Thunk; ErrorHandler: ThunkError; ParamBytes: 0; LastError: Error_Call_Not_Implemented),
    (Name: 'wvsprintfW'; Module: mUser32; Override: @@Unicows_wvsprintfW;
      Thunk: wvsprintfW_Thunk; ErrorHandler: ThunkError; ParamBytes: 12; LastError: Error_Call_Not_Implemented),
    (Name: 'GetProcAddress'; Module: mKernel32; Override: @@Unicows_GetProcAddress;
      Thunk: GetProcAddress_Thunk; ErrorHandler: ThunkError; ParamBytes: 8; LastError: Error_Call_Not_Implemented)
  );
{$ENDREGION}

procedure _GodotFailGetPrivateProfileIntW(const DataIndex: TMSLUFunction);//(lpAppName, lpKeyName: PWideChar; nDefault: Integer; lpFileName: PWideChar): UINT; stdcall;
// This function returns nDefault on error.
// esp -> return addr
// esp + 4 -> lpFileName
// esp + 8 -> nDefault
// esp + 12 -> lpKeyName
// esp + 16 -> lpAppName
asm
  push Error_Call_Not_Implemented
  call SetLastError
  mov eax, [esp + 8]
  ret 16
end;

procedure _GodotFailGetProfileIntW(const DataIndex: TMSLUFunction);//(lpAppName, lpKeyName: PWideChar; nDefault: Integer): UINT; stdcall;
// This function returns nDefault on error
// esp -> return addr
// esp + 4 -> nDefault
// esp + 8 -> lpKeyName
// esp + 12 -> lpAppName
asm
  push Error_Call_Not_Implemented
  call SetLastError
  mov eax, [esp + 4]
  ret 12
end;

procedure _GodotFailGetStartupInfoWWorker(const DataIndex: TMSLUFunction; const ErrorAddr: Pointer);
var
  Data: PMSLUProcInfo;
begin
  Data := @MSLUData[DataIndex];
  raise EMSLU.Create(Data.Name) at ErrorAddr;
end;

procedure _GodotFailGetStartupInfoW(const DataIndex: TMSLUFunction);//(var lpStartupInfo: TStartupInfo); stdcall;
// Put the return address in EDX so that _GodotFailGetStartupInfoWWorker can
// report it as the location of the exception.
// esp -> return addr
// esp + 4 -> @lpStartInfo
asm
  mov edx, [esp]
  jmp _GodotFailGetStartupInfoWWorker
end;

procedure _GodotFailmmioOpenW(const DataIndex: TMSLUFunction);//(szFileName: PChar; lpmmioinfo: PMMIOInfo; dwOpenFlags: DWORD): HMMIO; stdcall;
// This function returns NULL on exit, but if lpmmioinfo is a valid pointer,
// then it also sets the wErrorRet member to an error code; I've chosen
// mmioErr_AccessDenied as the closest available match to the actual problem.
// esp -> return addr
// esp + 4 -> dwOpenFlags
// esp + 8 -> lpmmioinfo
// esp + 12 -> szFileName
asm
  mov ecx, [esp + 8]
  xor eax, eax
  jecxz @@exit
  mov [ecx].TMMIOInfo.wErrorRet, mmioErr_AccessDenied
@@exit:
  ret 12
end;

procedure ThunkError(const DataIndex: TMSLUFunction);
// This function pops the proper number of bytes off the stack because it's
// really a stand-in for a stdcall function. (It also works for wsprintfW, which
// is cdecl, because we lie and say there are 0 bytes to pop off the stack.)
// Next, this function calls SetLastError with the configured error code and
// returns another configured value. All the information for this function is
// stored in the MSLUData variable above.
asm
  shl eax, 5
  lea eax, [MSLUData + eax]
  mov ecx, [eax].TMSLUProcInfo.ParamBytes
  jecxz @@skip_stack
  pop edx // return address
  add esp, ecx
  push edx
@@skip_stack:
  push [eax].TMSLUProcInfo.ErrorReturn
  push [eax].TMSLUProcInfo.LastError
  call SetLastError
  pop eax
end;

function LoadUnicows: HModule; inline;
// LoadUnicows returns a handle to Unicows.dll. If the DLL is not already
// loaded, then it will try to load it using the _PfnLoadUnicows callback
// function.
begin
  Result := Windows.GetModuleHandleA(unicows);
  if Result <> 0 then exit;
  if Assigned(_PfnLoadUnicows) then Result := _PfnLoadUnicows
  else Result := Windows.LoadLibraryA(unicows);
end;

type
  TGetProcAddress = function(hModule: HModule; const lpProcName: PAnsiChar): TFarProc; stdcall;
var
  OriginalGetProcAddress: TGetProcAddress;

function LocalGetProcAddress(hModule: HModule; const lpProcName: PAnsiChar): TFarProc; inline;
// LocalGetProcAddress is a wrapper for the normal GetProcAddress API function.
// GetProcAddress is an MSLU-supported function, but we need to call the
// original to load function addresses from Unicows.dll.
begin
  Assert(Assigned(OriginalGetProcAddress), 'GetProcAddress patched without original reference');
  Result := OriginalGetProcAddress(hModule, lpProcName);
end;

function ResolveThunkWorker(const DataIndex: TMSLUFunction; var ThunkVar: TFarProc): TFarProc;
// This function determines which real function to call when the program calls
// an MSLU function. It will use the override function if it's available. Next,
// it will try to load the function from Unicows.dll. If the DLL is not present,
// or if the DLL does not export the function, then ResolveThunkWorker will use
// the function's configured error handler. ResolveThunkWorker also returns a
// pointer to the resolved function so that ResolveThunk can jump to it
// afterward.
{$J+}
const
  HUnicows: HModule = 0;
{$J-}
var
  Data: PMSLUProcInfo;
begin
  Assert(ThunkVar = @ResolveThunk);
  Data := @MSLUData[DataIndex];
  Result := Data.Override^;
  if not Assigned(Result) then begin
    if HUnicows = 0 then HUnicows := LoadUnicows;
    if HUnicows <> 0 then Result := LocalGetProcAddress(HUnicows, PAnsiChar(Data.Name));
  end;
  if not Assigned(Result) then TErrorProc(Result) := Data.ErrorHandler;
  Assert(Assigned(Result));
  ThunkVar := Result;
end;

procedure ResolveThunk(const DataIndex: TMSLUFunction; var ThunkVar: TFarProc);
asm
  push eax
  call ResolveThunkWorker
  // In case ResolveThunkWorker returns the error handler, we need to restore
  // the value of DataIndex so the exception can include the correct function
  // name.
  mov ecx, eax
  pop eax
  jmp ecx
end;

procedure PatchImports;
// This function searches the module's import tables for mentions of functions
// supported by MSLU. It then patches the import table to refer to the thunk
// functions in this unit, so, for instance, a call to DispatchMessageW anywhere
// in the program will be rerouted to DispatchMessageW_Thunk instead. The first
// time each thunk is called, it will call ResolveThunk, which is described in
// more detail above.
// The import-table patching mimics in Delphi what a C linker would have done in
// normal operation; Delphi links by unit name as well as by function name, so
// merely including a unit that implements an imported DLL function is not
// enough to direct all calls in the program to the local copy of the function.
// The above only occurs on non-NT systems. Windows NT already supports Unicode,
// so the import table remains unpatched, which means that Unicows.dll does not
// need to be present.
const
  ModuleNames: array[TModuleID] of string = (
    'Kernel32.dll', 'Secur32.dll', 'GDI32.dll', 'WinSpool.drv', 'User32.dll',
    'ComDlg32.dll', 'Oleacc.dll', 'AdvAPI32.dll', 'Shell32.dll', 'Version.dll',
    'MSVFW32.dll', 'SensAPI.dll', 'MPR.dll', 'OleDlg.dll', 'WinMM.dll',
    'RasAPI32.dll'
  );
var
  fn: TMSLUFunction;
  SelfHandle: Pointer;
  Imports: TJclPeMapImgHooks;
  Thunk: TFarProc;
begin
  // If SysUtils is not initialized before MSLU, then the Win32Platform global
  // variable will not have a meaningful value. The initial value of
  // Win32Platform is 0, which is also the value of Ver_Platform_Win32s, a valid
  // value for the variable. Instead, we use GetDiskFreeSpaceEx as the indicator
  // for initialization. Its default value is nil, so if it has a non-nil value,
  // then we can safely assume that SysUtils has already been initialized.
  Assert(Assigned(SysUtils.GetDiskFreeSpaceEx), 'MSLU requires SysUtils initialization');
  if Win32Platform <> Ver_Platform_Win32_NT then begin
    SelfHandle := Ptr(SysInit.HInstance);
    //SelfHandle := Ptr(GetModuleHandleA(nil));

    // Hook into all imported functions with thunks
    Imports := TJclPeMapImgHooks.Create(False);
    try
      for fn := Low(MSLUData) to High(MSLUData) do begin
        TProcedure(Thunk) := MSLUData[fn].Thunk;
        // This line might be reported as the source of some memory leaks.
        // HookImport creates a new object that, when freed, will unhook the
        // import, and we don't want that to happen, so we never free the object.
        Imports.HookImport(
          SelfHandle,
          ModuleNames[MSLUData[fn].Module],
          MSLUData[fn].Name,
          Thunk,
          Pointer(@OriginalGetProcAddress)
        );
        // We need to keep track of the original GetProcAddress address so we
        // can load functions from Unicows.dll. Unicows.GetProcAddress cannot
        // load itself. For why GetProcAddress is in MSLU at all, see
        // http://blogs.msdn.com/michkap/archive/2005/05/04/414562.aspx.
        // Since fnGetLastError is the last item in the TMSLUFunction enum, we
        // can keep on providing the same OriginalGetProcAddress variable as the
        // last parameter because on the last iteration of the loop, the value
        // the variable gets will indeed be the address of the original
        // GetProcAddress function from Kernel32.dll.
      end;
    finally
      Imports.Free;
    end;
  end else begin
    // This unit does absolutely nothing on Windows NT.
  end;
end;

{ EMSLU }

constructor EMSLU.Create(const AFunctionName: string);
begin
  CreateFmt('Call not implemented: %s', [AFunctionName]);
  FFunctionName := AFunctionName;
end;

initialization
  PatchImports;
end.
